@@ -17,7 +17,6 @@
 
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
-#include <klocale.h>
 #include <kdebug.h>
 
 #include <qfileinfo.h>
@@ -39,6 +38,7 @@ int main(int argc, char *argv[])
                           "(c) 2001, Javier Campos", 0, "http://keduca.sourceforge.net", "submit@bugs.kde.org");
     aboutData.addAuthor("Javier Campos","Original Author", "javi@asyris.org");
     aboutData.addAuthor("Klas Kalass","Current Maintainer", "klas@kde.org");
+    aboutData.addAuthor("Anne-Marie Mahfouf","Various fixes and cleanups", "annma@kde.org");
     KCmdLineArgs::init( argc, argv, &aboutData );
     KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
 
