@@ -26,21 +26,15 @@
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kfiledialog.h>
-#include <kconfig.h>
 #include <kedittoolbar.h>
-#include <kkeydialog.h>
 #include <kdebug.h>
 #include <kio/netaccess.h>
-#include <kglobal.h>
 #include <kmessagebox.h>
 
 #include <qlayout.h>
-#include <qsplitter.h>
 #include <kprinter.h>
-#include <qpaintdevice.h>
 #include <qpaintdevicemetrics.h>
 #include <qpainter.h>
-#include <qfontmetrics.h>
 
 static const char* const keducabuilder_data[] = {
     "15 16 4 1",
@@ -107,6 +101,7 @@ void KEducaBuilder::init()
     form2Layout->addWidget( _split );
 
     this->setCentralWidget( mainView );
+    setupGUI( ToolBar | Keys | StatusBar | Save | Create, "keducabuilderui.rc" );
 }
 
 /** Init menu bar settings */
@@ -122,17 +117,11 @@ void KEducaBuilder::initMenuBar()
     (void)new KAction(i18n("Document Info"), "info", 0, this, SLOT( slotHeader() ), actionCollection(), "info_doc");
     KStdAction::quit(this, SLOT( close() ), actionCollection());
 
-    (void)new KAction(i18n("Add..."), "addquestion", 0, this, SLOT( slotAdd() ), actionCollection(), "question_add");
-    (void)new KAction(i18n("Edit..."), "editquestion", 0, this, SLOT( slotEdit() ), actionCollection(), "question_edit");
-    (void)new KAction(i18n("Remove"), "delquestion", 0, this, SLOT( slotRemove() ), actionCollection(), "question_remove");
-    (void)new KAction(i18n("Up"), "up", 0, this, SLOT( slotUp() ), actionCollection(), "question_up");
-    (void)new KAction(i18n("Down"), "down", 0, this, SLOT( slotDown() ), actionCollection(), "question_down");
-
-      setStandardToolBarMenuEnabled(true);
-    KStdAction::keyBindings				(this, SLOT( slotConfigureKeys() ), actionCollection());
-    KStdAction::configureToolbars	(this, SLOT( slotConfigureToolbar() ), actionCollection());
-
-    createGUI( "keducabuilderui.rc" );
+    (void)new KAction(i18n("&Add..."), "addquestion", 0, this, SLOT( slotAdd() ), actionCollection(), "question_add");
+    (void)new KAction(i18n("&Edit..."), "editquestion", 0, this, SLOT( slotEdit() ), actionCollection(), "question_edit");
+    (void)new KAction(i18n("&Remove"), "delquestion", 0, this, SLOT( slotRemove() ), actionCollection(), "question_remove");
+    (void)new KAction(i18n("&Up"), "up", 0, this, SLOT( slotUp() ), actionCollection(), "question_up");
+    (void)new KAction(i18n("&Down"), "down", 0, this, SLOT( slotDown() ), actionCollection(), "question_down");
 }
 
 /** Delete current document and start new */
@@ -449,7 +438,7 @@ bool KEducaBuilder::fileSaveAs()
             newURL.setPath( newURL.path() + extension );
         }
 
-        if ( KIO::NetAccess::exists( newURL ) ) { // this file exists => ask for confirmation
+        if ( KIO::NetAccess::exists( newURL, false, this ) ) { // this file exists => ask for confirmation
             bOk = KMessageBox::questionYesNo( this,
                                               i18n("A document with this name already exists.\n"\
                                                    "Do you want to overwrite it?"),
@@ -555,28 +544,6 @@ bool KEducaBuilder::checkSave()
     return true;
 }
 
-/** Configure keys */
-void KEducaBuilder::slotConfigureKeys()
-{
-    KKeyDialog::configure( actionCollection() );
-}
-
-/** Configure toolbar */
-void KEducaBuilder::slotConfigureToolbar()
-{
-    this->saveMainWindowSettings( KGlobal::config(), "keducacontrol" );
-    KEditToolbar edit( actionCollection(), "keducacontrolui.rc", this );
-    connect(&edit,SIGNAL(newToolbarConfig()),this,SLOT(slotNewToolbarConfig()));
-    edit.exec();
-}
-
-/** OK/Apply pressed in toolbar editor */
-void KEducaBuilder::slotNewToolbarConfig()
-{
-    createGUI( "keducacontrolui.rc" );
-    this->applyMainWindowSettings( KGlobal::config(), "keducacontrol" );
-}
-
 bool KEducaBuilder::startChooser() {
     KEducaEditorStartDialog startDialog(this, "KEducaEditorStartDialog", true);
 
