@@ -19,14 +19,11 @@
 
 #include <assert.h>
 
-#include <klocale.h>
 #include <kio/netaccess.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
 #include <ktempfile.h>
 
-#include <qtextstream.h>
-#include <qfile.h>
 #include <qfileinfo.h>
 #include <qpixmap.h>
 
@@ -41,11 +38,10 @@ FileRead::~FileRead()
 {
 }
 
-/** Open keduca file. This function can open a remote or local url. */
 bool FileRead::openFile(const KURL &url) {
     QString tmpFile;
     bool returnval=false;
-    if( KIO::NetAccess::download( url, tmpFile ) )
+    if( KIO::NetAccess::download( url, tmpFile, 0 ) )
     {
         returnval=loadFile( tmpFile );
         if (returnval) {
@@ -72,10 +68,12 @@ bool FileRead::loadFile( const QString &filename )
     }
     doc.setContent( &file );
 
-    if( doc.doctype().name() != "educa" )
-    { return false; }
+     QDomElement docElem = doc.documentElement();
+   if( (doc.doctype().isNull()) || (doc.doctype().name() != "educa") )   { 
+    	file.close(); 
+	return false;
+	}
 
-    QDomElement docElem = doc.documentElement();
     QDomNode n = docElem.firstChild();
 
     QDomNodeList dnList = n.childNodes();
@@ -150,7 +148,6 @@ bool FileRead::loadFile( const QString &filename )
     return true;
 }
 
-/** Set value to questions fields */
 void FileRead::setQuestion( QuestionField field, QString text)
 {
 // QF_text, QF_picture, QF_type, QF_time, QF_tip, QF_explain
@@ -175,7 +172,6 @@ void FileRead::setQuestion( QuestionField field, QString text)
     _changed=true;
 }
 
-/** Set value to questions fields */
 void FileRead::setQuestion( QuestionField field, int value )
 {
     switch( field )
@@ -196,7 +192,6 @@ void FileRead::setQuestion( QuestionField field, int value )
     _changed=true;
 }
 
-/** Set value to results fields */
 void FileRead::setResult( ResultField field, QString text)
 {
 // RS_text, QF_picture
@@ -215,7 +210,6 @@ void FileRead::setResult( ResultField field, QString text)
     _changed=true;
 }
 
-/** Set value to results fields */
 void FileRead::setResult( ResultField field, int value )
 {
     switch( field )
@@ -233,8 +227,6 @@ void FileRead::setResult( ResultField field, int value )
     _changed=true;
 }
 
-
-/** Insert an answer field */
 void FileRead::setAnswer( QString text, bool value, int points)
 {
     Answers tmpAnswers;
@@ -247,7 +239,6 @@ void FileRead::setAnswer( QString text, bool value, int points)
     _changed=true;
 }
 
-/** Insert a blank question */
 void FileRead::insertQuestion()
 {
     Questions tempQuestions;
@@ -257,7 +248,6 @@ void FileRead::insertQuestion()
     _changed=true;
 }
 
-/** Insert a blank question */
 void FileRead::insertResult()
 {
     Results tempResults;
@@ -267,7 +257,6 @@ void FileRead::insertResult()
     _changed=true;
 }
 
-/** Go to the First record */
 void FileRead::recordFirst()
 {
     if( _fileEOF = true ) _fileEOF = false;
@@ -275,7 +264,6 @@ void FileRead::recordFirst()
     _recordQuestions = _listQuestions.begin();
 }
 
-/** Go to the Last Record */
 void FileRead::recordLast()
 {
     if( _fileBOF = true ) 	_fileBOF = false;
@@ -284,7 +272,6 @@ void FileRead::recordLast()
     --_recordQuestions;
 }
 
-/** Record Next */
 void FileRead::recordNext()
 {
     ++_recordQuestions;
@@ -297,7 +284,6 @@ void FileRead::recordNext()
       if( _fileBOF = true ) _fileBOF = false;
 }
 
-/** Record previous */
 void FileRead::recordPrevious()
 {
     if( _recordQuestions == _listQuestions.begin() )
@@ -309,7 +295,6 @@ void FileRead::recordPrevious()
     }
 }
 
-/** Go to the First record */
 void FileRead::recordResultFirst()
 {
     if( _fileResultEOF = true ) _fileResultEOF = false;
@@ -317,7 +302,6 @@ void FileRead::recordResultFirst()
     _recordResults = _listResults.begin();
 }
 
-/** Go to the Last Record */
 void FileRead::recordResultLast()
 {
     if( _fileResultBOF = true ) 	_fileResultBOF = false;
@@ -326,7 +310,6 @@ void FileRead::recordResultLast()
     --_recordResults;
 }
 
-/** Record Next */
 void FileRead::recordResultNext()
 {
     ++_recordResults;
@@ -341,7 +324,6 @@ void FileRead::recordResultNext()
     }
 }
 
-/** Record previous */
 void FileRead::recordResultPrevious()
 {
     if( _recordResults == _listResults.begin() )
@@ -355,7 +337,6 @@ void FileRead::recordResultPrevious()
     }
 }
 
-/** Go to the First record */
 void FileRead::recordAnswerFirst()
 {
     if( _fileAnswerEOF = true ) _fileAnswerEOF = false;
@@ -363,7 +344,6 @@ void FileRead::recordAnswerFirst()
     (*_recordQuestions).recordAnswers = (*_recordQuestions).listAnswers.begin();
 }
 
-/** Go to the Last Record */
 void FileRead::recordAnswerLast()
 {
     if( _fileAnswerBOF = true ) 	_fileAnswerBOF = false;
@@ -372,7 +352,6 @@ void FileRead::recordAnswerLast()
     --(*_recordQuestions).recordAnswers;
 }
 
-/** Record Next */
 void FileRead::recordAnswerNext()
 {
     ++(*_recordQuestions).recordAnswers;
@@ -387,7 +366,6 @@ void FileRead::recordAnswerNext()
     }
 }
 
-/** Record previous */
 void FileRead::recordAnswerPrevious()
 {
     if( (*_recordQuestions).recordAnswers == (*_recordQuestions).listAnswers.begin() )
@@ -401,7 +379,6 @@ void FileRead::recordAnswerPrevious()
     }
 }
 
-/** Record previous */
 void FileRead::recordAnswerAt( unsigned int index)
 {
     (*_recordQuestions).recordAnswers = (*_recordQuestions).listAnswers.begin();
@@ -409,13 +386,11 @@ void FileRead::recordAnswerAt( unsigned int index)
       ++(*_recordQuestions).recordAnswers;
 }
 
-/** Record previous */
 unsigned int FileRead::recordAnswerCount()
 {
   return (*_recordQuestions).listAnswers.count();
 }
 
-/** Get the value of the field question */
 QString FileRead::getQuestion( QuestionField field )
 {
 // QF_text, QF_picture, QF_type, QF_time, QF_tip, QF_explain
@@ -447,7 +422,6 @@ QString FileRead::getQuestion( QuestionField field )
     }
 }
 
-/** Get the value of the field questions in integer */
 int FileRead::getQuestionInt( QuestionField field )
 {
     switch( field )
@@ -467,7 +441,6 @@ int FileRead::getQuestionInt( QuestionField field )
     }
 }
 
-/** Get Answer field */
 QString FileRead::getAnswer( AnswerField field )
 {
     // AField { AF_text, AF_value, AF_picture, AF_point };
@@ -488,19 +461,16 @@ QString FileRead::getAnswer( AnswerField field )
     }
 }
 
-/** Get Answer field */
 bool FileRead::getAnswerValue()
 {
     return (*(*_recordQuestions).recordAnswers).value;
 }
 
-/** Get answer field */
 int FileRead::getAnswerPoints()
 {
     return (*(*_recordQuestions).recordAnswers).points;
 }
 
-/** Get the value of the field result */
 QString FileRead::getResult( ResultField field )
 {
     switch( field )
@@ -524,7 +494,6 @@ QString FileRead::getResult( ResultField field )
     }
 }
 
-/** Get the value of the field result */
 int FileRead::getResultInt( ResultField field )
 {
     switch( field )
@@ -542,37 +511,31 @@ int FileRead::getResultInt( ResultField field )
     }
 }
 
-/** Returns if this record is a end of file */
 bool FileRead::recordEOF()
 {
     return _fileEOF;
 }
 
-/** Returns if this record is a begin of file */
 bool FileRead::recordBOF()
 {
     return _fileBOF;
 }
 
-/** Returns if this record is a end of file */
 bool FileRead::recordResultEOF()
 {
     return _fileResultEOF;
 }
 
-/** Returns if this record is a begin of file */
 bool FileRead::recordResultBOF()
 {
     return _fileResultBOF;
 }
 
-/** Returns if this record is a end of file */
 bool FileRead::recordAnswerEOF()
 {
     return _fileAnswerEOF;
 }
 
-/** Returns if this record is a begin of file */
 bool FileRead::recordAnswerBOF()
 {
     return _fileAnswerBOF;
@@ -601,13 +564,13 @@ QString FileRead::getPicture()
   return picture;
 }
 
-/** Get an existing file */
 QPixmap FileRead::getPicturePixmap()
 {
-  QString picture = getPicture();
+  
+  KURL picture ( getPicture() );
   QPixmap pict;
     
-  if( KIO::NetAccess::download( picture, _tmpfileImage ) )
+  if( KIO::NetAccess::download( picture, _tmpfileImage, 0 ) )
   {
     kdDebug()<<"... load successful: "<< _tmpfileImage <<endl;
     pict = QPixmap( _tmpfileImage );
@@ -622,21 +585,18 @@ QPixmap FileRead::getPicturePixmap()
   return pict;
 }
 
-/** Clear answers */
 void FileRead::clearAnswers()
 {
     ((*_recordQuestions).listAnswers).clear();
     _changed=true;
 }
 
-/** Delete current record */
 void FileRead::recordDelete()
 {
     _listQuestions.remove( _recordQuestions );
     _changed=true;
 }
 
-/** Swap two variables */
 void FileRead::recordSwap( bool moveup )
 {
     Questions listTMP;
@@ -663,7 +623,6 @@ void FileRead::recordSwap( bool moveup )
     _changed=true;
 }
 
-/** Save file */
 bool FileRead::saveFile( const KURL &url, bool copyimages )
 {
     if (url.isValid())
@@ -696,7 +655,7 @@ bool FileRead::saveFile( const KURL &url, bool copyimages )
         // otherwise, we already had a temp file
         if( saveFile(_tmpfile->name(), copyimages) ) {
             // upload the file
-             KIO::Job * job = KIO::file_copy( _tmpfile->name(), _currentURL, -1, true /*overwrite*/ );
+             KIO::Job * job = KIO::file_copy( KURL::fromPathOrURL( _tmpfile->name() ), _currentURL, -1, true /*overwrite*/ );
              connect( job, SIGNAL( result( KIO::Job * ) ), this, SLOT( slotUploadFinished (KIO::Job *) ) );
             return true;
         }
@@ -818,7 +777,7 @@ bool FileRead::saveFile( const QString &filename, bool copyimages )
         KURL::List	KurlLIST( copyJOB );
         KIO::CopyJob *copyjob;
 
-        copyjob = KIO::copy( KurlLIST, _currentURL.directory(false,true), true);
+        copyjob = KIO::copy( KurlLIST, KURL( _currentURL.directory(false,true) ), true);
     }
     _changed=false;
     return true;
@@ -858,7 +817,7 @@ bool FileRead::saveResults( const KURL &url, const QString &results )
         // otherwise, we already had a temp file
         if( saveResults(_tmpfile->name(), results) ) {
             // upload the file
-             KIO::Job * job = KIO::file_copy( _tmpfile->name(), _currentURL, -1, true /*overwrite*/ );
+             KIO::Job * job = KIO::file_copy( KURL::fromPathOrURL( _tmpfile->name() ), _currentURL, -1, true /*overwrite*/ );
              connect( job, SIGNAL( result( KIO::Job * ) ), this, SLOT( slotUploadFinished (KIO::Job *) ) );
             return true;
         }
