@@ -20,24 +20,29 @@
 
 #include "exporttoimagedialog.h"
 
-#include "../kig/kig_view.h"
+#include "../kig/kig_document.h"
 #include "../kig/kig_part.h"
-#include "../objects/object_imp.h"
-#include "../objects/object.h"
-#include "../objects/line_imp.h"
-#include "../objects/text_imp.h"
-#include "../objects/circle_imp.h"
-#include "../objects/point_imp.h"
-#include "../objects/other_imp.h"
+#include "../kig/kig_view.h"
 #include "../misc/common.h"
+#include "../objects/circle_imp.h"
+#include "../objects/line_imp.h"
+#include "../objects/object_drawer.h"
+#include "../objects/object_holder.h"
+#include "../objects/object_imp.h"
+#include "../objects/other_imp.h"
+#include "../objects/point_imp.h"
+#include "../objects/text_imp.h"
+
+#include <qcolor.h>
+#include <qfile.h>
+#include <qiconset.h>
+#include <qtextstream.h>
 
 #include <kaction.h>
 #include <kfiledialog.h>
+#include <kiconloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
-#include <qfile.h>
-#include <qtextstream.h>
-#include <qcolor.h>
 
 #include <map>
 
@@ -51,19 +56,28 @@ class ExporterAction
   : public KAction
 {
   KigExporter* mexp;
-  const KigDocument* mdoc;
+  const KigPart* mdoc;
   KigWidget* mw;
 public:
-  ExporterAction( const KigDocument* doc, KigWidget* w,
+  ExporterAction( const KigPart* doc, KigWidget* w,
                   KActionCollection* parent, KigExporter* exp );
   void slotActivated();
 };
 
-ExporterAction::ExporterAction( const KigDocument* doc, KigWidget* w,
+ExporterAction::ExporterAction( const KigPart* doc, KigWidget* w,
                                 KActionCollection* parent, KigExporter* exp )
   : KAction( exp->menuEntryName(), KShortcut(), 0, 0, parent ),
     mexp( exp ), mdoc( doc ), mw( w )
 {
+  QString iconstr = exp->menuIcon();
+  if ( iconstr.isEmpty() )
+    return;
+  KIconLoader* l = doc->instance()->iconLoader();
+  QPixmap icon = l->loadIcon( iconstr, KIcon::User, 0, KIcon::DefaultState, 0L, true );
+  if ( icon.isNull() )
+    icon = l->loadIcon( exp->menuIcon(), KIcon::Small );
+  if ( !icon.isNull() )
+    setIconSet( QIconSet( icon ) );
 }
 
 void ExporterAction::slotActivated()
@@ -89,7 +103,12 @@ QString ImageExporter::menuEntryName() const
   return i18n( "&Image..." );
 }
 
-void ImageExporter::run( const KigDocument& doc, KigWidget& w )
+QString ImageExporter::menuIcon() const
+{
+  return "image";
+}
+
+void ImageExporter::run( const KigPart& doc, KigWidget& w )
 {
   ExportToImageDialog* d = new ExportToImageDialog( &w, &doc );
   d->exec();
@@ -109,7 +128,7 @@ KigExportManager::~KigExportManager()
     delete mexporters[i];
 }
 
-void KigExportManager::addMenuAction( const KigDocument* doc, KigWidget* w,
+void KigExportManager::addMenuAction( const KigPart* doc, KigWidget* w,
                                       KActionCollection* coll )
 {
   KActionMenu* m =
@@ -139,11 +158,16 @@ QString XFigExporter::menuEntryName() const
   return i18n( "&XFig File..." );
 }
 
+QString XFigExporter::menuIcon() const
+{
+  return "xfig";
+}
+
 class XFigExportImpVisitor
   : public ObjectImpVisitor
 {
   QTextStream& mstream;
-  RealObject* mcurobj;
+  ObjectHolder* mcurobj;
   const KigWidget& mw;
   Rect msr;
   std::map<const QColor, int> mcolormap;
@@ -164,8 +188,8 @@ class XFigExportImpVisitor
 
   void emitLine( const Coordinate& a, const Coordinate& b, int width, bool vector = false );
 public:
-  void visit( Object* obj );
-  void mapColor( Object* obj );
+  void visit( ObjectHolder* obj );
+  void mapColor( const ObjectDrawer* obj );
 
   XFigExportImpVisitor( QTextStream& s, const KigWidget& w )
     : mstream( s ), mw( w ), msr( mw.showingRect() ),
@@ -195,7 +219,7 @@ public:
   void visit( const ArcImp* imp );
 };
 
-void XFigExportImpVisitor::mapColor( Object* obj )
+void XFigExportImpVisitor::mapColor( const ObjectDrawer* obj )
 {
   if ( ! obj->shown() ) return;
   QColor color = obj->color();
@@ -209,13 +233,12 @@ void XFigExportImpVisitor::mapColor( Object* obj )
   }
 }
 
-void XFigExportImpVisitor::visit( Object* obj )
+void XFigExportImpVisitor::visit( ObjectHolder* obj )
 {
-  if ( ! obj->shown() ) return;
-  assert( obj->inherits( Object::ID_RealObject ) );
-  assert( mcolormap.find( obj->color() ) != mcolormap.end() );
-  mcurcolorid = mcolormap[ obj->color() ];
-  mcurobj = static_cast<RealObject*>( obj );
+  if ( ! obj->drawer()->shown() ) return;
+  assert( mcolormap.find( obj->drawer()->color() ) != mcolormap.end() );
+  mcurcolorid = mcolormap[ obj->drawer()->color() ];
+  mcurobj = obj;
   obj->imp()->visit( this );
 }
 
@@ -224,10 +247,11 @@ void XFigExportImpVisitor::visit( const LineImp* imp )
   Coordinate a = imp->data().a;
   Coordinate b = imp->data().b;
   calcBorderPoints( a, b, msr );
-  int width = mcurobj->width();
+  int width = mcurobj->drawer()->width();
   if ( width == -1 ) width = 1;
 
-  emitLine( a, b, width );
+  if ( a != b )
+    emitLine( a, b, width );
 }
 
 void XFigExportImpVisitor::emitLine( const Coordinate& a, const Coordinate& b, int width, bool vector )
@@ -275,7 +299,7 @@ void XFigExportImpVisitor::emitLine( const Coordinate& a, const Coordinate& b, i
 void XFigExportImpVisitor::visit( const PointImp* imp )
 {
   const QPoint center = convertCoord( imp->coordinate() );
-  int width = mcurobj->width();
+  int width = mcurobj->drawer()->width();
   if ( width == -1 ) width = 5;
   width *= 10;
 
@@ -327,7 +351,7 @@ void XFigExportImpVisitor::visit( const AngleImp* )
 
 void XFigExportImpVisitor::visit( const VectorImp* imp )
 {
-  int width = mcurobj->width();
+  int width = mcurobj->drawer()->width();
   if ( width == -1 ) width = 1;
   emitLine( imp->a(), imp->b(), width, true );
 }
@@ -346,7 +370,7 @@ void XFigExportImpVisitor::visit( const CircleImp* imp )
   mstream << "1 "  // Ellipse type
           << "3 "  // circle defined by radius subtype
           << "0 "; // line_style: Solid
-  int width = mcurobj->width();
+  int width = mcurobj->drawer()->width();
   if ( width == -1 ) width = 1;
   mstream << width << " " // thickness: *1/80 inch
           << mcurcolorid << " " // pen_color: default
@@ -368,7 +392,7 @@ void XFigExportImpVisitor::visit( const CircleImp* imp )
 
 void XFigExportImpVisitor::visit( const ConicImp* imp )
 {
-  int width = mcurobj->width();
+  int width = mcurobj->drawer()->width();
   if ( width == -1 ) width = 1;
   if ( imp->conicType() == 1 )
   {
@@ -431,7 +455,7 @@ void XFigExportImpVisitor::visit( const SegmentImp* imp )
 {
   Coordinate a = imp->data().a;
   Coordinate b = imp->data().b;
-  int width = mcurobj->width();
+  int width = mcurobj->drawer()->width();
   if ( width == -1 ) width = 1;
 
   emitLine( a, b, width );
@@ -443,7 +467,7 @@ void XFigExportImpVisitor::visit( const RayImp* imp )
   Coordinate b = imp->data().b;
   calcRayBorderPoints( a, b, msr );
 
-  int width = mcurobj->width();
+  int width = mcurobj->drawer()->width();
   if ( width == -1 ) width = 1;
 
   emitLine( a, b, width );
@@ -467,7 +491,7 @@ void XFigExportImpVisitor::visit( const ArcImp* imp )
   mstream << "5 "  // Ellipse type
           << "1 "  // subtype: open ended arc
           << "0 "; // line_style: Solid
-  int width = mcurobj->width();
+  int width = mcurobj->drawer()->width();
   if ( width == -1 ) width = 1;
   mstream << width << " " // thickness: *1/80 inch
           << mcurcolorid << " " // pen_color: default
@@ -491,16 +515,18 @@ void XFigExportImpVisitor::visit( const ArcImp* imp )
           << "\n";
 }
 
-void XFigExporter::run( const KigDocument& doc, KigWidget& w )
+void XFigExporter::run( const KigPart& doc, KigWidget& w )
 {
   QString formats = i18n( "*.fig|XFig Documents (*.fig)" );
-  QString file_name = KFileDialog::getSaveFileName(":document", formats );
+  QString file_name = KFileDialog::getSaveFileName(":document", formats, &w,
+                        i18n( "Export as XFig File" ) );
   if ( file_name.isEmpty() ) return;
   else if ( QFileInfo( file_name ).exists() )
   {
     int ret = KMessageBox::warningYesNo(
       &w,
-      i18n( "The file \"%1\" already exists. Do you wish to overwrite it?" ).arg( file_name ) );
+      i18n( "The file \"%1\" already exists. Do you wish to overwrite it?" ).arg( file_name ),
+      i18n( "Overwrite File?" ) );
     if ( ret != KMessageBox::Yes ) return;
   };
   QFile file( file_name );
@@ -522,16 +548,16 @@ void XFigExporter::run( const KigDocument& doc, KigWidget& w )
   stream << "-2\n";
   stream << "1200 2\n";
 
-  Objects os = doc.objects();
+  std::vector<ObjectHolder*> os = doc.document().objects();
   XFigExportImpVisitor visitor( stream, w );
 
-  for ( Objects::const_iterator i = os.begin();
+  for ( std::vector<ObjectHolder*>::const_iterator i = os.begin();
         i != os.end(); ++i )
   {
-    visitor.mapColor( *i );
+    visitor.mapColor( ( *i )->drawer() );
   };
 
-  for ( Objects::const_iterator i = os.begin();
+  for ( std::vector<ObjectHolder*>::const_iterator i = os.begin();
         i != os.end(); ++i )
   {
     visitor.visit( *i );
