@@ -23,6 +23,7 @@
 
 #include "aboutdata.h"
 #include "kig_commands.h"
+#include "kig_document.h"
 #include "kig_view.h"
 
 #include "../filters/exporter.h"
@@ -36,9 +37,14 @@
 #include "../misc/object_constructor.h"
 #include "../misc/screeninfo.h"
 #include "../modes/normal.h"
-#include "../objects/object.h"
+#include "../objects/object_drawer.h"
 #include "../objects/point_imp.h"
 
+#include <stdio.h>
+
+#include <algorithm>
+#include <functional>
+
 #include <kaction.h>
 #include <kapplication.h>
 #include <kdebug.h>
@@ -50,68 +56,127 @@
 #include <kmainwindow.h>
 #include <kmessagebox.h>
 #include <kmimetype.h>
-#include <kparts/genericfactory.h>
 #include <kprinter.h>
 #include <kstandarddirs.h>
 #include <kstdaction.h>
 #include <ktoolbar.h>
+#include <kparts/genericfactory.h>
+#include <kdeprint/kprintdialogpage.h>
 
+#include <qcheckbox.h>
 #include <qfile.h>
+#include <qlayout.h>
 #include <qpaintdevicemetrics.h>
+#include <qsizepolicy.h>
 #include <qtimer.h>
 #if QT_VERSION >= 0x030100
 #include <qeventloop.h>
 #endif
 
-#include <algorithm>
-#include <functional>
-
 using namespace std;
 
 // export this library...
-typedef KParts::GenericFactory<KigDocument> KigDocumentFactory;
-K_EXPORT_COMPONENT_FACTORY ( libkigpart, KigDocumentFactory )
+typedef KParts::GenericFactory<KigPart> KigPartFactory;
+K_EXPORT_COMPONENT_FACTORY ( libkigpart, KigPartFactory )
 
-KAboutData* KigDocument::createAboutData()
+KAboutData* KigPart::createAboutData()
 {
-  return kigAboutData( "kigpart", I18N_NOOP( "KigPart" ) );
+  return kigAboutData( "kig", I18N_NOOP( "KigPart" ) );
 }
 
 class SetCoordinateSystemAction
-  : public KAction
+  : public KSelectAction
 {
-  KigDocument& md;
-  uint mn;
+  KigPart& md;
 public:
-  SetCoordinateSystemAction( const QString text, KigDocument& d,
-                             uint i, KActionCollection* parent );
-  void slotActivated();
+  SetCoordinateSystemAction( KigPart& d, KActionCollection* parent );
+  void slotActivated( int index );
 };
 
 SetCoordinateSystemAction::SetCoordinateSystemAction(
-  const QString text, KigDocument& d,
-  uint i, KActionCollection* parent )
-  : KAction( text, 0, 0, 0, parent, 0 ),
-    md( d ), mn( i )
+  KigPart& d, KActionCollection* parent )
+  : KSelectAction( i18n( "&Set Coordinate System" ), 0, parent, "settings_set_coordinate_system" ),
+    md( d )
 {
+  setItems( CoordinateSystemFactory::names() );
+  setCurrentItem( md.document().coordinateSystem().id() );
 }
 
-void SetCoordinateSystemAction::slotActivated()
+void SetCoordinateSystemAction::slotActivated( int index )
 {
-  CoordinateSystem* sys = CoordinateSystemFactory::build( mn );
+  CoordinateSystem* sys = CoordinateSystemFactory::build( index );
   assert( sys );
   md.history()->addCommand( KigCommand::changeCoordSystemCommand( md, sys ) );
+  setCurrentItem( index );
 }
 
-KigDocument::KigDocument( QWidget *parentWidget, const char *,
+class KigPrintDialogPage
+  : public KPrintDialogPage
+{
+public:
+  KigPrintDialogPage( QWidget* parent = 0, const char* name = 0 );
+  ~KigPrintDialogPage();
+
+  void getOptions( QMap<QString,QString>& opts, bool );
+  void setOptions( const QMap<QString,QString>& opts );
+  bool isValid( QString& );
+
+private:
+  QCheckBox *showgrid;
+  QCheckBox *showaxes;
+};
+
+KigPrintDialogPage::KigPrintDialogPage( QWidget* parent, const char* name )
+ : KPrintDialogPage( parent, name )
+{
+  setTitle( i18n( "Kig Options" ) );
+
+ QVBoxLayout* vl = new QVBoxLayout( this, 0 , 11 );
+
+ showgrid = new QCheckBox( i18n( "Show grid" ), this );
+ vl->addWidget( showgrid );
+
+ showaxes = new QCheckBox( i18n( "Show axes" ), this );
+ vl->addWidget( showaxes );
+
+ vl->addItem( new QSpacerItem( 10, 10, QSizePolicy::Fixed, QSizePolicy::Expanding ) );
+}
+
+KigPrintDialogPage::~KigPrintDialogPage()
+{
+}
+
+void KigPrintDialogPage::getOptions( QMap< QString, QString >& opts, bool )
+{
+  opts[ "kde-kig-showgrid" ] = QString::number( showgrid->isChecked() );
+  opts[ "kde-kig-showaxes" ] = QString::number( showaxes->isChecked() );
+}
+
+void KigPrintDialogPage::setOptions( const QMap< QString, QString >& opts )
+{
+  QString tmp = opts[ "kde-kig-showgrid" ];
+  bool bt = ( tmp != "0" );
+  showgrid->setChecked( bt );
+  tmp = opts[ "kde-kig-showaxes" ];
+  bt = ( tmp != "0" );
+  showaxes->setChecked( bt );
+}
+
+bool KigPrintDialogPage::isValid( QString& )
+{
+  return true;
+}
+
+KigPart::KigPart( QWidget *parentWidget, const char *,
 			  QObject *parent, const char *name,
 			  const QStringList& )
   : KParts::ReadWritePart( parent, name ),
-    mMode( 0 ),
-    mcoordsystem( new EuclideanCoords )
+    mMode( 0 ), mdocument( new KigDocument() )
 {
   // we need an instance
-  setInstance( KigDocumentFactory::instance() );
+  setInstance( KigPartFactory::instance() );
+
+  mMode = new NormalMode( *this );
 
   // we need a widget, to actually show the document
   m_widget = new KigView(this, false, parentWidget, "kig_view");
@@ -137,12 +202,10 @@ KigDocument::KigDocument( QWidget *parentWidget, const char *,
 
   setModified (false);
 
-  mMode = new NormalMode( *this );
-
   GUIActionList::instance()->regDoc( this );
 }
 
-void KigDocument::setupActions()
+void KigPart::setupActions()
 {
   // save actions..
   (void) KStdAction::saveAs(this, SLOT(fileSaveAs()), actionCollection());
@@ -163,7 +226,7 @@ void KigDocument::setupActions()
     "edit_invert_selection" );
 
   // we need icons...
-  KIconLoader* l = KGlobal::iconLoader();
+  KIconLoader* l = instance()->iconLoader();
   QPixmap tmp;
 
   tmp = l->loadIcon( "editdelete", KIcon::Toolbar);
@@ -193,7 +256,7 @@ void KigDocument::setupActions()
   aNewMacro->setToolTip(i18n("Define a new macro"));
 
   aConfigureTypes = new KAction(
-    i18n("Manage &Types"), 0, this, SLOT(editTypes()),
+    i18n("Manage &Types..."), 0, this, SLOT(editTypes()),
     actionCollection(), "types_edit");
   aConfigureTypes->setToolTip(i18n("Manage macro types."));
 
@@ -225,7 +288,7 @@ void KigDocument::setupActions()
 #ifdef KIG_PART_CPP_STD_FULLSCREEN_ACTION
   a = KStdAction::fullScreen( m_widget, SLOT( toggleFullScreen() ), actionCollection(), 0 );
 #else
-  tmp = l->loadIcon( "window_fullscreen", KIcon::User );
+  tmp = l->loadIcon( "window_fullscreen", KIcon::Toolbar );
   a = new KAction(
     i18n( "Full Screen" ), tmp, CTRL+SHIFT+Key_F,
     m_widget, SLOT( toggleFullScreen() ),
@@ -237,57 +300,52 @@ void KigDocument::setupActions()
   // TODO: an icon for this..
   tmp = l->loadIcon( "viewmagfit", KIcon::Toolbar );
   a = new KAction(
-    i18n( "Select Shown Area" ), tmp, 0, m_widget, SLOT( zoomRect() ),
+    i18n( "&Select Shown Area" ), tmp, 0, m_widget, SLOT( zoomRect() ),
     actionCollection(), "view_select_shown_rect" );
   a->setToolTip( i18n( "Select the area that you want to be shown in the window." ) );
   a->setWhatsThis( i18n( "Select the area that you want to be shown in the window." ) );
 
+  a = new KAction(
+    i18n( "S&elect Zoom Area" ), 0, m_widget, SLOT( zoomArea() ),
+    actionCollection(), "view_zoom_area" );
+//  a->setToolTip( i18n( "Select the area that you want to be shown in the window." ) );
+//  a->setWhatsThis( i18n( "Select the area that you want to be shown in the window." ) );
+
+  aToggleGrid = new KToggleAction(
+    i18n( "Show &Grid" ), 0, this, SLOT( toggleGrid() ),
+    actionCollection(), "settings_show_grid" );
+  aToggleGrid->setToolTip( i18n( "Show or hide the grid." ) );
+  aToggleGrid->setChecked( true );
+
+  aToggleAxes = new KToggleAction(
+    i18n( "Show &Axes" ), 0, this, SLOT( toggleAxes() ),
+    actionCollection(), "settings_show_axes" );
+  aToggleAxes->setToolTip( i18n( "Show or hide the axes." ) );
+  aToggleAxes->setChecked( true );
+
   // select coordinate system KActionMenu..
-  KActionMenu* am =
-    new KActionMenu( i18n( "&Set Coordinate System" ), actionCollection(),
-                     "settings_set_coordinate_system" );
-  QStringList csnames = CoordinateSystemFactory::names();
-  for ( uint i = 0; i < csnames.size(); ++i )
-    am->insert( new SetCoordinateSystemAction( csnames[i], *this, i,
-                                               actionCollection() ) );
+  aCoordSystem = new SetCoordinateSystemAction( *this, actionCollection() );
 }
 
-void KigDocument::setupTypes()
+void KigPart::setupTypes()
 {
   setupBuiltinStuff();
   setupBuiltinMacros();
   setupMacroTypes();
   GUIActionList& l = *GUIActionList::instance();
-  for ( uint i = 0; i < l.actions().size(); ++i )
+  typedef GUIActionList::avectype::const_iterator iter;
+  for ( iter i = l.actions().begin(); i != l.actions().end(); ++i )
   {
-    KigGUIAction* ret = new KigGUIAction( l.actions()[i], *this, actionCollection() );
+    KigGUIAction* ret = new KigGUIAction( *i, *this, actionCollection() );
     aActions.push_back( ret );
     ret->plug( this );
   };
 }
 
-KigDocument::~KigDocument()
+KigPart::~KigPart()
 {
   GUIActionList::instance()->unregDoc( this );
 
-  // TODO: remove some time in the future..  doesn't really hurt, but
-  // well, it's not really necessary either..  However, I'm not going
-  // to remove this in the next release yet, since it would cause
-  // duplication of macro types combined with the changing to use
-  // macro.kigt instead of macro files named after the macro they
-  // contain..
-  // remove old types:
-  QStringList relFiles;
-  QStringList dataFiles =
-    KGlobal::dirs()->findAllResources("appdata", "kig-types/*.kigt",
-                                        true, false, relFiles);
-  for ( QStringList::iterator file = dataFiles.begin();
-        file != dataFiles.end(); ++file )
-  {
-    QFile f( *file );
-    f.remove();
-  };
-
   // save our types...
   QString typesDir = KGlobal::dirs()->saveLocation("appdata", "kig-types");
   if (typesDir[typesDir.length() - 1] != '/') typesDir += '/';
@@ -301,18 +359,19 @@ KigDocument::~KigDocument()
   aActions.clear();
 
   // cleanup
-  delete mcoordsystem;
   delete mMode;
   delete mhistory;
+
+  delete mdocument;
 }
 
-bool KigDocument::openFile()
+bool KigPart::openFile()
 {
   QFileInfo fileinfo( m_file );
   if ( ! fileinfo.exists() )
   {
     KMessageBox::sorry( widget(),
-                        i18n( "The file \"%1\" you tried to open does not exist.  "
+                        i18n( "The file \"%1\" you tried to open does not exist. "
                               "Please verify that you entered the correct path." ).arg( m_file ),
                         i18n( "File Not Found" ) );
     return false;
@@ -329,8 +388,8 @@ bool KigDocument::openFile()
     KMessageBox::sorry
       (
         widget(),
-        i18n( "You tried to open a document of type \"%1\". Unfortunately, "
-              "Kig doesn't support this format. If you think the format in "
+        i18n( "You tried to open a document of type \"%1\"; unfortunately, "
+              "Kig does not support this format. If you think the format in "
               "question would be worth implementing support for, you can "
               "always ask me nicely on mailto:devriese@kde.org "
               "or do the work yourself and send me a patch."
@@ -339,22 +398,29 @@ bool KigDocument::openFile()
         );
     return false;
   };
-  if ( !filter->load (m_file, *this) )
-    return false;
+
+  KigDocument* newdoc = filter->load (m_file);
+  if ( !newdoc ) return false;
+  delete mdocument;
+  mdocument = newdoc;
+  coordSystemChanged( mdocument->coordinateSystem().id() );
+  aToggleGrid->setChecked( mdocument->grid() );
+  aToggleAxes->setChecked( mdocument->axes() );
 
   setModified(false);
   mhistory->clear();
 
-  Objects tmp = calcPath( objects() );
-  tmp.calc( *this );
+  std::vector<ObjectCalcer*> tmp = calcPath( getAllParents( getCalcers( document().objects() ) ) );
+  for ( std::vector<ObjectCalcer*>::iterator i = tmp.begin(); i != tmp.end(); ++i )
+    ( *i )->calc( document() );
   emit recenterScreen();
 
-  mode()->redrawScreen();
+  redrawScreen();
 
   return true;
 }
 
-bool KigDocument::saveFile()
+bool KigPart::saveFile()
 {
   if ( m_file.isEmpty() ) return internalSaveAs();
   // mimetype:
@@ -362,17 +428,15 @@ bool KigDocument::saveFile()
   if ( mimeType->name() != "application/x-kig" )
   {
     // we don't support this mime type...
-    KMessageBox::sorry
-      (
-        widget(),
-        i18n( "Kig does not support saving to any other file format than "
-              "its own." ).arg( mimeType->name() ),
-        i18n( "Format not Supported" )
-        );
-    return false;
+    if( KMessageBox::warningYesNo( widget(),
+                     i18n( "Kig does not support saving to any other file format than "
+                           "its own. Save to Kig's format instead?" ),
+                     i18n( "Format not Supported" ) ) == KMessageBox::No )
+      return false;
+    internalSaveAs();
   };
 
-  if ( KigFilters::instance()->save( *this, m_file ) )
+  if ( KigFilters::instance()->save( document(), m_file ) )
   {
     setModified ( false );
     mhistory->documentSaved();
@@ -381,183 +445,126 @@ bool KigDocument::saveFile()
   return false;
 }
 
-void KigDocument::addObject(Object* o)
+void KigPart::addObject(ObjectHolder* o)
 {
   mhistory->addCommand( KigCommand::addCommand( *this, o ) );
 }
 
-void KigDocument::addObjects( const Objects& os )
+void KigPart::addObjects( const std::vector<ObjectHolder*>& os )
 {
   mhistory->addCommand( KigCommand::addCommand( *this, os ) );
 }
 
-void KigDocument::_addObject( Object* o )
+void KigPart::_addObject( ObjectHolder* o )
 {
-  mobjsref.addParent( o );
+  document().addObject( o );
   setModified(true);
 }
 
-void KigDocument::delObject(Object* o)
+void KigPart::delObject( ObjectHolder* o )
 {
   // we delete all children and their children etc. too...
-  Objects all = o->getAllChildren();
-  all.upush(o);
-  mhistory->addCommand( KigCommand::removeCommand( *this, all ) );
+  std::vector<ObjectHolder*> os;
+  os.push_back( o );
+  delObjects( os );
 }
 
-void KigDocument::_delObjects( const Objects& o )
+void KigPart::_delObjects( const std::vector<ObjectHolder*>& o )
 {
-  for ( Objects::const_iterator i = o.begin(); i != o.end(); ++i )
-  {
-    mobjsref.delParent( *i );
-    (*i)->setSelected( false );
-  };
+  document().delObjects( o );
   setModified( true );
 }
 
-void KigDocument::_delObject(Object* o)
+void KigPart::_delObject(ObjectHolder* o)
 {
-  mobjsref.delParent( o );
-  o->setSelected( false );
+  document().delObject( o );
   setModified(true);
 }
 
-Objects KigDocument::whatAmIOn(const Coordinate& p, const KigWidget& w ) const
-{
-  Objects tmp;
-  Objects nonpoints;
-  const Objects objs = objects();
-  for ( Objects::const_iterator i = objs.begin(); i != objs.end(); ++i )
-  {
-    if(!(*i)->contains(p, w) || !(*i)->shown() || !(*i)->valid()) continue;
-    if ( (*i)->hasimp( PointImp::stype() ) ) tmp.push_back( *i );
-    else nonpoints.push_back( *i );
-  };
-  std::copy( nonpoints.begin(), nonpoints.end(), std::back_inserter( tmp ) );
-  return tmp;
-}
-
-Objects KigDocument::whatIsInHere( const Rect& p, const KigWidget& w )
-{
-  Objects tmp;
-  Objects nonpoints;
-  const Objects objs = objects();
-  for ( Objects::const_iterator i = objs.begin(); i != objs.end(); ++i )
-  {
-    if(! (*i)->inRect( p, w ) || !(*i)->shown() || ! (*i)->valid() ) continue;
-    if ((*i)->hasimp( PointImp::stype() ) ) tmp.push_back( *i );
-    else nonpoints.push_back( *i );
-  };
-  std::copy( nonpoints.begin(), nonpoints.end(), std::back_inserter( tmp ) );
-  return tmp;
-}
-
-Rect KigDocument::suggestedRect() const
-{
-  bool rectInited = false;
-  Rect r(0.,0.,0.,0.);
-  const Objects objs = objects();
-  for (Objects::const_iterator i = objs.begin(); i != objs.end(); ++i )
-  {
-    if ( (*i)->shown() && (*i)->hasimp( PointImp::stype() ) )
-    {
-      if( !rectInited )
-      {
-        r.setCenter( static_cast<const PointImp*>( (*i)->imp() )->coordinate() );
-        rectInited = true;
-      }
-      else
-        r.setContains( static_cast<const PointImp*>( (*i)->imp() )->coordinate() );
-    };
-  };
-
-  if ( ! rectInited )
-    return Rect( -5.5, -5.5, 11., 11. );
-  r.setContains( Coordinate( 0, 0 ) );
-  if (r.width() == 0) r.setWidth( 1 );
-  if (r.height() == 0) r.setHeight( 1 );
-  Coordinate center = r.center();
-  r *= 2;
-  r.setCenter(center);
-  return r;
-}
-
-const CoordinateSystem& KigDocument::coordinateSystem() const
-{
-  assert( mcoordsystem );
-  return *mcoordsystem;
-}
-
-void KigDocument::setMode( KigMode* m )
+void KigPart::setMode( KigMode* m )
 {
   mMode = m;
   m->enableActions();
+  redrawScreen();
 }
 
-void KigDocument::_addObjects( const Objects& os )
+void KigPart::_addObjects( const std::vector<ObjectHolder*>& os )
 {
-  os.calc( *this );
-  mobjsref.addParents( os );
+  document().addObjects( os );
   setModified( true );
 }
 
-void KigDocument::deleteObjects()
+void KigPart::deleteObjects()
 {
   mode()->deleteObjects();
 }
 
-void KigDocument::cancelConstruction()
+void KigPart::cancelConstruction()
 {
   mode()->cancelConstruction();
 }
 
-void KigDocument::showHidden()
+void KigPart::showHidden()
 {
   mode()->showHidden();
 }
 
-void KigDocument::newMacro()
+void KigPart::newMacro()
 {
   mode()->newMacro();
 }
 
-void KigDocument::editTypes()
+void KigPart::editTypes()
 {
   mode()->editTypes();
 }
 
-void KigDocument::setUnmodified()
+void KigPart::setUnmodified()
 {
   setModified( false );
 }
 
-KCommandHistory* KigDocument::history()
+KCommandHistory* KigPart::history()
 {
   return mhistory;
 }
 
-void KigDocument::delObjects( const Objects& os )
+void KigPart::delObjects( const std::vector<ObjectHolder*>& os )
 {
-  Objects tos = os.getAllChildren();
-  tos |= os;
+  if ( os.size() < 1 ) return;
+  std::set<ObjectHolder*> delobjs;
 
-  const Objects objs = objects();
-  Objects dos;
-  for ( Objects::iterator i = tos.begin(); i != tos.end(); ++i )
-    if ( objs.contains( *i ) )
-      dos.upush( *i );
-  if ( dos.empty() ) return;
-  mhistory->addCommand( KigCommand::removeCommand( *this, dos ) );
+  std::set<ObjectCalcer*> delcalcers = getAllChildren( getCalcers( os ) );
+  std::map<ObjectCalcer*, ObjectHolder*> holdermap;
+
+  std::set<ObjectHolder*> curobjs = document().objectsSet();
+
+  for ( std::set<ObjectHolder*>::iterator i = curobjs.begin();
+        i != curobjs.end(); ++i )
+    holdermap[( *i )->calcer()] = *i;
+
+  for ( std::set<ObjectCalcer*>::iterator i = delcalcers.begin();
+        i != delcalcers.end(); ++i )
+  {
+    std::map<ObjectCalcer*, ObjectHolder*>::iterator j = holdermap.find( *i );
+    if ( j != holdermap.end() )
+      delobjs.insert( j->second );
+  }
+
+  assert( delobjs.size() >= os.size() );
+
+  std::vector<ObjectHolder*> delobjsvect( delobjs.begin(), delobjs.end() );
+  mhistory->addCommand( KigCommand::removeCommand( *this, delobjsvect ) );
 }
 
-void KigDocument::enableConstructActions( bool enabled )
+void KigPart::enableConstructActions( bool enabled )
 {
   for_each( aActions.begin(), aActions.end(),
             bind2nd( mem_fun( &KAction::setEnabled ),
                      enabled ) );
 }
 
-void KigDocument::unplugActionLists()
+void KigPart::unplugActionLists()
 {
   unplugActionList( "user_conic_types" );
   unplugActionList( "user_segment_types" );
@@ -568,7 +575,7 @@ void KigDocument::unplugActionLists()
   unplugActionList( "user_types" );
 }
 
-void KigDocument::plugActionLists()
+void KigPart::plugActionLists()
 {
   plugActionList( "user_conic_types", aMNewConic );
   plugActionList( "user_segment_types", aMNewSegment );
@@ -579,22 +586,22 @@ void KigDocument::plugActionLists()
   plugActionList( "user_types", aMNewAll );
 }
 
-void KigDocument::emitStatusBarText( const QString& text )
+void KigPart::emitStatusBarText( const QString& text )
 {
   emit setStatusBarText( text );
 }
 
-void KigDocument::fileSaveAs()
+void KigPart::fileSaveAs()
 {
   internalSaveAs();
 }
 
-void KigDocument::fileSave()
+void KigPart::fileSave()
 {
   save();
 }
 
-bool KigDocument::internalSaveAs()
+bool KigPart::internalSaveAs()
 {
   // this slot is connected to the KStdAction::saveAs action...
   QString formats;
@@ -609,17 +616,17 @@ bool KigDocument::internalSaveAs()
   {
     int ret = KMessageBox::warningYesNo( m_widget,
                                          i18n( "The file \"%1\" already exists. Do you wish to overwrite it?" )
-                                         .arg( file_name ) );
+                                         .arg( file_name ), i18n( "Overwrite File?" ) );
     if ( ret != KMessageBox::Yes )
     {
       return false;
     }
   }
-  saveAs(file_name);
+  saveAs(KURL::fromPathOrURL( file_name ));
   return true;
 }
 
-void KigDocument::runMode( KigMode* m )
+void KigPart::runMode( KigMode* m )
 {
   KigMode* prev = mMode;
 
@@ -632,10 +639,10 @@ void KigDocument::runMode( KigMode* m )
 #endif
 
   setMode( prev );
-  prev->redrawScreen();
+  redrawScreen();
 }
 
-void KigDocument::doneMode( KigMode* d )
+void KigPart::doneMode( KigMode* d )
 {
   assert( d == mMode );
   // pretend to use this var..
@@ -647,27 +654,19 @@ void KigDocument::doneMode( KigMode* d )
 #endif
 }
 
-void KigDocument::setObjects( const Objects& os )
-{
-  assert( objects().empty() );
-  mobjsref.setParents( os );
-}
-
-void KigDocument::setCoordinateSystem( CoordinateSystem* cs )
-{
-  delete mcoordsystem;
-  mcoordsystem = cs;
-}
-
-void KigDocument::actionRemoved( GUIAction* a, GUIUpdateToken& t )
+void KigPart::actionRemoved( GUIAction* a, GUIUpdateToken& t )
 {
   KigGUIAction* rem = 0;
-  for ( myvector<KigGUIAction*>::iterator i = aActions.begin(); i != aActions.end(); ++i )
+  for ( std::vector<KigGUIAction*>::iterator i = aActions.begin(); i != aActions.end(); ++i )
   {
-    if ( (*i)->guiAction() == a ) rem = *i;
+    if ( (*i)->guiAction() == a )
+    {
+      rem = *i;
+      aActions.erase( i );
+      break;
+    }
   };
   assert( rem );
-  aActions.remove( rem );
   aMNewSegment.remove( rem );
   aMNewConic.remove( rem );
   aMNewPoint.remove( rem );
@@ -678,14 +677,14 @@ void KigDocument::actionRemoved( GUIAction* a, GUIUpdateToken& t )
   t.push_back( rem );
 }
 
-void KigDocument::actionAdded( GUIAction* a, GUIUpdateToken& )
+void KigPart::actionAdded( GUIAction* a, GUIUpdateToken& )
 {
   KigGUIAction* ret = new KigGUIAction( a, *this, actionCollection() );
   aActions.push_back( ret );
   ret->plug( this );
 }
 
-void KigDocument::endGUIActionUpdate( GUIUpdateToken& t )
+void KigPart::endGUIActionUpdate( GUIUpdateToken& t )
 {
   unplugActionLists();
   plugActionLists();
@@ -693,12 +692,12 @@ void KigDocument::endGUIActionUpdate( GUIUpdateToken& t )
   t.clear();
 }
 
-KigDocument::GUIUpdateToken KigDocument::startGUIActionUpdate()
+KigPart::GUIUpdateToken KigPart::startGUIActionUpdate()
 {
   return GUIUpdateToken();
 }
 
-void KigDocument::setupMacroTypes()
+void KigPart::setupMacroTypes()
 {
   static bool alreadysetup = false;
   if ( ! alreadysetup )
@@ -709,11 +708,11 @@ void KigDocument::setupMacroTypes()
     QStringList dataFiles =
       KGlobal::dirs()->findAllResources("appdata", "kig-types/*.kigt",
                                         true, false );
-    myvector<Macro*> macros;
+    std::vector<Macro*> macros;
     for ( QStringList::iterator file = dataFiles.begin();
           file != dataFiles.end(); ++file )
     {
-      myvector<Macro*> nmacros;
+      std::vector<Macro*> nmacros;
       bool ok = MacroList::instance()->load( *file, nmacros, *this );
       if ( ! ok ) continue;
       copy( nmacros.begin(), nmacros.end(), back_inserter( macros ) );
@@ -725,7 +724,7 @@ void KigDocument::setupMacroTypes()
   QTimer::singleShot( 0, this, SLOT( plugActionLists() ) );
 }
 
-void KigDocument::setupBuiltinMacros()
+void KigPart::setupBuiltinMacros()
 {
   static bool alreadysetup = false;
   if ( ! alreadysetup )
@@ -738,7 +737,7 @@ void KigDocument::setupBuiltinMacros()
     for ( QStringList::iterator file = builtinfiles.begin();
           file != builtinfiles.end(); ++file )
     {
-      myvector<Macro*> macros;
+      std::vector<Macro*> macros;
       bool ok = MacroList::instance()->load( *file, macros, *this );
       if ( ! ok ) continue;
       for ( uint i = 0; i < macros.size(); ++i )
@@ -757,48 +756,42 @@ void KigDocument::setupBuiltinMacros()
   };
 }
 
-void KigDocument::addWidget( KigWidget* v )
+void KigPart::addWidget( KigWidget* v )
 {
   mwidgets.push_back( v );
 }
 
-void KigDocument::delWidget( KigWidget* v )
+void KigPart::delWidget( KigWidget* v )
 {
-  std::remove( mwidgets.begin(), mwidgets.end(), v );
+  mwidgets.erase( std::remove( mwidgets.begin(), mwidgets.end(), v ), mwidgets.end() );
 }
 
-const std::vector<KigWidget*>& KigDocument::widgets()
-{
-  return mwidgets;
-}
-
-CoordinateSystem* KigDocument::switchCoordinateSystem( CoordinateSystem* s )
-{
-  CoordinateSystem* ret = mcoordsystem;
-  mcoordsystem = s;
-  return ret;
-}
-
-void KigDocument::filePrintPreview()
+void KigPart::filePrintPreview()
 {
   KPrinter printer;
   printer.setPreviewOnly( true );
   doPrint( printer );
 }
 
-void KigDocument::filePrint()
+void KigPart::filePrint()
 {
   KPrinter printer;
+  KigPrintDialogPage* kp = new KigPrintDialogPage();
+  printer.addDialogPage( kp );
+  printer.setFullPage( true );
+  printer.setOption( "kde-kig-showgrid", QString::number( document().grid() ) );
+  printer.setOption( "kde-kig-showaxes", QString::number( document().axes() ) );
+  printer.setPageSelection( KPrinter::ApplicationSide );
   if ( printer.setup( m_widget, i18n("Print Geometry") ) )
   {
     doPrint( printer );
   };
 }
 
-void KigDocument::doPrint( KPrinter& printer )
+void KigPart::doPrint( KPrinter& printer )
 {
   QPaintDeviceMetrics metrics( &printer );
-  Rect rect = suggestedRect();
+  Rect rect = document().suggestedRect();
   QRect qrect( 0, 0, metrics.width(), metrics.height() );
   if ( rect.width() * qrect.height() > rect.height() * qrect.width() )
   {
@@ -817,33 +810,179 @@ void KigDocument::doPrint( KPrinter& printer )
     qrect.setRight( qrect.right() - rest / 2 );
   };
   ScreenInfo si( rect, qrect );
-  KigPainter painter( si, &printer, *this );
+  KigPainter painter( si, &printer, document() );
   painter.setWholeWinOverlay();
-  painter.drawGrid( coordinateSystem() );
-  painter.drawObjects( objects() );
+  bool sg = true;
+  bool sa = true;
+  if ( !printer.previewOnly() )
+  {
+    sg = ( printer.option( "kde-kig-showgrid" ) != "0" );
+    sa = ( printer.option( "kde-kig-showaxes" ) != "0" );
+  }
+  else
+  {
+    sg = document().grid();
+    sg = document().axes();
+  }
+  painter.drawGrid( document().coordinateSystem(), sg, sa );
+  painter.drawObjects( document().objects(), false );
 }
 
-const Objects KigDocument::objects() const
-{
-  return mobjsref.parents();
-}
-
-const Objects KigDocument::allObjects() const
-{
-  return getAllParents( objects() );
-}
-
-void KigDocument::slotSelectAll()
+void KigPart::slotSelectAll()
 {
   mMode->selectAll();
 }
 
-void KigDocument::slotDeselectAll()
+void KigPart::slotDeselectAll()
 {
   mMode->deselectAll();
 }
 
-void KigDocument::slotInvertSelection()
+void KigPart::slotInvertSelection()
 {
   mMode->invertSelection();
 }
+
+void KigPart::hideObjects( const std::vector<ObjectHolder*>& inos )
+{
+  std::vector<ObjectHolder*> os;
+  for (std::vector<ObjectHolder*>::const_iterator i = inos.begin(); i != inos.end(); ++i )
+  {
+    if ( (*i)->shown() )
+      os.push_back( *i );
+  };
+  KigCommand* kc = 0;
+  if ( os.size() == 0 ) return;
+  else if ( os.size() == 1 )
+    kc = new KigCommand( *this, os[0]->imp()->type()->hideAStatement() );
+  else kc = new KigCommand( *this, i18n( "Hide %n Object", "Hide %n Objects", os.size() ) );
+  for ( std::vector<ObjectHolder*>::iterator i = os.begin();
+        i != os.end(); ++i )
+    kc->addTask( new ChangeObjectDrawerTask( *i, ( *i )->drawer()->getCopyShown( false ) ) );
+  mhistory->addCommand( kc );
+}
+
+void KigPart::showObjects( const std::vector<ObjectHolder*>& inos )
+{
+  std::vector<ObjectHolder*> os;
+  for (std::vector<ObjectHolder*>::const_iterator i = inos.begin(); i != inos.end(); ++i )
+  {
+    if ( !(*i)->shown() )
+      os.push_back( *i );
+  };
+  KigCommand* kc = 0;
+  if ( os.size() == 0 ) return;
+  else if ( os.size() == 1 )
+    kc = new KigCommand( *this, os[0]->imp()->type()->showAStatement() );
+  else kc = new KigCommand( *this, i18n( "Show %n Object", "Show %n Objects", os.size() ) );
+  for ( std::vector<ObjectHolder*>::iterator i = os.begin();
+        i != os.end(); ++i )
+    kc->addTask( new ChangeObjectDrawerTask( *i, ( *i )->drawer()->getCopyShown( true ) ) );
+  mhistory->addCommand( kc );
+}
+
+void KigPart::redrawScreen( KigWidget* w )
+{
+  mode()->redrawScreen( w );
+}
+
+void KigPart::redrawScreen()
+{
+  for ( std::vector<KigWidget*>::iterator i = mwidgets.begin();
+        i != mwidgets.end(); ++i )
+  {
+    mode()->redrawScreen( *i );
+  }
+}
+
+const KigDocument& KigPart::document() const
+{
+  return *mdocument;
+}
+
+KigDocument& KigPart::document()
+{
+  return *mdocument;
+}
+
+extern "C" int convertToNative( const KURL& url, const QCString& outfile )
+{
+  kdDebug() << "converting " << url.prettyURL() << " to " << outfile << endl;
+
+  if ( ! url.isLocalFile() )
+  {
+    // TODO
+    kdError() << "--convert-to-native only supports local files for now." << endl;
+    return -1;
+  }
+
+  QString file = url.path();
+
+  QFileInfo fileinfo( file );
+  if ( ! fileinfo.exists() )
+  {
+    kdError() << "The file \"" << file << "\" does not exist" << endl;
+    return -1;
+  };
+
+  KMimeType::Ptr mimeType = KMimeType::findByPath ( file );
+  kdDebug() << k_funcinfo << "mimetype: " << mimeType->name() << endl;
+  KigFilter* filter = KigFilters::instance()->find( mimeType->name() );
+  if ( !filter )
+  {
+    kdError() << "The file \"" << file << "\" is of a filetype not currently supported by Kig." << endl;
+    return -1;
+  };
+
+  KigDocument* doc = filter->load (file);
+  if ( !doc )
+  {
+    kdError() << "Parse error in file \"" << file << "\"." << endl;
+    return -1;
+  }
+
+  std::vector<ObjectCalcer*> tmp = calcPath( getAllParents( getCalcers( doc->objects() ) ) );
+  for ( std::vector<ObjectCalcer*>::iterator i = tmp.begin(); i != tmp.end(); ++i )
+    ( *i )->calc( *doc );
+  for ( std::vector<ObjectCalcer*>::iterator i = tmp.begin(); i != tmp.end(); ++i )
+    ( *i )->calc( *doc );
+
+  bool success = true;
+  QTextStream stdoutstream( stdout, IO_WriteOnly );
+  if ( outfile == "-" )
+    success = KigFilters::instance()->save( *doc, stdoutstream );
+  else
+    success = KigFilters::instance()->save( *doc, outfile );
+  if ( !success )
+  {
+    kdError() << "something went wrong while saving" << endl;
+    return -1;
+  }
+
+  delete doc;
+
+  return 0;
+};
+
+void KigPart::toggleGrid()
+{
+  bool toshow = !mdocument->grid();
+  aToggleGrid->setChecked( toshow );
+  mdocument->setGrid( toshow );
+
+  redrawScreen();
+}
+
+void KigPart::toggleAxes()
+{
+  bool toshow = !mdocument->axes();
+  aToggleAxes->setChecked( toshow );
+  mdocument->setAxes( toshow );
+
+  redrawScreen();
+}
+
+void KigPart::coordSystemChanged( int id )
+{
+  aCoordSystem->setCurrentItem( id );
+}
