@@ -172,7 +172,8 @@ const ConicCartesianData calcConicThroughPoints (
   const LinearConstraints c4,
   const LinearConstraints c5 )
 {
-  // points is a vector of at least 5 points through which the conic is
+  assert( 0 < points.size() && points.size() <= 5 );
+  // points is a vector of up to 5 points through which the conic is
   // constrained.
   // this routine should compute the coefficients in the cartesian equation
   //    a x^2 + b y^2 + c xy + d x + e y + f = 0
@@ -321,8 +322,7 @@ const LineData calcConicPolarLine (
 
 const Coordinate calcConicPolarPoint (
   const ConicCartesianData& data,
-  const LineData& polar,
-  bool& valid )
+  const LineData& polar )
 {
   Coordinate p1 = polar.a;
   Coordinate p2 = polar.b;
@@ -354,10 +354,8 @@ const Coordinate calcConicPolarPoint (
 
   if (fabs(z) < 1e-10)          // point at infinity
   {
-    valid = false;
-    return Coordinate (0,0);
+    return Coordinate::invalidCoord();
   }
-  valid = true;
 
   x /= z;
   y /= z;
@@ -366,9 +364,10 @@ const Coordinate calcConicPolarPoint (
 
 const Coordinate calcConicLineIntersect( const ConicCartesianData& c,
                                          const LineData& l,
-                                         int which, bool& valid )
+					 double knownparam,
+                                         int which )
 {
-  assert( which == 1 || which == -1 );
+  assert( which == 1 || which == -1 || which == 0 );
 
   double aa = c.coeffs[0];
   double bb = c.coeffs[1];
@@ -386,16 +385,20 @@ const Coordinate calcConicLineIntersect( const ConicCartesianData& c,
   double bbb = 2*aa*x*dx + 2*bb*y*dy + cc*x*dy + cc*y*dx + dd*dx + ee*dy;
   double ccc = aa*x*x + bb*y*y + cc*x*y + dd*x + ee*y + ff;
 
+  double t;
+  if ( which == 0 )  /* i.e. we have a known intersection */
+  {
+    t = - bbb/aaa - knownparam;
+    return l.a + t*(l.b - l.a);
+  }
+
   double discrim = bbb*bbb - 4*aaa*ccc;
   if (discrim < 0.0)
   {
-    valid = false;
-    return Coordinate();
+    return Coordinate::invalidCoord();
   }
   else
   {
-    valid = true;
-    double t;
     if ( which*bbb > 0 )
     {
       t = bbb + which*sqrt(discrim);
