@@ -18,7 +18,7 @@
 
 #include "object_hierarchy.h"
 
-#include "../objects/object.h"
+#include "../objects/object_holder.h"
 #include "../objects/other_type.h"
 #include "../objects/object_imp.h"
 #include "../objects/object_imp_factory.h"
@@ -42,7 +42,21 @@ public:
   virtual void apply( std::vector<const ObjectImp*>& stack, int loc,
                       const KigDocument& ) const = 0;
 
-  virtual void apply( Objects& stack, int loc ) const = 0;
+  virtual void apply( std::vector<ObjectCalcer*>& stack, int loc ) const = 0;
+
+  // this function is used to check whether the final objects depend
+  // on the given objects.  The dependsstack contains a set of
+  // booleans telling which parts of the hierarchy certainly depend on
+  // the given objects.  In this function, the node should check
+  // whether any of its parents have true set, and if so, set its own
+  // value to true.
+  virtual void checkDependsOnGiven( std::vector<bool>& dependsstack, int loc ) const = 0;
+  // this function is used to check whether the given objects are all
+  // used by one or more of the final objects.  The usedstack contains
+  // a set of booleans telling which parts of the hierarchy are
+  // certainly ancestors of the final objects.  In this function, the
+  // node should set all of its parents' booleans to true.
+  virtual void checkArgumentsUsed( std::vector<bool>& usedstack ) const = 0;
 };
 
 ObjectHierarchy::Node::~Node()
@@ -63,12 +77,24 @@ public:
   Node* copy() const;
   void apply( std::vector<const ObjectImp*>& stack,
               int loc, const KigDocument& ) const;
-  void apply( Objects& stack, int loc ) const;
+  void apply( std::vector<ObjectCalcer*>& stack, int loc ) const;
+
+  void checkDependsOnGiven( std::vector<bool>& dependsstack, int loc ) const;
+  void checkArgumentsUsed( std::vector<bool>& usedstack ) const;
 };
 
-void PushStackNode::apply( Objects& stack, int loc ) const
+void PushStackNode::checkArgumentsUsed( std::vector<bool>& ) const
 {
-  stack[loc] = new DataObject( mimp->copy() );
+}
+
+void PushStackNode::apply( std::vector<ObjectCalcer*>& stack, int loc ) const
+{
+  stack[loc] = new ObjectConstCalcer( mimp->copy() );
+}
+
+void PushStackNode::checkDependsOnGiven( std::vector<bool>&, int ) const {
+  // pushstacknode depends on nothing..
+  return;
 }
 
 int PushStackNode::id() const { return ID_PushStack; }
@@ -106,11 +132,30 @@ public:
   int id() const;
   void apply( std::vector<const ObjectImp*>& stack,
               int loc, const KigDocument& ) const;
-  void apply( Objects& stack, int loc ) const;
+  void apply( std::vector<ObjectCalcer*>& stack, int loc ) const;
+
+  void checkDependsOnGiven( std::vector<bool>& dependsstack, int loc ) const;
+  void checkArgumentsUsed( std::vector<bool>& usedstack ) const;
 };
 
 int ApplyTypeNode::id() const { return ID_ApplyType; }
 
+void ApplyTypeNode::checkArgumentsUsed( std::vector<bool>& usedstack ) const
+{
+  for ( uint i = 0; i < mparents.size(); ++i )
+  {
+    usedstack[mparents[i]] = true;
+  }
+}
+
+void ApplyTypeNode::checkDependsOnGiven( std::vector<bool>& dependsstack, int loc ) const
+{
+  bool result = false;
+  for ( uint i = 0; i < mparents.size(); ++i )
+    if ( dependsstack[mparents[i]] == true ) result = true;
+  dependsstack[loc] = result;
+}
+
 ApplyTypeNode::~ApplyTypeNode()
 {
 }
@@ -120,12 +165,12 @@ ObjectHierarchy::Node* ApplyTypeNode::copy() const
   return new ApplyTypeNode( mtype, mparents );
 }
 
-void ApplyTypeNode::apply( Objects& stack, int loc ) const
+void ApplyTypeNode::apply( std::vector<ObjectCalcer*>& stack, int loc ) const
 {
-  Objects parents;
+  std::vector<ObjectCalcer*> parents;
   for ( uint i = 0; i < mparents.size(); ++i )
     parents.push_back( stack[ mparents[i] ] );
-  stack[loc] = new RealObject( mtype, parents );
+  stack[loc] = new ObjectTypeCalcer( mtype, parents );
 }
 
 void ApplyTypeNode::apply( std::vector<const ObjectImp*>& stack,
@@ -133,9 +178,8 @@ void ApplyTypeNode::apply( std::vector<const ObjectImp*>& stack,
 {
   Args args;
   for ( uint i = 0; i < mparents.size(); ++i )
-  {
     args.push_back( stack[mparents[i]] );
-  };
+  args = mtype->sortArgs( args );
   stack[loc] = mtype->calc( args, doc );
 }
 
@@ -155,19 +199,31 @@ public:
   ~FetchPropertyNode();
   Node* copy() const;
 
+  void checkDependsOnGiven( std::vector<bool>& dependsstack, int loc ) const;
+  void checkArgumentsUsed( std::vector<bool>& usedstack ) const;
   int parent() const { return mparent; };
   const QCString& propinternalname() const { return mname; };
 
   int id() const;
   void apply( std::vector<const ObjectImp*>& stack,
               int loc, const KigDocument& ) const;
-  void apply( Objects& stack, int loc ) const;
+  void apply( std::vector<ObjectCalcer*>& stack, int loc ) const;
 };
 
 FetchPropertyNode::~FetchPropertyNode()
 {
 }
 
+void FetchPropertyNode::checkArgumentsUsed( std::vector<bool>& usedstack ) const
+{
+  usedstack[mparent] = true;
+}
+
+void FetchPropertyNode::checkDependsOnGiven( std::vector<bool>& dependsstack, int loc ) const
+{
+  dependsstack[loc] = dependsstack[mparent];
+}
+
 ObjectHierarchy::Node* FetchPropertyNode::copy() const
 {
   return new FetchPropertyNode( mparent, mname, mpropid );
@@ -189,11 +245,12 @@ void FetchPropertyNode::apply( std::vector<const ObjectImp*>& stack,
     stack[loc] = new InvalidImp();
 }
 
-void FetchPropertyNode::apply( Objects& stack, int loc ) const
+void FetchPropertyNode::apply( std::vector<ObjectCalcer*>& stack, int loc ) const
 {
-  if ( mpropid == -1 ) mpropid = stack[mparent]->propertiesInternalNames().findIndex( mname );
+  if ( mpropid == -1 )
+    mpropid = stack[mparent]->imp()->propertiesInternalNames().findIndex( mname );
   assert( mpropid != -1 );
-  stack[loc] = new PropertyObject( stack[mparent], mpropid );
+  stack[loc] = new ObjectPropertyCalcer( stack[mparent], mpropid );
 }
 
 std::vector<ObjectImp*> ObjectHierarchy::calc( const Args& a, const KigDocument& doc ) const
@@ -226,17 +283,17 @@ std::vector<ObjectImp*> ObjectHierarchy::calc( const Args& a, const KigDocument&
   };
 }
 
-int ObjectHierarchy::visit( const Object* o, std::map<const Object*, int>& seenmap,
-                            bool isresult )
+int ObjectHierarchy::visit( const ObjectCalcer* o, std::map<const ObjectCalcer*, int>& seenmap,
+                            bool needed, bool neededatend )
 {
   using namespace std;
 
-  std::map<const Object*, int>::iterator smi = seenmap.find( o );
+  std::map<const ObjectCalcer*, int>::iterator smi = seenmap.find( o );
   if ( smi != seenmap.end() )
   {
-    if ( isresult )
+    if ( neededatend )
     {
-      // isresult means that this object is one of the resultant
+      // neededatend means that this object is one of the resultant
       // objects.  Therefore, its node has to appear at the end,
       // because that's where we expect it..  We therefore copy it
       // there using CopyObjectType..
@@ -249,27 +306,31 @@ int ObjectHierarchy::visit( const Object* o, std::map<const Object*, int>& seenm
     else return smi->second;
   }
 
-  Objects p( o->parents() );
+  std::vector<ObjectCalcer*> p( o->parents() );
   // we check if o descends from the given objects..
   bool descendsfromgiven = false;
   std::vector<int> parents;
   parents.resize( p.size(), -1 );
   for ( uint i = 0; i < p.size(); ++i )
   {
-    int v = visit( p[i], seenmap );
+    int v = visit( p[i], seenmap, false );
     parents[i] = v;
     descendsfromgiven |= (v != -1);
   };
 
-  if ( ! descendsfromgiven )
+  if ( ! descendsfromgiven && ! ( needed && o->imp()->isCache() ) )
   {
-    if ( isresult )
+    if ( needed )
     {
       assert( ! o->imp()->isCache() );
-      // o is a result object that does not descend from the given
-      // objects..  We have to just save its value here, I guess..
-      mnodes.push_back( new PushStackNode( o->imp()->copy() ) );
-      return mnodes.size() + mnumberofargs - 1;
+      // o is an object that does not depend on the given objects, but
+      // is needed by other objects, so we just have to just save its
+      // current value here.
+      Node* node = new PushStackNode( o->imp()->copy() );
+      mnodes.push_back( node );
+      int ret = mnodes.size() + mnumberofargs - 1;
+      seenmap[o] = ret;
+      return ret;
     }
     else
       return -1;
@@ -285,7 +346,8 @@ ObjectHierarchy::~ObjectHierarchy()
 
 ObjectHierarchy::ObjectHierarchy( const ObjectHierarchy& h )
   : mnumberofargs( h.mnumberofargs ), mnumberofresults( h.mnumberofresults ),
-    margrequirements( h.margrequirements )
+    margrequirements( h.margrequirements ), musetexts( h.musetexts ),
+    mselectstatements( h.mselectstatements )
 {
   mnodes.reserve( h.mnodes.size() );
   for ( uint i = 0; i < h.mnodes.size(); ++i )
@@ -313,36 +375,38 @@ ObjectHierarchy ObjectHierarchy::withFixedArgs( const Args& a ) const
   return ret;
 }
 
-ObjectHierarchy::ObjectHierarchy( const Objects& from, const Object* to )
-  : mnumberofargs( from.size() ), mnumberofresults( 1 )
+void ObjectHierarchy::init( const std::vector<ObjectCalcer*>& from, const std::vector<ObjectCalcer*>& to )
 {
+  mnumberofargs = from.size();
+  mnumberofresults = to.size();
   margrequirements.resize( from.size(), ObjectImp::stype() );
-  std::map<const Object*, int> seenmap;
+  musetexts.resize( margrequirements.size(), "" );
+  std::map<const ObjectCalcer*, int> seenmap;
   for ( uint i = 0; i < from.size(); ++i )
     seenmap[from[i]] = i;
-  Objects parents = to->parents();
-  for ( Objects::const_iterator i = parents.begin();
-        i != parents.end(); ++i )
-    visit( *i, seenmap );
-  visit( to, seenmap, true );
+  for ( std::vector<ObjectCalcer*>::const_iterator i = to.begin(); i != to.end(); ++i )
+  {
+    std::vector<ObjectCalcer*> parents = (*i)->parents();
+    for ( std::vector<ObjectCalcer*>::const_iterator j = parents.begin();
+          j != parents.end(); ++j )
+      visit( *j, seenmap, true );
+  }
+  for ( std::vector<ObjectCalcer*>::const_iterator i = to.begin(); i != to.end(); ++i )
+    visit( *i, seenmap, true, true );
+
+  mselectstatements.resize( margrequirements.size(), "" );
 }
 
-ObjectHierarchy::ObjectHierarchy( const Objects& from, const Objects& to )
-  : mnumberofargs( from.size() ), mnumberofresults( to.size() )
+ObjectHierarchy::ObjectHierarchy( const std::vector<ObjectCalcer*>& from, const ObjectCalcer* to )
 {
-  margrequirements.resize( from.size(), ObjectImp::stype() );
-  std::map<const Object*, int> seenmap;
-  for ( uint i = 0; i < from.size(); ++i )
-    seenmap[from[i]] = i;
-  for ( Objects::const_iterator i = to.begin(); i != to.end(); ++i )
-  {
-    Objects parents = (*i)->parents();
-    for ( Objects::const_iterator j = parents.begin();
-          j != parents.end(); ++j )
-      visit( *j, seenmap );
-  }
-  for ( Objects::const_iterator i = to.begin(); i != to.end(); ++i )
-    visit( *i, seenmap, true );
+  std::vector<ObjectCalcer*> tov;
+  tov.push_back( const_cast<ObjectCalcer*>( to ) );
+  init( from, tov );
+}
+
+ObjectHierarchy::ObjectHierarchy( const std::vector<ObjectCalcer*>& from, const std::vector<ObjectCalcer*>& to )
+{
+  init( from, to );
 }
 
 void ObjectHierarchy::serialize( QDomElement& parent, QDomDocument& doc ) const
@@ -353,6 +417,14 @@ void ObjectHierarchy::serialize( QDomElement& parent, QDomDocument& doc ) const
     QDomElement e = doc.createElement( "input" );
     e.setAttribute( "id", id++ );
     e.setAttribute( "requirement", margrequirements[i]->internalName() );
+    // we don't save these atm, since the user can't define them.
+    // we only load them from builtin macro's.
+//     QDomElement ut = doc.createElement( "UseText" );
+//     ut.appendChild( doc.createTextNode( QString::fromLatin1(musetexts[i].c_str() ) ) );
+//     e.appendChild( ut );
+//     QDomElement ss = doc.createElement( "SelectStatement" );
+//     ss.appendChild( doc.createTextNode( QString::fromLatin1(mselectstatements[i].c_str() ) ) );
+//     e.appendChild( ss );
     parent.appendChild( e );
   }
 
@@ -417,7 +489,26 @@ ObjectHierarchy::ObjectHierarchy( const QDomElement& parent )
     const ObjectImpType* req = ObjectImpType::typeFromInternalName( tmp.latin1() );
     if ( req == 0 ) req = ObjectImp::stype(); // sucks, i know..
     margrequirements.resize( mnumberofargs, ObjectImp::stype() );
+    musetexts.resize( mnumberofargs, "" );
+    mselectstatements.resize( mnumberofargs, "" );
     margrequirements[id - 1] = req;
+    musetexts[id - 1] = req->selectStatement();
+    QDomElement esub = e.firstChild().toElement();
+    for ( ; !esub.isNull(); esub = esub.nextSibling().toElement() )
+    {
+      if ( esub.tagName() == "UseText" )
+      {
+        musetexts[id - 1] = esub.text().latin1();
+      }
+      else if ( esub.tagName() == "SelectStatement" )
+      {
+        mselectstatements[id - 1] = esub.text().latin1();
+      }
+      else
+      {
+        // broken file ? ignore...
+      }
+    }
   }
   for (; !e.isNull(); e = e.nextSibling().toElement() )
   {
@@ -489,20 +580,20 @@ ArgsParser ObjectHierarchy::argParser() const
     const ObjectImpType* req = margrequirements[i];
     ArgsParser::spec spec;
     spec.type = req;
-    spec.usetext = req->selectStatement();
-    assert( spec.usetext );
+    spec.usetext = musetexts[i];
+    spec.selectstat = mselectstatements[i];
     specs.push_back( spec );
   };
   return ArgsParser( specs );
 }
 
-Objects ObjectHierarchy::buildObjects( const Objects& os, const KigDocument& doc ) const
+std::vector<ObjectCalcer*> ObjectHierarchy::buildObjects( const std::vector<ObjectCalcer*>& os, const KigDocument& doc ) const
 {
   assert( os.size() == mnumberofargs );
   for ( uint i = 0; i < os.size(); ++i )
-    assert( os[i]->hasimp( margrequirements[i] ) );
+    assert( os[i]->imp()->inherits( margrequirements[i] ) );
 
-  Objects stack;
+  std::vector<ObjectCalcer*> stack;
   stack.resize( mnodes.size() + mnumberofargs, 0 );
   std::copy( os.begin(), os.end(), stack.begin() );
 
@@ -512,10 +603,7 @@ Objects ObjectHierarchy::buildObjects( const Objects& os, const KigDocument& doc
     stack[mnumberofargs + i]->calc( doc );
   };
 
-  for ( uint i = mnumberofargs; i < stack.size() - mnumberofresults; ++i )
-    stack[i]->setShown( false );
-
-  Objects ret( stack.end() - mnumberofresults, stack.end() );
+  std::vector<ObjectCalcer*> ret( stack.end() - mnumberofresults, stack.end() );
 
   return ret;
 }
@@ -565,11 +653,15 @@ bool operator==( const ObjectHierarchy& lhs, const ObjectHierarchy& rhs )
 
 bool ObjectHierarchy::resultDoesNotDependOnGiven() const
 {
-  for ( uint i = mnodes.size() - mnumberofresults; i < mnodes.size(); ++i )
-  {
-    if ( mnodes[i]->id() == Node::ID_PushStack )
+  std::vector<bool> dependsstack( mnodes.size() + mnumberofargs, false );
+
+  for ( uint i = 0; i < mnumberofargs; ++i )
+    dependsstack[i] = true;
+  for ( uint i = 0; i < mnodes.size(); ++i )
+    mnodes[i]->checkDependsOnGiven( dependsstack, i + mnumberofargs );
+  for ( uint i = dependsstack.size() - mnumberofresults; i < dependsstack.size(); ++i )
+    if ( !dependsstack[i] )
       return true;
-  };
   return false;
 }
 
@@ -593,8 +685,8 @@ const ObjectImpType* lowermost( const ObjectImpType* a, const ObjectImpType* b )
 // the location of objects that are already in mnodes and -1
 // otherwise..  -1 means we have to store their ObjectImp, unless
 // they're cache ObjectImp's etc.
-int ObjectHierarchy::storeObject( const Object* o, const Objects& po, std::vector<int>& pl,
-                                  std::map<const Object*, int>& seenmap )
+int ObjectHierarchy::storeObject( const ObjectCalcer* o, const std::vector<ObjectCalcer*>& po, std::vector<int>& pl,
+                                  std::map<const ObjectCalcer*, int>& seenmap )
 {
   for ( uint i = 0; i < po.size(); ++i )
   {
@@ -603,40 +695,65 @@ int ObjectHierarchy::storeObject( const Object* o, const Objects& po, std::vecto
       // we can't store cache ObjectImp's..
       if ( po[i]->imp()->isCache() )
       {
-        Objects parentos = po[i]->parents();
-        std::vector<int> parentlocs( parentos.size(), -1 );
-        pl[i] = storeObject( po[i], parentos, parentlocs, seenmap );
+        pl[i] = visit( po[i], seenmap, true, false );
       }
       else
       {
-        mnodes.push_back( new PushStackNode( po[i]->imp()->copy() ) );
-        pl[i] = mnumberofargs + mnodes.size() - 1;
+        Node* argnode = new PushStackNode( po[i]->imp()->copy() );
+        mnodes.push_back( argnode );
+        int argloc = mnumberofargs + mnodes.size() - 1;
+        seenmap[po[i]] = argloc;
+        pl[i] = argloc;
       };
     }
     else if ( (uint) pl[i] < mnumberofargs )
     {
-      Object* parent = o->parents()[i];
-      Objects opl = o->parents();
+      ObjectCalcer* parent = o->parents()[i];
+      std::vector<ObjectCalcer*> opl = o->parents();
 
       margrequirements[pl[i]] =
         lowermost( margrequirements[pl[i]],
                    o->impRequirement( parent, opl ) );
+      musetexts[pl[i]] = margrequirements[pl[i]]->selectStatement();
     };
   };
-  if ( o->inherits( Object::ID_RealObject ) )
-    mnodes.push_back( new ApplyTypeNode( static_cast<const RealObject*>( o )->type(), pl ) );
-  else if ( o->inherits( Object::ID_PropertyObject ) )
+  if ( dynamic_cast<const ObjectTypeCalcer*>( o ) )
+    mnodes.push_back( new ApplyTypeNode( static_cast<const ObjectTypeCalcer*>( o )->type(), pl ) );
+  else if ( dynamic_cast<const ObjectPropertyCalcer*>( o ) )
   {
     assert( pl.size() == 1 );
     int parent = pl.front();
-    Object* op = po.front();
+    ObjectCalcer* op = po.front();
     assert( op );
-    uint propid = static_cast<const PropertyObject*>( o )->propId();
-    assert( propid < op->propertiesInternalNames().size() );
-    mnodes.push_back( new FetchPropertyNode( parent, op->propertiesInternalNames()[propid], propid ) );
+    uint propid = static_cast<const ObjectPropertyCalcer*>( o )->propId();
+    assert( propid < op->imp()->propertiesInternalNames().size() );
+    mnodes.push_back( new FetchPropertyNode( parent, op->imp()->propertiesInternalNames()[propid], propid ) );
   }
   else
     assert( false );
   seenmap[o] = mnumberofargs + mnodes.size() - 1;
   return mnumberofargs + mnodes.size() - 1;
 }
+
+ObjectHierarchy::ObjectHierarchy( const ObjectCalcer* from, const ObjectCalcer* to )
+{
+  std::vector<ObjectCalcer*> fromv;
+  fromv.push_back( const_cast<ObjectCalcer*>( from ) );
+  std::vector<ObjectCalcer*> tov;
+  tov.push_back( const_cast<ObjectCalcer*>( to ) );
+  init( fromv, tov );
+}
+
+bool ObjectHierarchy::allGivenObjectsUsed() const
+{
+  std::vector<bool> usedstack( mnodes.size() + mnumberofargs, false );
+  for ( uint i = mnodes.size() - mnumberofresults; i < mnodes.size(); ++i )
+    usedstack[i + mnumberofargs] = true;
+  for ( int i = mnodes.size() - 1; i >= 0; --i )
+    if ( usedstack[i + mnumberofargs] )
+      mnodes[i]->checkArgumentsUsed( usedstack );
+  for ( uint i = 0; i < mnumberofargs; ++i )
+    if ( ! usedstack[i] ) return false;
+  return true;
+}
+
