@@ -23,8 +23,11 @@
 #include "point_imp.h"
 #include "circle_imp.h"
 #include "line_imp.h"
+#include "object_calcer.h"
 #include "../misc/conic-common.h"
 #include "../misc/common.h"
+#include "../kig/kig_commands.h"
+#include "../kig/kig_part.h"
 
 #include <klocale.h>
 
@@ -32,13 +35,20 @@ static const char constructstatement[] = I18N_NOOP( "Construct a conic through t
 
 static const struct ArgsParser::spec argsspecConicB5P[] =
 {
-  { PointImp::stype(), constructstatement },
-  { PointImp::stype(), constructstatement },
-  { PointImp::stype(), constructstatement },
-  { PointImp::stype(), constructstatement },
-  { PointImp::stype(), constructstatement }
+  { PointImp::stype(), constructstatement,
+    I18N_NOOP( "Select a point for the new conic to go through..." ), true },
+  { PointImp::stype(), constructstatement,
+    I18N_NOOP( "Select a point for the new conic to go through..." ), true },
+  { PointImp::stype(), constructstatement,
+    I18N_NOOP( "Select a point for the new conic to go through..." ), true },
+  { PointImp::stype(), constructstatement,
+    I18N_NOOP( "Select a point for the new conic to go through..." ), true },
+  { PointImp::stype(), constructstatement,
+    I18N_NOOP( "Select a point for the new conic to go through..." ),true }
 };
 
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( ConicB5PType )
+
 ConicB5PType::ConicB5PType()
   : ArgsParserObjectType( "ConicB5P", argsspecConicB5P, 5 )
 {
@@ -71,11 +81,16 @@ const ConicB5PType* ConicB5PType::instance()
 
 static const ArgsParser::spec argsspecConicBAAP[] =
 {
-  { AbstractLineImp::stype(), I18N_NOOP( "Construct a conic with this asymptote" ) },
-  { AbstractLineImp::stype(), I18N_NOOP( "Construct a conic with this asymptote" ) },
-  { PointImp::stype(), I18N_NOOP( "Construct a conic through this point" ) }
+  { AbstractLineImp::stype(), I18N_NOOP( "Construct a conic with this asymptote" ),
+    I18N_NOOP( "Select the first asymptote of the new conic..." ), false },
+  { AbstractLineImp::stype(), I18N_NOOP( "Construct a conic with this asymptote" ),
+    I18N_NOOP( "Select the second asymptote of the new conic..." ), false },
+  { PointImp::stype(), I18N_NOOP( "Construct a conic through this point" ),
+    I18N_NOOP( "Select a point for the new conic to go through..." ), true }
 };
 
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( ConicBAAPType )
+
 ConicBAAPType::ConicBAAPType()
   : ArgsParserObjectType( "ConicBAAP", argsspecConicBAAP, 3 )
 {
@@ -127,11 +142,16 @@ static const char constructellipsewithfocusstat[] =
 
 static const ArgsParser::spec argsspecEllipseBFFP[] =
 {
-  { PointImp::stype(), constructellipsewithfocusstat },
-  { PointImp::stype(), constructellipsewithfocusstat },
-  { PointImp::stype(), I18N_NOOP( "Construct an ellipse through this point" ) }
+  { PointImp::stype(), constructellipsewithfocusstat,
+    I18N_NOOP( "Select the first focus of the new ellipse..." ), false },
+  { PointImp::stype(), constructellipsewithfocusstat,
+    I18N_NOOP( "Select the second focus of the new ellipse..." ), false },
+  { PointImp::stype(), I18N_NOOP( "Construct an ellipse through this point" ),
+    I18N_NOOP( "Select a point for the new ellipse to go through..." ), true }
 };
 
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( EllipseBFFPType )
+
 EllipseBFFPType::EllipseBFFPType()
   : ConicBFFPType( "EllipseBFFP", argsspecEllipseBFFP, 3 )
 {
@@ -157,11 +177,16 @@ static const char constructhyperbolawithfocusstat[] =
 
 static const ArgsParser::spec argsspecHyperbolaBFFP[] =
 {
-  { PointImp::stype(), constructhyperbolawithfocusstat },
-  { PointImp::stype(), constructhyperbolawithfocusstat },
-  { PointImp::stype(), I18N_NOOP( "Construct a hyperbola through this point" ) }
+  { PointImp::stype(), constructhyperbolawithfocusstat,
+    I18N_NOOP( "Select the first focus of the new hyperbola..." ), false },
+  { PointImp::stype(), constructhyperbolawithfocusstat,
+    I18N_NOOP( "Select the second focus of the new hyperbola..." ), false },
+  { PointImp::stype(), I18N_NOOP( "Construct a hyperbola through this point" ),
+    I18N_NOOP( "Select a point for the new hyperbola to go through..." ), true }
 };
 
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( HyperbolaBFFPType )
+
 HyperbolaBFFPType::HyperbolaBFFPType()
   : ConicBFFPType( "HyperbolaBFFP", argsspecHyperbolaBFFP, 3 )
 {
@@ -190,11 +215,16 @@ const ConicBDFPType* ConicBDFPType::instance()
 
 static const struct ArgsParser::spec argsspecConicBDFP[] =
 {
-  { AbstractLineImp::stype(), I18N_NOOP( "Construct a conic with this line as directrix" ) },
-  { PointImp::stype(), I18N_NOOP( "Construct a conic with this point as focus" ) },
-  { PointImp::stype(), I18N_NOOP( "Construct a conic through this point" ) }
+  { AbstractLineImp::stype(), I18N_NOOP( "Construct a conic with this line as directrix" ),
+    I18N_NOOP( "Select the directrix of the new conic..." ), false },
+  { PointImp::stype(), I18N_NOOP( "Construct a conic with this point as focus" ),
+    I18N_NOOP( "Select the focus of the new conic..." ), false },
+  { PointImp::stype(), I18N_NOOP( "Construct a conic through this point" ),
+    I18N_NOOP( "Select a point for the new conic to go through..." ), true }
 };
 
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( ConicBDFPType )
+
 ConicBDFPType::ConicBDFPType()
   : ArgsParserObjectType( "ConicBDFP", argsspecConicBDFP, 3 )
 {
@@ -232,11 +262,16 @@ static const char constructparabolathroughpointstat[] =
 
 static const ArgsParser::spec argsspecParabolaBTP[] =
 {
-  { PointImp::stype(), constructparabolathroughpointstat },
-  { PointImp::stype(), constructparabolathroughpointstat },
-  { PointImp::stype(), constructparabolathroughpointstat }
+  { PointImp::stype(), constructparabolathroughpointstat,
+    I18N_NOOP( "Select a point for the new parabola to go through..." ), true },
+  { PointImp::stype(), constructparabolathroughpointstat,
+    I18N_NOOP( "Select a point for the new parabola to go through..." ), true },
+  { PointImp::stype(), constructparabolathroughpointstat,
+    I18N_NOOP( "Select a point for the new parabola to go through..." ), true }
 };
 
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( ParabolaBTPType )
+
 ParabolaBTPType::ParabolaBTPType()
   : ArgsParserObjectType( "ParabolaBTP", argsspecParabolaBTP, 3 )
 {
@@ -270,10 +305,14 @@ ObjectImp* ParabolaBTPType::calc( const Args& parents, const KigDocument& ) cons
 
 static const ArgsParser::spec argsspecConicPolarPoint[] =
 {
-  { ConicImp::stype(), I18N_NOOP( "Construct a polar point wrt. this conic" ) },
-  { AbstractLineImp::stype(), I18N_NOOP( "Construct the polar point of this line" ) }
+  { ConicImp::stype(), I18N_NOOP( "Construct a polar point wrt. this conic" ),
+    I18N_NOOP( "Select the conic wrt. which you want to construct a polar point..." ), false },
+  { AbstractLineImp::stype(), I18N_NOOP( "Construct the polar point of this line" ),
+    I18N_NOOP( "Select the line of which you want to construct the polar point..." ), false }
 };
 
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( ConicPolarPointType )
+
 ConicPolarPointType::ConicPolarPointType()
   : ArgsParserObjectType( "ConicPolarPoint", argsspecConicPolarPoint, 2 )
 {
@@ -295,18 +334,21 @@ ObjectImp* ConicPolarPointType::calc( const Args& parents, const KigDocument& )
 
   const ConicCartesianData c = static_cast<const ConicImp*>( parents[0] )->cartesianData();
   const LineData l = static_cast<const AbstractLineImp*>( parents[1] )->data();
-  bool valid = true;
-  const Coordinate p = calcConicPolarPoint( c, l, valid );
-  if ( valid ) return new PointImp( p );
+  const Coordinate p = calcConicPolarPoint( c, l );
+  if ( p.valid() ) return new PointImp( p );
   else return new InvalidImp;
 }
 
 static const ArgsParser::spec argsspecConicPolarLine[] =
 {
-  { ConicImp::stype(), I18N_NOOP( "Construct a polar line wrt. this conic" ) },
-  { PointImp::stype(), I18N_NOOP( "Construct the polar line of this point" ) }
+  { ConicImp::stype(), I18N_NOOP( "Construct a polar line wrt. this conic" ),
+    I18N_NOOP( "Select the conic wrt. which you want to construct a polar point..." ), false },
+  { PointImp::stype(), I18N_NOOP( "Construct the polar line of this point" ),
+    I18N_NOOP( "Select the line of which you want to construct the polar point..." ), false }
 };
 
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( ConicPolarLineType )
+
 ConicPolarLineType::ConicPolarLineType()
   : ArgsParserObjectType( "ConicPolarLine", argsspecConicPolarLine, 2 )
 {
@@ -336,9 +378,12 @@ ObjectImp* ConicPolarLineType::calc( const Args& parents, const KigDocument& ) c
 
 static const ArgsParser::spec argsspecConicDirectrix[] =
 {
-  { ConicImp::stype(), I18N_NOOP( "Construct the directrix of this conic" ) }
+  { ConicImp::stype(), I18N_NOOP( "Construct the directrix of this conic" ),
+    I18N_NOOP( "Select the conic of which you want to construct the directrix..." ), false }
 };
 
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( ConicDirectrixType )
+
 ConicDirectrixType::ConicDirectrixType()
   : ArgsParserObjectType( "ConicDirectrix", argsspecConicDirectrix, 1 )
 {
@@ -374,12 +419,18 @@ static const char hyperbolatpstatement[] = I18N_NOOP( "Construct a hyperbola thr
 
 static const ArgsParser::spec argsspecHyperbolaB4P[] =
 {
-  { PointImp::stype(), hyperbolatpstatement },
-  { PointImp::stype(), hyperbolatpstatement },
-  { PointImp::stype(), hyperbolatpstatement },
-  { PointImp::stype(), hyperbolatpstatement }
+  { PointImp::stype(), hyperbolatpstatement,
+    I18N_NOOP( "Select a point for the new hyperbola to go through..." ), true },
+  { PointImp::stype(), hyperbolatpstatement,
+    I18N_NOOP( "Select a point for the new hyperbola to go through..." ), true },
+  { PointImp::stype(), hyperbolatpstatement,
+    I18N_NOOP( "Select a point for the new hyperbola to go through..." ), true },
+  { PointImp::stype(), hyperbolatpstatement,
+    I18N_NOOP( "Select a point for the new hyperbola to go through..." ), true }
 };
 
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( EquilateralHyperbolaB4PType )
+
 EquilateralHyperbolaB4PType::EquilateralHyperbolaB4PType()
   : ArgsParserObjectType( "EquilateralHyperbolaB4P", argsspecHyperbolaB4P, 4 )
 {
@@ -412,10 +463,14 @@ ObjectImp* EquilateralHyperbolaB4PType::calc( const Args& parents, const KigDocu
 
 static const ArgsParser::spec argsspecParabolaBDP[] =
 {
-  { AbstractLineImp::stype(), I18N_NOOP( "Construct a parabola with this directrix" ) },
-  { PointImp::stype(), I18N_NOOP( "Construct a parabola through this point" ) }
+  { AbstractLineImp::stype(), I18N_NOOP( "Construct a parabola with this directrix" ),
+    I18N_NOOP( "Select the directrix of the new parabola..." ), false },
+  { PointImp::stype(), I18N_NOOP( "Construct a parabola with this focus" ),
+    I18N_NOOP( "Select the focus of the new parabola..." ), true }
 };
 
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( ParabolaBDPType )
+
 ParabolaBDPType::ParabolaBDPType()
   : ObjectLPType( "ParabolaBDP", argsspecParabolaBDP, 2 )
 {
@@ -448,10 +503,13 @@ ObjectImp* ParabolaBDPType::calc( const LineData& l, const Coordinate& c ) const
 
 static const ArgsParser::spec argsspecConicAsymptote[] =
 {
-  { ConicImp::stype(), I18N_NOOP( "Construct the asymptotes of this conic" ) },
-  { IntImp::stype(), "param" }
+  { ConicImp::stype(), I18N_NOOP( "Construct the asymptotes of this conic" ),
+    I18N_NOOP( "Select the conic of which you want to construct the asymptotes..." ), false },
+  { IntImp::stype(), "param", "SHOULD NOT BE SEEN", false }
 };
 
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( ConicAsymptoteType )
+
 ConicAsymptoteType::ConicAsymptoteType()
   : ArgsParserObjectType( "ConicAsymptote", argsspecConicAsymptote, 2 )
 {
@@ -487,12 +545,16 @@ static const char radicallinesstatement[] = I18N_NOOP( "Construct the radical li
 
 static const ArgsParser::spec argsspecConicRadical[] =
 {
-  { ConicImp::stype(), radicallinesstatement },
-  { ConicImp::stype(), radicallinesstatement },
-  { IntImp::stype(), "param" },
-  { IntImp::stype(), "param" }
+  { ConicImp::stype(), radicallinesstatement,
+    I18N_NOOP( "Select the first of the two conics of which you want to construct the radical line..." ), false },
+  { ConicImp::stype(), radicallinesstatement,
+    I18N_NOOP( "Select the other of the two conic of which you want to construct the radical line..." ), false },
+  { IntImp::stype(), "param", "SHOULD NOT BE SEEN", false },
+  { IntImp::stype(), "param", "SHOULD NOT BE SEEN", false }
 };
 
+KIG_INSTANTIATE_OBJECT_TYPE_INSTANCE( ConicRadicalType )
+
 ConicRadicalType::ConicRadicalType()
   : ArgsParserObjectType( "ConicRadical", argsspecConicRadical, 4 )
 {
@@ -602,3 +664,27 @@ const ObjectImpType* ConicRadicalType::resultId() const
   return LineImp::stype();
 }
 
+QStringList ConicRadicalType::specialActions() const
+{
+  QStringList ret;
+  ret << i18n( "Switch Radical Lines" );
+  return ret;
+}
+
+void ConicRadicalType::executeAction( int i, ObjectHolder&, ObjectTypeCalcer& t,
+                                      KigPart& d, KigWidget&, NormalMode& ) const
+{
+  assert( i == 0 );
+  std::vector<ObjectCalcer*> parents = t.parents();
+  assert( dynamic_cast<ObjectConstCalcer*>( parents[3] ) );
+  ObjectConstCalcer* zeroindexo = static_cast<ObjectConstCalcer*>( parents[3] );
+  MonitorDataObjects mon( zeroindexo );
+  assert( zeroindexo->imp()->inherits( IntImp::stype() ) );
+  int oldzeroindex = static_cast<const IntImp*>( zeroindexo->imp() )->data();
+  int newzeroindex = oldzeroindex % 3 + 1;
+  zeroindexo->setImp( new IntImp( newzeroindex ) );
+  KigCommand* kc = new KigCommand( d, "Switch Conic Radical Lines" );
+  mon.finish( kc );
+  d.history()->addCommand( kc );
+}
+
