@@ -1,41 +1,44 @@
-#include <kaccel.h>
+/**
+ This file is part of Kiten, a KDE Japanese Reference Tool...
+ Copyright (C) 2001  Jason Katz-Brown <jason@katzbrown.com>
+
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2 of the License, or
+ (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with this program; if not, write to the Free Software
+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ USA
+**/
+
 #include <kaction.h>
 #include <kapplication.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <kdeversion.h>
 #include <kedittoolbar.h>
-#include <kglobal.h>
 #include <kglobalaccel.h>
 #include <kiconloader.h>
-#include <kkeydialog.h>
 #include <klocale.h>
 #include <kmainwindow.h>
-#include <kmessagebox.h>
-#include <kshortcut.h>
 #include <kstandarddirs.h>
 #include <kstatusbar.h>
-#include <kstdaction.h>
-#include <kstdguiitem.h>
 
-#include <qcheckbox.h>
 #include <qclipboard.h>
-#include <qfile.h>
-#include <qguardedptr.h>
-#include <qlayout.h>
-#include <qpushbutton.h>
 #include <qregexp.h>
 #include <qtextcodec.h>
 #include <qtimer.h>
-#include <qwidget.h>
 
-#include "deinf.h"
-#include "dict.h"
 #include "kiten.h"
 #include "learn.h"
 #include "optiondialog.h"
-#include "rad.h"
-#include "widgets.h"
 
 #include <cassert>
 
@@ -57,12 +60,12 @@ TopLevel::TopLevel(QWidget *parent, const char *name) : KMainWindow(parent, name
 	(void) KStdAction::quit(this, SLOT(close()), actionCollection());
 	(void) KStdAction::print(this, SLOT(print()), actionCollection());
 	(void) KStdAction::preferences(this, SLOT(slotConfigure()), actionCollection());
-	(void) KStdAction::keyBindings(this, SLOT(slotKeyBindings()), actionCollection());
+	KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), actionCollection());
 	(void) new KAction(i18n("&Learn"), "pencil", CTRL+Key_L, this, SLOT(createLearn()), actionCollection(), "file_learn");
 	(void) new KAction(i18n("&Dictionary Editor..."), "edit", 0, this, SLOT(createEEdit()), actionCollection(), "dict_editor");
 	(void) new KAction(i18n("Ra&dical Search..."), "gear", CTRL+Key_R, this, SLOT(radicalSearch()), actionCollection(), "search_radical");
 	Edit = new EditAction(i18n("Search Edit"), 0, this, SLOT(search()), actionCollection(), "search_edit");
-	(void) new KAction(KStdGuiItem::clear().text(), BarIcon("locationbar_erase", 16), 0, Edit, SLOT(clear()), actionCollection(), "clear_search");
+	(void) new KAction(i18n("&Clear Search Bar"), BarIcon("locationbar_erase", 16), CTRL+Key_N, Edit, SLOT(clear()), actionCollection(), "clear_search");
 	(void) new KAction(i18n("&Search"), "key_enter", 0, this, SLOT(search()), actionCollection(), "search");
 	(void) new KAction(i18n("Search with &Beginning of Word"), 0, this, SLOT(searchBeginning()), actionCollection(), "search_beginning");
 	(void) new KAction(i18n("&Search Anywhere"), 0, this, SLOT(searchAnywhere()), actionCollection(), "search_anywhere");
@@ -120,22 +123,30 @@ TopLevel::~TopLevel()
 
 void TopLevel::finishInit()
 {
-	if (kanjiCB->isChecked())
-		Edit->setText(QTextCodec::codecForName("eucJP")->toUnicode(QCString("")));
-	else
-		Edit->setText(QTextCodec::codecForName("eucJP")->toUnicode(QCString("")));
+	// if it's the application's first time starting, 
+	// the app group won't exist and we show demo
+	if (!kapp->config()->hasGroup("app"))
+	{
+		if (kanjiCB->isChecked())
+			Edit->setText(QTextCodec::codecForName("eucJP")->toUnicode(QCString("")));
+		else
+			Edit->setText(QTextCodec::codecForName("eucJP")->toUnicode(QCString("")));
 
-	search();
+		search();
+	}
+
+	Edit->clear(); // make sure the edit is focused initially
+	StatusBar->message(i18n("Welcome to Kiten"));
 	setCaption(QString::null);
 }
 
-void TopLevel::closeEvent(QCloseEvent *)
+bool TopLevel::queryClose()
 {
 	for (QPtrListIterator<Learn> i(learnList); *i;)
 	{
 		(*i)->show();
 		if (!(*i)->closeWindow())
-			return;
+			return false; // cancel
 		Learn *old = *i;
 		++i;
 		learnList.remove(old);
@@ -154,8 +165,7 @@ void TopLevel::closeEvent(QCloseEvent *)
 	config->writeEntry("__useGlobal", edictUseGlobal);
 
 	saveMainWindowSettings(KGlobal::config(), "TopLevelWindow");
-
-	kapp->quit();
+	return true;
 }
 
 void TopLevel::addToList()
@@ -297,14 +307,13 @@ void TopLevel::searchBeginning()
 	QString text = Edit->text();
 	QRegExp regexp;
 
-	QTextCodec *codec = QTextCodec::codecForName("eucJP");
-	QCString csch_str = codec->fromUnicode(text);
-	unsigned char first = csch_str[0];
-
-	if (first <= 128)
-		regexp = QRegExp(QString("\\W").append(text));
-	else if (first < 0xa5)
+	switch (Dict::textType(text))
 	{
+	case Dict::Text_Latin:
+		regexp = QRegExp(QString("\\W").append(text));
+		break;
+
+	case Dict::Text_Kana:
 		if (kanjiCB->isChecked())
 		{
 			regexp = QRegExp(QString("\\W").append(text));
@@ -314,9 +323,11 @@ void TopLevel::searchBeginning()
 			beginningReadingSearch = true;
 			regexp = QRegExp(QString("\\[").append(text));
 		}
-	}
-	else if (first > 0xa8)
+		break;
+
+	case Dict::Text_Kanji:
 		regexp = QRegExp(QString("^").append(text));
+	}
 
 	doSearch(text, regexp);
 }
@@ -352,25 +363,19 @@ void TopLevel::search(bool inResults)
 	QString text = Edit->text();
 	QRegExp regexp;
 
-	QTextCodec *codec = QTextCodec::codecForName("eucJP");
-	QCString csch_str = codec->fromUnicode(text);
-	unsigned char first = csch_str[0];
-	unsigned char last = csch_str[csch_str.length()];
-
-	// gjiten seems to do this stuff to tell between the three...
-	// TODO: factor out this gjiten heuristic
-	if (first <= 128)
+	switch (Dict::textType(text))
 	{
+	case Dict::Text_Latin:
 		regexp = searchItems();
-	}
-	else if (first < 0xa8)
-	{
+		break;
+
+	case Dict::Text_Kana:
 		regexp = readingSearchItems(kanjiCB->isChecked());
 		readingSearch = true;
-	}
-	else if (first > 0xa8)
-	{
-		if (last < 0xa5 && deinfCB->isChecked()) // deinflect
+		break;
+
+	case Dict::Text_Kanji:
+		if (deinfCB->isChecked()) // deinflect
 		{
 			bool common = comCB->isChecked();
 			QStringList names;
@@ -719,9 +724,7 @@ QRegExp TopLevel::readingSearchItems(bool kanji)
 {
 	QString text = Edit->text();
 	if (text.isEmpty()) // abandon search
-	{
 		return QRegExp(); //empty
-	}
 
 	//CompletionObj->addItem(text);
 	QString regexp;
@@ -740,9 +743,7 @@ QRegExp TopLevel::kanjiSearchItems(bool beginning)
 	QString text = Edit->text();
 
 	if (text.isEmpty())
-	{
 		return QRegExp(); //empty
-	}
 
 	QString regexp;
 	if (beginning)
@@ -760,9 +761,7 @@ QRegExp TopLevel::searchItems()
 	QString regexp;
 	QString text = Edit->text();
 	if (text.isEmpty())
-	{
 		return QRegExp(); //empty
-	}
 
 	unsigned int contains = text.contains(QRegExp("[A-Za-z0-9_:]"));
 	if (wholeWord && contains == text.length())
@@ -779,11 +778,6 @@ void TopLevel::toggleCom()
 {
 }
 
-void TopLevel::slotKeyBindings()
-{
-	KKeyDialog::configure(actionCollection());
-}
-
 void TopLevel::configureToolBars()
 {
 	saveMainWindowSettings(KGlobal::config(), "TopLevelWindow");
@@ -935,7 +929,6 @@ void TopLevel::addHistory(Dict::SearchResult result)
 
 	enableHistoryButtons();
 
-	// we don't want the history list tooo long..
 	if (resultHistory.size() > 50)
 		resultHistory.pop_front();
 }
