@@ -1,26 +1,40 @@
+/**
+ This file is part of Kiten, a KDE Japanese Reference Tool...
+ Copyright (C) 2001  Jason Katz-Brown <jason@katzbrown.com>
+
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2 of the License, or
+ (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with this program; if not, write to the Free Software
+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ USA
+**/
+
+#include <kdebug.h>
 #include <kapplication.h>
 #include <qvgroupbox.h>
 #include <kkeydialog.h>
 #include <kfontdialog.h>
 #include <qtextcodec.h>
 #include <kglobalaccel.h>
-#include <kglobal.h>
-#include <kdebug.h>
 #include <klocale.h>
 #include <qcombobox.h>
-#include <kconfig.h>
 #include <kfiledialog.h>
 #include <kstandarddirs.h>
 #include <kurllabel.h>
-#include <klistview.h>
+#include <krun.h>
 
 #include <qlayout.h>
-#include <qstring.h>
 #include <qcheckbox.h>
-#include <qstringlist.h>
-#include <qlabel.h>
 #include <qpushbutton.h>
-#include <qfileinfo.h>
 
 #include "optiondialog.h"
 
@@ -36,10 +50,19 @@ ConfigureDialog::ConfigureDialog(KGlobalAccel *accel, QWidget *parent, char *nam
 	QFrame *Page0 = addPage(i18n("Dictionaries"));
 	QVBoxLayout *descBox = new QVBoxLayout(Page0);
 	descBox->addWidget(new QLabel(QString("<p>") + i18n("Kiten includes Edict for a regular word search. For Kanji searching, Kanjidic is included. Feel free to add your own extras (see foreign-language link below) by adding them in the configuration pages below this one.") + QString("</p>"), Page0));
+
 	descBox->addStretch();
-	descBox->addWidget(new KURLLabel("http://www.csse.monash.edu.au/~jwb/edict.html", i18n("Edict information page"), Page0));
-	descBox->addWidget(new KURLLabel("http://www.csse.monash.edu.au/~jwb/kanjidic.html", i18n("Kanjidic information page"), Page0));
-	descBox->addWidget(new KURLLabel("http://www.katzbrown.com/kiten/Dictionaries/", i18n("Foreign language Edicts"), Page0));
+
+	KURLLabel *edictLabel = new KURLLabel("http://www.csse.monash.edu.au/~jwb/edict.html", i18n("Edict information page"), Page0);
+	connect(edictLabel, SIGNAL(leftClickedURL(const QString &)), this, SLOT(openURL(const QString &)));
+	descBox->addWidget(edictLabel);
+	KURLLabel *kanjidicLabel = new KURLLabel("http://www.csse.monash.edu.au/~jwb/kanjidic.html", i18n("Kanjidic information page"), Page0);
+	connect(kanjidicLabel, SIGNAL(leftClickedURL(const QString &)), this, SLOT(openURL(const QString &)));
+	descBox->addWidget(kanjidicLabel);
+	KURLLabel *foreignLabel = new KURLLabel("http://www.katzbrown.com/kiten/Dictionaries/", i18n("Foreign language Edicts"), Page0);
+	connect(foreignLabel, SIGNAL(leftClickedURL(const QString &)), this, SLOT(openURL(const QString &)));
+	descBox->addWidget(foreignLabel);
+
 	descBox->addStretch();
 
 	list.append(i18n("Edict"));
@@ -159,6 +182,11 @@ void ConfigureDialog::writeConfig()
 	Accel->writeSettings(KGlobal::config());
 }
 
+void ConfigureDialog::openURL(const QString &url)
+{
+	KRun::runURL(KURL(url), "text/html");
+}
+
 void ConfigureDialog::slotOk()
 {
 	slotApply();
