@@ -1,3 +1,23 @@
+/**
+ This file is part of Kiten, a KDE Japanese Reference Tool...
+ Copyright (C) 2001  Jason Katz-Brown <jason@katzbrown.com>
+
+ This program is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2 of the License, or
+ (at your option) any later version.
+
+ This program is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+
+ You should have received a copy of the GNU General Public License
+ along with this program; if not, write to the Free Software
+ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ USA
+**/
+
 #include <kaction.h>
 #include <kapplication.h>
 #include <kconfig.h>
@@ -6,22 +26,14 @@
 #include <kmessagebox.h>
 #include <kprinter.h>
 #include <kprocess.h>
-#include <kpushbutton.h>
 #include <kstandarddirs.h>
 #include <kstatusbar.h>
-#include <kstdaction.h>
-#include <ktoolbar.h>
-#include <qcstring.h>
-#include <qfile.h>
 #include <qfileinfo.h>
-#include <qfont.h>
 #include <qpaintdevicemetrics.h>
 #include <qpainter.h>
-#include <qrect.h>
 #include <qregexp.h>
 #include <qsimplerichtext.h>
 #include <qtextcodec.h>
-#include <qtextstream.h>
 
 #include <cassert>
 
@@ -29,24 +41,23 @@
 #include "kromajiedit.h"
 #include "widgets.h"
 
-ResultView::ResultView(bool _links, QWidget *parent, const char *name)
+ResultView::ResultView(bool showLinks, QWidget *parent, const char *name)
 	: KTextBrowser(parent, name)
 {
 	setReadOnly(true);
 	setLinkUnderline(false);
 	basicMode = false;
-	links = _links;
+	links = showLinks;
 
-	// qtextbrowser.cpp connects this... we don't need it
-	// it gives console output ;)
-	disconnect(this, SIGNAL(linkClicked(const QString &)), this, SLOT(setSource(const QString &)));
+	// don't let ktextbrowser internally handle link clicks
+	setNotifyClick(true);
 }
 
-void ResultView::addResult(Dict::Entry result, bool com)
+void ResultView::addResult(Dict::Entry result, bool common)
 {
 	if (result.dictName() != "__NOTSET")
 	{
-		addHeader((com? i18n("Common results from %1") : i18n("Results from %1")).arg(result.dictName()), 5);
+		addHeader((common? i18n("Common results from %1") : i18n("Results from %1")).arg(result.dictName()), 5);
 		return;
 	}
 	if (result.header() != "__NOTSET")
@@ -67,7 +78,7 @@ void ResultView::addResult(Dict::Entry result, bool com)
 	{
 		if ((*it).find("(P)") >= 0)
 		{
-			if (com)
+			if (common)
 				continue;
 			else
 			{
@@ -86,11 +97,11 @@ void ResultView::addResult(Dict::Entry result, bool com)
 	append(html);
 }
 
-void ResultView::addKanjiResult(Dict::Entry result, bool com, Radical rad)
+void ResultView::addKanjiResult(Dict::Entry result, bool common, Radical rad)
 {
 	if (result.dictName() != "__NOTSET")
 	{
-		addHeader((com? i18n("Common results from %1") : i18n("Results from %1")).arg(result.dictName()), 5);
+		addHeader((common? i18n("Common results from %1") : i18n("Results from %1")).arg(result.dictName()), 5);
 		return;
 	}
 	if (result.header() != "__NOTSET")
@@ -106,7 +117,9 @@ void ResultView::addKanjiResult(Dict::Entry result, bool com, Radical rad)
 	if (freq == 0) // does it have a frequency?
 		html = html.arg(i18n("Rare"));
 	else
-		html = html.arg(i18n("#%1").arg(freq));
+		// this isn't a number of times, it's simply an index of
+		// probability
+		html = html.arg(i18n("Probability rank #%1").arg(freq));
 
 	html += "<br />";
 
@@ -129,7 +142,7 @@ void ResultView::addKanjiResult(Dict::Entry result, bool com, Radical rad)
 				if (basicMode)
 					break;
 
-				html.truncate(html.length() - 2);
+				html.truncate(html.length() - 2); 
 				html += i18n("<br />As radical: ");
 			}
 			else
@@ -139,7 +152,7 @@ void ResultView::addKanjiResult(Dict::Entry result, bool com, Radical rad)
 			}
 		}
 	}
-	html.truncate(html.length() - 2);
+	html.truncate(html.length() - 2); 
 
 	html += "<br />";
 
@@ -149,7 +162,7 @@ void ResultView::addKanjiResult(Dict::Entry result, bool com, Radical rad)
 		html += (*it);
 		html += "; ";
 	}
-	html.truncate(html.length() - 2);
+	html.truncate(html.length() - 2); 
 	html += "<br />";
 	html += i18n("Grade Level: %1. Strokes: %2.");
 
@@ -194,19 +207,14 @@ QString ResultView::putchars(const QString &text)
 	unsigned int len = text.length();
 	QString ret;
 
-	QTextCodec *codec = QTextCodec::codecForName("eucJP");
-
 	for (unsigned i = 0; i < len; i++)
 	{
-		QCString str = codec->fromUnicode(QString(text.at(i)));
-		unsigned char first = str[0];
-
-		if (first > 0xa8)
+		if (Dict::textType(QString(text.at(i))) == Dict::Text_Kanji)
 			ret.append(QString("<a href=\"%1\">%1</a>").arg(text.at(i)).arg(text.at(i)));
 		else
 			ret.append(text.at(i));
 	}
-
+	
 	return ret;
 }
 
@@ -238,9 +246,9 @@ void ResultView::print(QString title)
 		int dpix = metrics.logicalDpiX();
 		int dpiy = metrics.logicalDpiY();
 		const int margin = 72; // pt
-
+	
 		QRect body(dpix, dpiy, metrics.width() - margin * dpix / margin * 2, metrics.height() - margin * dpiy / margin * 2);
-
+	
 		QSimpleRichText richText(title.isNull()? printText : i18n("<h1>Search for \"%1\"</h1>").arg(title) + printText, font(), context(), styleSheet(), mimeSourceFactory(), body.height(), Qt::black, false);
 		richText.setWidth(&p, body.width());
 		QRect view(body);
@@ -277,7 +285,7 @@ void ResultView::print(QString title)
 void ResultView::updateFont()
 {
 	KConfig *config = kapp->config();
-
+	
 	config->setGroup("General");
 	QFont defaultFont(config->readFontEntry("font"));
 	config->setGroup("Font");
@@ -346,7 +354,7 @@ void eEdit::openFile(const QString &file)
 	QString s;
 
 	while (!t.eof())
-	{
+	{ 
 		s = t.readLine();
 		if (s.left(1) == "#" || s.isEmpty())
 			continue;
@@ -367,7 +375,7 @@ void eEdit::save()
 	QTextStream t(&f);
 
 	t << "# Generated by Kiten's EDICT editor" << endl << "# http://katzbrown.com/kiten" << endl << endl;
-
+	
 	QListViewItemIterator it(List);
 	for (; it.current(); ++it)
 	{
@@ -399,10 +407,10 @@ void eEdit::save()
 
 	// find the index generator executable
 	KProcess proc;
-	proc << KStandardDirs::findExe("kitengen") << filename << KGlobal::dirs()->saveLocation("appdata", "xjdx/", true) + QFileInfo(filename).baseName() + ".xjdx";
+	proc << KStandardDirs::findExe("kitengen") << filename << KGlobal::dirs()->saveLocation("data", "kiten/xjdx/", true) + QFileInfo(filename).baseName() + ".xjdx";
 	// TODO: put up a status dialog and event loop instead of blocking
 	proc.start(KProcess::Block, KProcess::NoCommunication);
-
+	
 	statusBar()->message(i18n("Saved"));
 	isMod = false;
 }
@@ -488,9 +496,10 @@ void EditAction::unplug( QWidget *w )
 void EditAction::clear()
 {
 	m_combo->clear();
+	m_combo->setFocus();
 }
 
-void EditAction::insert(QString text)
+void EditAction::insert(const QString text)
 {
 	m_combo->insert(text);
 }
