@@ -1,4 +1,22 @@
+/***************************************************************************
+                          kmwnewconfig.cc -  description
+                             -------------------
+    begin                : Sun Oct 21 2001
+    copyright            : (C) 2001 by Primoz Anzur 
+    email                : zerokode@gmx.net
+ ***************************************************************************/
+
+/***************************************************************************
+ *                                                                         *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ ***************************************************************************/
+ 
 #include "kmwnewconfig.h"
+
 KmwConfigurator::KmwConfigurator(QWidget *parent, const char *name) : KmwConfig(parent, name)
 {
 	themeID=0L;
