@@ -2,8 +2,8 @@
                           kwritewords.cpp  -  description
                              -------------------
     begin                : Thu Aug 2 2001
-    copyright            : (C) 2001 by Primoz Anzur (zer0Kode)
-    email                : zerokode@yahoo.com
+    copyright            : (C) 2001 by Primoz Anzur 
+    email                : zerokode@gmx.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,7 +18,7 @@
 #include "kwritewords.h"
 #include "kwritewords.moc"
 
-KWriteWords::KWriteWords(QWidget *parent, const char *name ) : WordsEditor(parent,name)
+KWriteWords::KWriteWords(QWidget *parent, const char *name) : WordsEditor(parent,name, true)
 {
 	openDataStream();
 }
@@ -94,3 +94,9 @@ void KWriteWords::slotCancel()
 {
 	close();
 }
+
+void KWriteWords::closeEvent(QCloseEvent *ev)
+{
+	emit getClose();
+	this->hide();
+}
