@@ -1,12 +1,9 @@
-#include <klocale.h>
 #include "mwconfig.h"
 #include "mwconfig.moc"
-#include "mainwindow.h"
 #include "splashscreen.h"
 #include <pwd.h>
-#include <kprocess.h>
 #include <kdebug.h>
-
+#include <kpushbutton.h>
 
 /*
  *  Constructs a Config which is a child of 'parent', with the
@@ -31,8 +28,7 @@ Config::Config( QWidget* parent,  const char* name, WFlags fl )
     ConfigLayout->setSpacing( 6 );
     ConfigLayout->setMargin( 11 );
 
-    btnCancel = new QPushButton( this, "btnCancel" );
-    btnCancel->setText( i18n( "&Cancel" ) );
+    btnCancel = new KPushButton( KStdGuiItem::cancel(), this, "btnCancel" );
 
     ConfigLayout->addWidget( btnCancel, 1, 2 );
 
@@ -119,8 +115,7 @@ Config::Config( QWidget* parent,  const char* name, WFlags fl )
 
     ConfigLayout->addMultiCellWidget( TabWidget3, 0, 0, 0, 2 );
 
-    btnOkay = new QPushButton( this, "btnOkay" );
-    btnOkay->setText( i18n( "&OK" ) );
+    btnOkay = new KPushButton( KStdGuiItem::ok(), this, "btnOkay" );
     btnOkay->setFocus();
 
     ConfigLayout->addWidget( btnOkay, 1, 0 );
@@ -177,7 +172,7 @@ void Config::grabData() {
 	d.setFilter( QDir::Dirs);
 	d.setSorting( QDir::Name);
 
-	for ( int i=0; i<d.count(); i++ ) {
+	for ( uint i=0; i<d.count(); i++ ) {
 	 	if ((d[i] != ".") && (d[i] != "..")) {
 			themeSelector->insertItem(d[i]);
 			if (d[i]==themeName){
