@@ -1,7 +1,7 @@
 /*
 * KmPlot - a math. function plotter for the KDE-Desktop
 *
-* Copyright (C) 1998, 1999  Klaus-Dieter Mller
+* Copyright (C) 1998, 1999  Klaus-Dieter Möller
 *               2000, 2002 kd.moeller@t-online.de
 *
 * This file is part of the KDE Project.
@@ -23,19 +23,25 @@
 *
 */
 
-// local includes
-#include "main.h"
+/**
+ * Version string of KmPlot.
+ */
+#define	KP_VERSION	"1.0.9"
+
 
 // KDE includes
-#include <kcmdlineargs.h>
 #include <kaboutdata.h>
-#include <klocale.h>
+#include <kapplication.h>
+
+// local includes
+#include "MainDlg.h"
 
 static const char description[] =
-    I18N_NOOP( "KmPlot is a mathematical function plotter for the KDE Desktop." );
+    I18N_NOOP( "Mathematical function plotter for KDE" );
 
 static KCmdLineOptions options[] =
     {
+        { "+[URL]", I18N_NOOP( "File to open" ), 0 },
         KCmdLineLastOption
         // INSERT YOUR COMMANDLINE OPTIONS HERE
     };
@@ -48,22 +54,25 @@ int main( int argc, char **argv )
 	    I18N_NOOP( "KmPlot" ),
 	    KP_VERSION, description, KAboutData::License_GPL,
 	    "(c) 2000-2002, Klaus-Dieter Möller",
-	    0, 0,
-	    "submit@bugs.kde.org" );
+	    0,
+	    "http://edu.kde.org/kmplot/" );
 	aboutData.addAuthor(
-	    "Klaus-Dieter Möller", 0 ,
-	    "kd.moeller@t-online.de" );
-	aboutData.addCredit("David Vignoni",
-                 I18N_NOOP("SVG icon" ),
-                 "david80v@tin.it");
+	    "Klaus-Dieter Möller", I18N_NOOP( "Original Author" ) ,
+	    "kdmoeller@foni.net" );
+	aboutData.addAuthor(
+	    "Matthias Meßmer", I18N_NOOP( "GUI" ) ,
+	    "bmlmessmer@web.de" );
+	aboutData.addAuthor( "Fredrik Edemar", I18N_NOOP( "Various improvements" ), "f_edemar@linux.se" );
+	aboutData.addCredit( "David Vignoni", I18N_NOOP( "svg icon" ), "david80v@tin.it" );
+	aboutData.addCredit( "Albert Astals Cid", I18N_NOOP( "command line options, MIME type" ), "tsdgeos@terra.es" );
+	
 	KCmdLineArgs::init( argc, argv, &aboutData );
 	KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
 
 	KApplication ka;
-	kc = KGlobal::config();
-	MainDlg *w = new MainDlg;
+	KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
+	MainDlg *w = new MainDlg( ka.sessionId(), args );
 	w->resize( 450, 400 );
-	//w->setPalette( QPalette( QColor( 255, 255, 255 ) ) );
 	w->show();
 	ka.setMainWidget( w );
 	return ka.exec();
