@@ -23,10 +23,6 @@
 #define KANSWER_H
 
 // Qt includes
-#include <qstringlist.h>
-#include <qpixmap.h>
-#include <qwidget.h>
-#include <qtimer.h>
 
 // KDE includes
 #include <kdialog.h>
