@@ -23,20 +23,14 @@
 #include <stdlib.h>
 
 // Qt includes
-#include <qfont.h>
-#include <qiconset.h>
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qpixmap.h>
-#include <qpopupmenu.h>
 #include <qtooltip.h>
 #include <qwhatsthis.h>
 
 // KDE includes
-#include <kapplication.h>
 #include <khelpmenu.h>
 #include <kiconloader.h>
-#include <kicontheme.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kpushbutton.h>
@@ -57,8 +51,6 @@ KPercentage::KPercentage( const char *name ) :
     // Icon loader for the button's icons
     KIconLoader icon_loader;
 
-    setCaption( "KPercentage - "KPERCENTAGE_VERSION );
-
     // let's set a suitable, not too small font size
     QFont the_font( font() );
     the_font.setPointSize( 12 );
@@ -91,7 +83,7 @@ KPercentage::KPercentage( const char *name ) :
     KPushButton *button_percentvalue = new KPushButton( i18n( "x% of y = ??" ), this );
     KPushButton *button_percentage = new KPushButton( i18n( "??% of x = y" ), this );
     KPushButton *button_random = new KPushButton( i18n( "??" ), this );
-    KPushButton *button_help = new KPushButton( i18n( "&Help" ), this );
+    KPushButton *button_help = new KPushButton( KStdGuiItem::help().text(), this );
     button_help->setIconSet( QIconSet( icon_loader.loadIcon( "help", KIcon::NoGroup, 32 ) ) );
 	KHelpMenu *help_menu = new KHelpMenu( this, KGlobal::instance()->aboutData(), true );
 	button_help->setPopup( ( QPopupMenu* ) ( help_menu->menu() ) );
@@ -165,7 +157,7 @@ KPercentage::KPercentage( const char *name ) :
 	QToolTip::add( combo_box_level, i18n( "Choose the level of difficulty." ) );
 	QToolTip::add( button_close, i18n( "Close KPercentage." ) );
 	QToolTip::add( button_help, i18n( "Get some help." ) );
-	
+
 	////////
 	// WhatsThis
 	QWhatsThis::add( button_basevalue, i18n( "Click here to start a sequence of exercises where the base value is omitted.") );
