@@ -18,43 +18,45 @@
 #ifndef ADDLINKDIALOG_H
 #define ADDLINKDIALOG_H
 
+#include <qradiobutton.h>
 #include <kdialogbase.h>
 #include <klineedit.h>
-#include <qradiobutton.h>
 
 class QString;
 class QHBoxLayout;
 class QVBoxLayout;
 class QGridLayout;
 class QPushButton;
-class QRadioButton;
 class QButtonGroup;
 
-/**@short Simple dialog for adding a custom URL to a popup menu.
+class SkyMap;
+
+/**@class Simple dialog for adding a custom URL to a popup menu.
   *@author Jason Harris
-	*@version 0.9
+	*@version 1.0
   */
 
 class AddLinkDialog : public KDialogBase  {
 	Q_OBJECT
 public:
-	/**Constructor. */
+/**Constructor. */
 	AddLinkDialog( QWidget* parent = 0 );
 
-	/**Destructor (empty) */
+/**Destructor (empty) */
 	~AddLinkDialog() {}
 
-	/**@returns QString of the entered URL */
+/**@return QString of the entered URL */
 	QString url() const { return URLEntry->text(); }
 
-	/**@returns QString of the entered menu entry text */
+/**@return QString of the entered menu entry text */
 	QString title() const { return TitleEntry->text(); }
 
-	/**@returns true if user declared the link is an image */
+/**@return TRUE if user declared the link is an image */
 	bool isImageLink() const { return ImageRadio->isChecked(); }
 
 private slots:
-	/**Open the entered URL in the web browser */
+/**Open the entered URL in the web browser 
+	*/
 	void checkURL( void );
 
 	/**We provide a default menu text string; this function changes the
