@@ -15,6 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
+#include <qfile.h>
 #include <kconfig.h>
 #include <kdebug.h>
 #include <klocale.h>
@@ -33,7 +34,7 @@ ColorScheme::ColorScheme() : FileName() {
 	//In addition, we define default RGB strings for each item.
 	//To add another color to the Palette, just add an entry for KeyName,
 	//Name and Default here.
-
+	
 	KeyName.append( "SkyColor" );
 	Name.append( i18n( "Sky" ) );
 	Default.append( "#002" );
@@ -61,6 +62,9 @@ ColorScheme::ColorScheme() : FileName() {
 	KeyName.append( "CLineColor" );
 	Name.append( i18n( "Constellation Line", "Constell. Line" ) );
 	Default.append( "#555" );
+	KeyName.append( "CBoundColor" );
+	Name.append( i18n( "Constellation Boundary", "Constell. Boundary" ) );
+	Default.append( "#222" );
 	KeyName.append( "MWColor" );
 	Name.append( i18n( "refers to the band of stars in the sky due to the Galactic plane", "Milky Way" ) );
 	Default.append( "#123" );
@@ -97,7 +101,15 @@ ColorScheme::ColorScheme() : FileName() {
 	KeyName.append( "PlanetTrailColor" );
 	Name.append( i18n( "Planet Trails" ) );
 	Default.append( "#963" );
+	KeyName.append( "AngularRuler" );
+	Name.append( i18n( "Angular Distance Ruler" ) );
+	Default.append( "#FFF" );
 
+	//Set the default colors in the Palette.
+	for( uint i=0; i<KeyName.count(); ++i ) {
+		setColor( KeyName[i], Default[i] );
+	}
+	
 	//Default values for integer variables:
 	StarColorMode = 0;
 	StarColorIntensity = 4;
@@ -128,7 +140,7 @@ void ColorScheme::copy( const ColorScheme &cs ) {
 
 QString ColorScheme::colorNamed( const QString &name ) const {
 	//QString color( Palette[ name ] );
-	if ( Palette[ name ].isEmpty() ) {
+	if ( ! hasColorNamed( name ) ) {
 		kdWarning() << i18n( "No color named \"%1\" found in color scheme." ).arg( name ) << endl;
 		//color = "#FFFFFF"; //set to white if no color found
 		return "#FFFFFF";
@@ -152,6 +164,10 @@ QString ColorScheme::keyAt( int i ) const {
 	return QString(*it);
 }
 
+QString ColorScheme::nameFromKey( const QString &key ) const {
+	return nameAt( KeyName.findIndex( key ) );
+}
+
 void ColorScheme::setColor( const QString &key, const QString &color ) {
 	//We can blindly insert() the new value; if the key exists, the old value is replaced
 	Palette.insert( key, color );
@@ -214,7 +230,9 @@ bool ColorScheme::load( const QString &filename ) {
 			//Assuming the old *.colors format.  Loop through the KeyName list,
 			//and assign each color.  Note that order matters here, but only here
 			//(so if you don't use the old format, then order doesn't ever matter)
-			for ( QStringList::Iterator it = KeyName.begin(); it != KeyName.end(); ++it )
+			QStringList::Iterator it = KeyName.begin();
+			QStringList::Iterator it_end = KeyName.end();
+			for ( ; it != it_end; ++it )
 				setColor( QString(*it), line.left( 7 ) );
 		}
 	}
@@ -244,7 +262,9 @@ bool ColorScheme::save( const QString &name ) {
 			QTextStream stream( &file );
 			stream << StarColorMode << ":" << StarColorIntensity << endl;
 
-			for ( QStringList::Iterator it = KeyName.begin(); it != KeyName.end(); ++it )
+			QStringList::Iterator it = KeyName.begin();
+			QStringList::Iterator it_end = KeyName.end();
+			for ( ; it != it_end; ++it )
 				stream << Palette[ (*it) ] << " :" << (*it) << endl;
 
 			file.close();
@@ -262,7 +282,7 @@ bool ColorScheme::save( const QString &name ) {
 			file.close();
 		}
 	} else {
-		QString message = i18n( "Invalid Filename requested.\nScheme cannot be recorded." );
+		QString message = i18n( "Invalid filename requested.\nScheme cannot be recorded." );
 		KMessageBox::sorry( 0, message, i18n( "Invalid Filename" ) );
 		return false;
 	}
@@ -272,7 +292,9 @@ bool ColorScheme::save( const QString &name ) {
 }
 
 void ColorScheme::loadFromConfig( KConfig *conf ) {
-	for ( QStringList::Iterator it = KeyName.begin(); it != KeyName.end(); ++it )
+	QStringList::Iterator it = KeyName.begin();
+	QStringList::Iterator it_end = KeyName.end();
+	for ( ; it != it_end; ++it )
 		setColor( QString(*it), conf->readEntry( QString(*it), QString( *Default.at( KeyName.findIndex(*it) ) ) ) );
 
 	setStarColorMode( conf->readNumEntry( "StarColorMode", 0 ) );
@@ -280,7 +302,9 @@ void ColorScheme::loadFromConfig( KConfig *conf ) {
 }
 
 void ColorScheme::saveToConfig( KConfig *conf ) {
-	for ( QStringList::Iterator it = KeyName.begin(); it != KeyName.end(); ++it )
+	QStringList::Iterator it = KeyName.begin();
+	QStringList::Iterator it_end = KeyName.end();
+	for ( ; it != it_end; ++it )
 		conf->writeEntry( QString(*it), colorNamed( QString(*it) ) );
 
 	conf->writeEntry( "StarColorMode", starColorMode() );
