@@ -61,89 +61,87 @@ static void ISPoll(void *);
 static void retryConnection(void *);
 
 /*INDI controls */
-static ISwitch PowerS[]          = {{"CONNECT" , "Connect" , ISS_OFF},{"DISCONNECT", "Disconnect", ISS_ON}};
-static ISwitch AlignmentS []     = {{"Polar", "", ISS_ON}, {"AltAz", "", ISS_OFF}, {"Land", "", ISS_OFF}};
-static ISwitch SitesS[]          = {{"Site 1", "", ISS_ON}, {"Site 2", "", ISS_OFF},  {"Site 3", "", ISS_OFF},  {"Site 4", "", ISS_OFF}};
-static ISwitch SlewModeS[]       = {{"Max", "", ISS_ON}, {"Find", "", ISS_OFF}, {"Centering", "", ISS_OFF}, {"Guide", "", ISS_OFF}};
-static ISwitch OnCoordSetS[]     = {{"SLEW", "Slew", ISS_ON }, {"TRACK", "Track", ISS_OFF}, {"SYNC", "Sync", ISS_OFF }};
-static ISwitch TrackModeS[]      = {{ "Default", "", ISS_ON} , { "Lunar", "", ISS_OFF}, {"Manual", "", ISS_OFF}};
-static ISwitch abortSlewS[]      = {{"ABORT", "Abort", ISS_OFF }};
-static ISwitch ParkS[]		 = { {"Park", "", ISS_OFF} };
+static ISwitch PowerS[]          = {{"CONNECT" , "Connect" , ISS_OFF, 0, 0},{"DISCONNECT", "Disconnect", ISS_ON, 0, 0}};
+static ISwitch AlignmentS []     = {{"Polar", "", ISS_ON, 0, 0}, {"AltAz", "", ISS_OFF, 0, 0}, {"Land", "", ISS_OFF, 0, 0}};
+static ISwitch SitesS[]          = {{"Site 1", "", ISS_ON, 0, 0}, {"Site 2", "", ISS_OFF, 0, 0},  {"Site 3", "", ISS_OFF, 0, 0},  {"Site 4", "", ISS_OFF, 0 ,0}};
+static ISwitch SlewModeS[]       = {{"Max", "", ISS_ON, 0, 0}, {"Find", "", ISS_OFF, 0, 0}, {"Centering", "", ISS_OFF, 0, 0}, {"Guide", "", ISS_OFF, 0 , 0}};
+static ISwitch OnCoordSetS[]     = {{"SLEW", "Slew", ISS_ON, 0, 0 }, {"TRACK", "Track", ISS_OFF, 0, 0}, {"SYNC", "Sync", ISS_OFF, 0 , 0}};
+static ISwitch TrackModeS[]      = {{ "Default", "", ISS_ON, 0, 0} , { "Lunar", "", ISS_OFF, 0, 0}, {"Manual", "", ISS_OFF, 0, 0}};
+static ISwitch abortSlewS[]      = {{"ABORT", "Abort", ISS_OFF, 0, 0 }};
+static ISwitch ParkS[]		 = { {"Park", "", ISS_OFF, 0, 0} };
 
-static ISwitch MovementS[]       = {{"N", "North", ISS_OFF}, {"W", "West", ISS_OFF}, {"E", "East", ISS_OFF}, {"S", "South", ISS_OFF}};
+static ISwitch MovementS[]       = {{"N", "North", ISS_OFF, 0, 0}, {"W", "West", ISS_OFF, 0, 0}, {"E", "East", ISS_OFF, 0, 0}, {"S", "South", ISS_OFF, 0, 0}};
 
-static ISwitch	FocusSpeedS[]	 = { {"Halt", "", ISS_ON}, { "Fast", "", ISS_OFF }, {"Slow", "", ISS_OFF}};
-static ISwitch  FocusMotionS[]	 = { {"Focus in", "", ISS_OFF}, {"Focus out", "", ISS_OFF}};
+static ISwitch	FocusSpeedS[]	 = { {"Halt", "", ISS_ON, 0, 0}, { "Fast", "", ISS_OFF, 0, 0}, {"Slow", "", ISS_OFF, 0, 0}};
+static ISwitch  FocusMotionS[]	 = { {"Focus in", "", ISS_OFF, 0, 0}, {"Focus out", "", ISS_OFF, 0, 0}};
 
 /* equatorial position */
 INumber eq[] = {
-    {"RA",  "RA  H:M:S", "%10.6m",  0., 24., 0., 0.},
-    {"DEC", "Dec D:M:S", "%10.6m", -90., 90., 0., 0.},
+    {"RA",  "RA  H:M:S", "%10.6m",  0., 24., 0., 0., 0, 0, 0},
+    {"DEC", "Dec D:M:S", "%10.6m", -90., 90., 0., 0., 0, 0, 0},
 };
 //TODO decide appropiate TIME_OUT
 // N.B. No Static identifier as it is needed for external linkage
 INumberVectorProperty eqNum = {
     mydev, "EQUATORIAL_COORD", "Equatorial J2000", BASIC_GROUP, IP_RW, 0, IPS_IDLE,
-    eq, NARRAY(eq),
-};
+    eq, NARRAY(eq), 0, 0};
 
 /* Fundamental group */
-ISwitchVectorProperty PowerSP		= { mydev, "CONNECTION" , "Connection", COMM_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, PowerS, NARRAY(PowerS)};
-static IText PortT[]			= {{"PORT", "Port", "/dev/ttyS0"}};
-static ITextVectorProperty Port		= { mydev, "DEVICE_PORT", "Ports", COMM_GROUP, IP_RW, 0, IPS_IDLE, PortT, NARRAY(PortT)};
+ISwitchVectorProperty PowerSP		= { mydev, "CONNECTION" , "Connection", COMM_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, PowerS, NARRAY(PowerS), 0, 0};
+static IText PortT[]			= {{"PORT", "Port", 0, 0, 0, 0}};
+static ITextVectorProperty Port		= { mydev, "DEVICE_PORT", "Ports", COMM_GROUP, IP_RW, 0, IPS_IDLE, PortT, NARRAY(PortT), 0, 0};
 
 /* Basic data group */
-static ISwitchVectorProperty AlignmentSw	= { mydev, "Alignment", "", COMM_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, AlignmentS, NARRAY(AlignmentS)};
+static ISwitchVectorProperty AlignmentSw	= { mydev, "Alignment", "", COMM_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, AlignmentS, NARRAY(AlignmentS), 0, 0};
 
 static INumber altLimit[] = {
-       {"minAlt", "min Alt", "%+03f", -90., 90., 0., 0.},
-       {"maxAlt", "max Alt", "%+03f", -90., 90., 0., 0.}};
-static INumberVectorProperty elevationLimit = { mydev, "altLimit", "Slew elevation Limit", BASIC_GROUP, IP_RW, 0, IPS_IDLE, altLimit, NARRAY(altLimit)};
+       {"minAlt", "min Alt", "%+03f", -90., 90., 0., 0., 0, 0, 0},
+       {"maxAlt", "max Alt", "%+03f", -90., 90., 0., 0., 0, 0, 0}};
+static INumberVectorProperty elevationLimit = { mydev, "altLimit", "Slew elevation Limit", BASIC_GROUP, IP_RW, 0, IPS_IDLE, altLimit, NARRAY(altLimit), 0, 0};
 
 /* Movement group */
-static ISwitchVectorProperty OnCoordSetSw    = { mydev, "ON_COORD_SET", "On Set", BASIC_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, OnCoordSetS, NARRAY(OnCoordSetS)};
+static ISwitchVectorProperty OnCoordSetSw    = { mydev, "ON_COORD_SET", "On Set", BASIC_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, OnCoordSetS, NARRAY(OnCoordSetS), 0, 0};
 
-static ISwitchVectorProperty abortSlewSw     = { mydev, "ABORT_MOTION", "Abort Slew/Track", BASIC_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, abortSlewS, NARRAY(abortSlewS)};
+static ISwitchVectorProperty abortSlewSw     = { mydev, "ABORT_MOTION", "Abort Slew/Track", BASIC_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, abortSlewS, NARRAY(abortSlewS), 0, 0};
 
-ISwitchVectorProperty	ParkSP = {mydev, "PARK", "Park Scope", BASIC_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, ParkS, NARRAY(ParkS) };
+ISwitchVectorProperty	ParkSP = {mydev, "PARK", "Park Scope", BASIC_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, ParkS, NARRAY(ParkS), 0, 0 };
 
-static ISwitchVectorProperty SlewModeSw      = { mydev, "Slew rate", "", MOVE_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, SlewModeS, NARRAY(SlewModeS)};
+static ISwitchVectorProperty SlewModeSw      = { mydev, "Slew rate", "", MOVE_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, SlewModeS, NARRAY(SlewModeS), 0, 0};
 
-static ISwitchVectorProperty TrackModeSw  = { mydev, "Tracking Mode", "", MOVE_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, TrackModeS, NARRAY(TrackModeS)};
+static ISwitchVectorProperty TrackModeSw  = { mydev, "Tracking Mode", "", MOVE_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, TrackModeS, NARRAY(TrackModeS), 0, 0};
 
-static INumber TrackFreq[]  = {{ "trackFreq", "Freq", "%g", 50.0, 80.0, 0.1, 60.1}};
+static INumber TrackFreq[]  = {{ "trackFreq", "Freq", "%g", 50.0, 80.0, 0.1, 60.1, 0, 0, 0}};
 
-static INumberVectorProperty TrackingFreq= { mydev, "Tracking Frequency", "", MOVE_GROUP, IP_RW, 0, IPS_IDLE, TrackFreq, NARRAY(TrackFreq)};
+static INumberVectorProperty TrackingFreq= { mydev, "Tracking Frequency", "", MOVE_GROUP, IP_RW, 0, IPS_IDLE, TrackFreq, NARRAY(TrackFreq), 0, 0};
 
-static ISwitchVectorProperty MovementSw      = { mydev, "MOVEMENT", "Move toward", MOVE_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, MovementS, NARRAY(MovementS)};
+static ISwitchVectorProperty MovementSw      = { mydev, "MOVEMENT", "Move toward", MOVE_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, MovementS, NARRAY(MovementS), 0, 0};
 
 // Focus Control
-static ISwitchVectorProperty	FocusSpeedSw  = {mydev, "Speed", "", FOCUS_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, FocusSpeedS, NARRAY(FocusSpeedS)};
+static ISwitchVectorProperty	FocusSpeedSw  = {mydev, "Speed", "", FOCUS_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, FocusSpeedS, NARRAY(FocusSpeedS), 0, 0};
 
-static ISwitchVectorProperty	FocusMotionSw = {mydev, "Motion", "", FOCUS_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, FocusMotionS, NARRAY(FocusMotionS)};
+static ISwitchVectorProperty	FocusMotionSw = {mydev, "Motion", "", FOCUS_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, FocusMotionS, NARRAY(FocusMotionS), 0, 0};
 
 /* Data & Time */
-static IText UTC[] = {{"UTC", "UTC", "YYYY-MM-DDTHH:MM:SS"}};
-ITextVectorProperty Time = { mydev, "TIME", "UTC Time", DATETIME_GROUP, IP_RW, 0, IPS_IDLE, UTC, NARRAY(UTC)};
-static INumber STime[] = {{"LST", "Sidereal time", "%10.6m" , 0.,0.,0.,0.}};
-INumberVectorProperty SDTime = { mydev, "SDTIME", "Sidereal Time", DATETIME_GROUP, IP_RW, 0, IPS_IDLE, STime, NARRAY(STime)};
+static IText UTC[] = {{"UTC", "UTC", 0, 0, 0, 0}};
+ITextVectorProperty Time = { mydev, "TIME", "UTC Time", DATETIME_GROUP, IP_RW, 0, IPS_IDLE, UTC, NARRAY(UTC), 0, 0};
+static INumber STime[] = {{"LST", "Sidereal time", "%10.6m" , 0.,24.,0.,0., 0, 0, 0}};
+INumberVectorProperty SDTime = { mydev, "SDTIME", "Sidereal Time", DATETIME_GROUP, IP_RW, 0, IPS_IDLE, STime, NARRAY(STime), 0, 0};
 
 
 /* Site managment */
-static ISwitchVectorProperty SitesSw  = { mydev, "Sites", "", SITE_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, SitesS, NARRAY(SitesS)};
+static ISwitchVectorProperty SitesSw  = { mydev, "Sites", "", SITE_GROUP, IP_RW, ISR_1OFMANY, 0, IPS_IDLE, SitesS, NARRAY(SitesS), 0, 0};
 /* geographic location */
 static INumber geo[] = {
-    {"LAT",  "Lat.  D:M:S +N", "%10.6m",  -90.,  90., 0., 0.},
-    {"LONG", "Long. D:M:S +E", "%10.6m", 0., 360., 0., 0.},
+    {"LAT",  "Lat.  D:M:S +N", "%10.6m",  -90.,  90., 0., 0., 0, 0, 0},
+    {"LONG", "Long. D:M:S +E", "%10.6m", 0., 360., 0., 0., 0, 0, 0},
 };
 static INumberVectorProperty geoNum = {
     mydev, "GEOGRAPHIC_COORD", "Geographic Location", SITE_GROUP, IP_RW, 0., IPS_IDLE,
-    geo, NARRAY(geo),
-};
-static IText   SiteNameT[] = {{"SiteName", "", ""}};
-static ITextVectorProperty SiteName = { mydev, "Site Name", "", SITE_GROUP, IP_RW, 0 , IPS_IDLE, SiteNameT, NARRAY(SiteNameT)};
+    geo, NARRAY(geo), 0, 0};
+static IText   SiteNameT[] = {{"SiteName", "", 0, 0, 0, 0}};
+static ITextVectorProperty SiteName = { mydev, "Site Name", "", SITE_GROUP, IP_RW, 0 , IPS_IDLE, SiteNameT, NARRAY(SiteNameT), 0, 0};
 
-void changeLX200GenericDeviceName(char * newName)
+void changeLX200GenericDeviceName(const char * newName)
 {
   strcpy(PowerSP.device , newName);
   strcpy(Port.device , newName);
@@ -177,7 +175,7 @@ void changeLX200GenericDeviceName(char * newName)
   
 }
 
-void changeAllDeviceNames(char *newName)
+void changeAllDeviceNames(const char *newName)
 {
   changeLX200GenericDeviceName(newName);
   changeLX200AutostarDeviceName(newName);
@@ -198,6 +196,9 @@ void ISInit()
  isInit = 1;
 
  
+  PortT[0].text = strcpy(new char[32], "/dev/ttyS0");
+  UTC[0].text   = strcpy(new char[32], "YYYY-MM-DDTHH:MM:SS");
+  
   if (strstr(me, "lx200classic"))
   {
      fprintf(stderr , "initilizaing from LX200 classic device...\n");
@@ -205,7 +206,7 @@ void ISInit()
      changeAllDeviceNames("LX200 Classic");
      // 2. device = sub_class
      telescope = new LX200Classic();
-     telescope->setCurrectDeviceName("LX200 Classic");
+     telescope->setCurrentDeviceName("LX200 Classic");
 
      MaxReticleFlashRate = 3;
   }
@@ -217,7 +218,7 @@ void ISInit()
      changeAllDeviceNames("LX200 GPS");
      // 2. device = sub_class
      telescope = new LX200GPS();
-     telescope->setCurrectDeviceName("LX200 GPS");
+     telescope->setCurrentDeviceName("LX200 GPS");
 
      MaxReticleFlashRate = 9;
   }
@@ -229,7 +230,7 @@ void ISInit()
     changeAllDeviceNames("LX200 16");
     // 2. device = sub_class
    telescope = new LX200_16();
-   telescope->setCurrectDeviceName("LX200 16");
+   telescope->setCurrentDeviceName("LX200 16");
 
    MaxReticleFlashRate = 3;
  }
@@ -241,7 +242,7 @@ void ISInit()
    changeAllDeviceNames("LX200 Autostar");
    // 2. device = sub_class
    telescope = new LX200Autostar();
-   telescope->setCurrectDeviceName("LX200 Autostar");
+   telescope->setCurrentDeviceName("LX200 Autostar");
 
    MaxReticleFlashRate = 9;
  }
@@ -249,7 +250,7 @@ void ISInit()
  else
  {
   telescope = new LX200Generic();
-  telescope->setCurrectDeviceName("LX200 Generic");
+  telescope->setCurrentDeviceName("LX200 Generic");
  }
 
 }
@@ -280,6 +281,7 @@ LX200Generic::LX200Generic()
    trackingMode   = LX200_TRACK_DEFAULT;
    lastSet        = -1;
    fault          = false;
+   simulation     = false;
    targetRA       = 0;
    targetDEC      = 0;
    currentRA      = 0;
@@ -299,7 +301,7 @@ LX200Generic::LX200Generic()
    IDLog("initilizaing from generic LX200 device...\n");
 }
 
-void LX200Generic::setCurrectDeviceName(const char * devName)
+void LX200Generic::setCurrentDeviceName(const char * devName)
 {
   strcpy(thisDevice, devName);
 
@@ -312,8 +314,8 @@ void LX200Generic::ISGetProperties(const char *dev)
     return;
 
   // COMM_GROUP
-  IDDefText   (&Port, NULL);
   IDDefSwitch (&PowerSP, NULL);
+  IDDefText   (&Port, NULL);
   IDDefSwitch (&AlignmentSw, NULL);
 
   // BASIC_GROUP
@@ -341,12 +343,16 @@ void LX200Generic::ISGetProperties(const char *dev)
   IDDefSwitch (&SitesSw, NULL);
   IDDefText   (&SiteName, NULL);
   IDDefNumber (&geoNum, NULL);
+  
+  /* Send the basic data to the new client if the previous client(s) are already connected. */		
+   if (PowerSP.s == IPS_OK)
+       getBasicData();
 
 }
 
 void LX200Generic::ISNewText (const char *dev, const char *name, char *texts[], char *names[], int n)
 {
-	double UTCOffset;
+	double UTCOffset, dayDiff;
 	int err;
 	struct tm *ltp = new tm;
 	struct tm utm;
@@ -409,11 +415,14 @@ void LX200Generic::ISNewText (const char *dev, const char *name, char *texts[],
 		utm.tm_year  += 1900;
 		ltp->tm_year += 1900;
 
-	  	UTCOffset = (utm.tm_hour - ltp->tm_hour);
-
-		if (utm.tm_mday - ltp->tm_mday != 0)
-			 UTCOffset += 24;
-
+	        
+                dayDiff = utm.tm_mday - ltp->tm_mday;
+		if (dayDiff == 0)
+		   UTCOffset = (ltp->tm_hour - utm.tm_hour);  
+		else if (dayDiff > 0)
+		   UTCOffset = ltp->tm_hour - utm.tm_hour - 24;
+		else UTCOffset = ltp->tm_hour - utm.tm_hour + 24;
+		
 		IDLog("time is %02d:%02d:%02d\n", ltp->tm_hour, ltp->tm_min, ltp->tm_sec);
 		
 		getSDTime(&STime[0].value);
@@ -1075,7 +1084,6 @@ void LX200Generic::ISNewSwitch (const char *dev, const char *name, ISState *stat
 
 void LX200Generic::handleError(ISwitchVectorProperty *svp, int err, const char *msg)
 {
-  char errmsg[1024];
   
   svp->s = IPS_ALERT;
   
@@ -1108,7 +1116,6 @@ void LX200Generic::handleError(ISwitchVectorProperty *svp, int err, const char *
 
 void LX200Generic::handleError(INumberVectorProperty *nvp, int err, const char *msg)
 {
-  char errmsg[1024];
   
   nvp->s = IPS_ALERT;
   
@@ -1141,7 +1148,6 @@ void LX200Generic::handleError(INumberVectorProperty *nvp, int err, const char *
 
 void LX200Generic::handleError(ITextVectorProperty *tvp, int err, const char *msg)
 {
-  char errmsg[1024];
   
   tvp->s = IPS_ALERT;
   
@@ -1183,6 +1189,8 @@ void LX200Generic::handleError(ITextVectorProperty *tvp, int err, const char *ms
 
 bool LX200Generic::isTelescopeOn(void)
 {
+  if (simulation) return true;
+  
   return (PowerSP.sp[0].s == ISS_ON);
 }
 
@@ -1565,9 +1573,15 @@ int LX200Generic::getOnSwitch(ISwitchVectorProperty *sp)
 
 int LX200Generic::checkPower(ISwitchVectorProperty *sp)
 {
+  if (simulation) return 0;
+  
   if (PowerSP.s != IPS_OK)
   {
-    IDMessage (thisDevice, "Cannot change a property while the telescope is offline.");
+    if (!strcmp(sp->label, ""))
+    	IDMessage (thisDevice, "Cannot change property %s while the telescope is offline.", sp->name);
+    else
+        IDMessage (thisDevice, "Cannot change property %s while the telescope is offline.", sp->label);
+	
     sp->s = IPS_IDLE;
     IDSetSwitch(sp, NULL);
     return -1;
@@ -1578,10 +1592,16 @@ int LX200Generic::checkPower(ISwitchVectorProperty *sp)
 
 int LX200Generic::checkPower(INumberVectorProperty *np)
 {
-
+  if (simulation) return 0;
+  
   if (PowerSP.s != IPS_OK)
   {
-    IDMessage (thisDevice, "Cannot change a property while the telescope is offline.");
+    
+    if (!strcmp(np->label, ""))
+    	IDMessage (thisDevice, "Cannot change property %s while the telescope is offline.", np->name);
+    else
+        IDMessage (thisDevice, "Cannot change property %s while the telescope is offline.", np->label);
+	
     np->s = IPS_IDLE;
     IDSetNumber(np, NULL);
     return -1;
@@ -1594,9 +1614,15 @@ int LX200Generic::checkPower(INumberVectorProperty *np)
 int LX200Generic::checkPower(ITextVectorProperty *tp)
 {
 
+  if (simulation) return 0;
+  
   if (PowerSP.s != IPS_OK)
   {
-    IDMessage (thisDevice, "Cannot change a property while the telescope is offline.");
+    if (!strcmp(tp->label, ""))
+    	IDMessage (thisDevice, "Cannot change property %s while the telescope is offline.", tp->name);
+    else
+        IDMessage (thisDevice, "Cannot change property %s while the telescope is offline.", tp->label);
+	
     tp->s = IPS_IDLE;
     IDSetText(tp, NULL);
     return -1;
@@ -1694,3 +1720,13 @@ void LX200Generic::getAlignment()
     IDSetSwitch (&AlignmentSw, NULL);
     IDLog("ACK success %c\n", align);
 }
+
+void LX200Generic::enableSimulation(bool enable)
+{
+   simulation = enable;
+   
+   if (simulation)
+     IDLog("Warning: Simulation is activated.\n");
+   else
+     IDLog("Simulation is disabled.\n");
+}
