@@ -17,12 +17,18 @@
 #include "indidriver.h"
 #include "indimenu.h"
 #include "indihostconf.h"
+#include "devicemanager.h"
+#include "indidevice.h"
 
 #include "kstars.h"
+#include "kstarsdata.h"
 #include "ksutils.h"
 
+#include <qfile.h>
 #include <qvaluelist.h>
 #include <qcstring.h>
+#include <qradiobutton.h>
+#include <qtextedit.h>
 
 #include <kiconloader.h>
 #include <klistview.h>
@@ -31,6 +37,8 @@
 #include <kmessagebox.h>
 #include <kpushbutton.h>
 #include <klineedit.h>
+#include <kstandarddirs.h>
+#include <kaction.h>
 
 #include <kextsock.h>
 #include <unistd.h>
@@ -57,6 +65,8 @@ INDIDriver::INDIDriver(QWidget *parent) : devManager( parent )
     KIconLoader *icons = KGlobal::iconLoader();
     runningPix = icons->loadIcon( "exec", KIcon::Small);
     stopPix    = icons->loadIcon( "button_cancel", KIcon::Small);
+    localMode  = icons->loadIcon( "network_local", KIcon::Small);
+    serverMode = icons->loadIcon( "network", KIcon::Small);
 
     LocalpopMenu = new KPopupMenu(localListView);
     LocalpopMenu->insertItem( runningPix, i18n("Run Service") , 0);
@@ -127,9 +137,29 @@ for (uint i=0; i < ksw->data()->INDIHostsList.count(); i++)
         affectedItem->setPixmap(0, disconnected);
 	connectHostB->setEnabled(true);
         disconnectHostB->setEnabled(false);
-	break;
+	return;
      }
  }
+ 
+  for (uint i=0; i < devices.size(); i++)
+  {
+    if (devices[i]->mgrID == mgrID)
+    {
+      affectedItem = localListView->findItem(devices[i]->label, 0);
+      if (!affectedItem) return;
+      affectedItem->setPixmap(1, stopPix);
+      affectedItem->setPixmap(2, NULL);
+      affectedItem->setText(4, QString(""));
+      runServiceB->setEnabled(true);
+      stopServiceB->setEnabled(false);
+      devices[i]->managed = false;
+      devices[i]->restart();
+      return;
+	
+    }
+  }
+      
+          
 }
 
 void INDIDriver::ClientprocessRightButton( QListViewItem *item, const QPoint &p, int column)
@@ -181,6 +211,12 @@ void INDIDriver::updateLocalButtons()
      {
 	runServiceB->setEnabled(devices[i]->state == 0);
 	stopServiceB->setEnabled(devices[i]->state == 1);
+	
+	serverLogText->clear();
+	
+	for ( QStringList::Iterator it = devices[i]->serverBuffer.begin(); it != devices[i]->serverBuffer.end(); ++it )
+	   serverLogText->insert(*it);
+	
 	break;
      }
 
@@ -215,43 +251,52 @@ void INDIDriver::processDeviceStatus(int id)
    for (uint i=0; i < devices.size(); i++)
      if (localListView->selectedItem()->text(0) == devices[i]->label)
      {
-	devices[i]->state = id == 0 ? 1 : 0;
+	devices[i]->state = (id == 0) ? 1 : 0;
 	if (devices[i]->state)
 	{
 
 	  ksw->getINDIMenu()->setCustomLabel(devices[i]->label);
 	  devices[i]->label = ksw->getINDIMenu()->currentLabel;
 
+	  devices[i]->serverBuffer.clear();
+	  
 	  if (!runDevice(devices[i]))
 	  {
 	   devices[i]->restart();
 	   return;
 	  }
 
-	  //Allow time for the INDI server to listen
-	  usleep(50000);
-
-	  if (!ksw->getINDIMenu()->processServer())
+	  if (devices[i]->mode == IDevice::M_LOCAL)
 	  {
-	   devices[i]->restart();
-	   return;
+	       //Allow time for the INDI server to listen
+	  	usleep(50000);
+
+	  	if (!ksw->getINDIMenu()->processServer())
+	  	{
+	   		devices[i]->restart();
+	   		return;
+	  	}
 	  }
 
 	  localListView->selectedItem()->setPixmap(1, runningPix);
-
-	  localListView->selectedItem()->setText(3, QString("%1").arg(devices[i]->indiPort));
+	  localListView->selectedItem()->setText(4, QString("%1").arg(devices[i]->indiPort));
 	  runServiceB->setEnabled(false);
 	  stopServiceB->setEnabled(true);
+	  
 	  return;
 	}
-
-	  ksw->getINDIMenu()->processServer();
+	
+	  if (devices[i]->mode == IDevice::M_LOCAL)
+	  	ksw->getINDIMenu()->processServer();
+		
 	  localListView->selectedItem()->setPixmap(1, stopPix);
-	  localListView->selectedItem()->setText(3, QString(""));
+	  localListView->selectedItem()->setPixmap(2, NULL);
+	  localListView->selectedItem()->setText(4, QString(""));
 	  runServiceB->setEnabled(true);
 	  stopServiceB->setEnabled(false);
 	  devices[i]->restart();
-	return;
+	  updateMenuActions();
+	  return;
      }
 }
 
@@ -263,11 +308,6 @@ void INDIDriver::processHostStatus(int id)
    if (!currentItem) return;
    INDIHostsInfo *hostInfo;
 
-   //kdDebug() << "The INDI host size is " << ksw->data()->INDIHostsList.count() << endl;
-   //for (uint i=0; i < ksw->data()->INDIHostsList.count(); i++)
-     //kdDebug() << "The name is " << ksw->data()->INDIHostsList.at(i)->name << endl;
-
-
    for (uint i=0; i < ksw->data()->INDIHostsList.count(); i++)
    {
      hostInfo = ksw->data()->INDIHostsList.at(i);
@@ -298,20 +338,66 @@ void INDIDriver::processHostStatus(int id)
 	  currentItem->setPixmap(0, disconnected);
 	  connectHostB->setEnabled(true);
 	  disconnectHostB->setEnabled(false);
+	  updateMenuActions();
 	}
+	
+	
 
-
-     }
+       }
     }
 }
 
-bool INDIDriver::runDevice(INDIDriver::IDevice *dev)
+void INDIDriver::updateMenuActions()
+{
+  // We iterate over devices, we enable INDI Control Panel if we have any active device
+  // We enable capture image sequence if we have any imaging device
+  
+  KAction *tmpAction;
+  INDIMenu *devMenu = ksw->getINDIMenu();
+  bool activeDevice = false;
+  bool activeImaging = false;
+  INDI_P *imgProp = NULL;
+  
+  if (devMenu == NULL)
+     return;
+  
+  if (devMenu->mgr.count() > 0)
+   activeDevice = true;
+   
+  for (uint i=0; i < devMenu->mgr.count(); i++)
+  {
+	for (uint j=0; j < devMenu->mgr.at(i)->indi_dev.count(); j++)
+	{
+  		        imgProp = devMenu->mgr.at(i)->indi_dev.at(j)->findProp("EXPOSE_DURATION");
+			if (imgProp && devMenu->mgr.at(i)->indi_dev.at(j)->isOn())
+			{
+			  activeImaging = true;
+			  break;
+			}
+	}
+  }
+   
+  tmpAction = ksw->actionCollection()->action("indi_control_panel");
+  if (!tmpAction)
+  	kdDebug() << "Warning: indi_control_panel action not found" << endl;
+  else
+  	tmpAction->setEnabled(activeDevice);
+  
+  tmpAction = ksw->actionCollection()->action("capture_sequence");
+  if (!tmpAction)
+  	kdDebug() << "Warning: capture_sequence action not found" << endl;
+  else
+  	tmpAction->setEnabled(activeImaging);
+  
+}
+
+bool INDIDriver::runDevice(IDevice *dev)
 {
   dev->indiPort = getINDIPort();
 
   if (dev->indiPort < 0)
   {
-   KMessageBox::error(0, i18n("Cannot start INDI server : port error."));
+   KMessageBox::error(0, i18n("Cannot start INDI server: port error."));
    return false;
   }
 
@@ -319,33 +405,24 @@ bool INDIDriver::runDevice(INDIDriver::IDevice *dev)
   
   *dev->proc << "indiserver";
   *dev->proc << "-v" << "-r" << "0" << "-p" << QString("%1").arg(dev->indiPort) << dev->exec;
+  
+  // Check Mode
+  dev->mode = localR->isChecked() ? IDevice::M_LOCAL : IDevice::M_SERVER;
+  
+  if (dev->mode == IDevice::M_LOCAL)
+    localListView->selectedItem()->setPixmap(2, localMode);
+  else
+    localListView->selectedItem()->setPixmap(2, serverMode);
 
-  //connect(dev->proc, SIGNAL(receivedStderr (KProcess *, char *, int)), this, SLOT(processstd(KProcess *, char*, int)));
+  connect(dev->proc, SIGNAL(receivedStderr (KProcess *, char *, int)),  dev, SLOT(processstd(KProcess *, char*, int)));
 
-  //dev->proc->start(KProcess::NotifyOnExit, KProcess::Stderr);
-  dev->proc->start();
+  dev->proc->start(KProcess::NotifyOnExit, KProcess::Stderr);
+  //dev->proc->start();
   
   return (dev->proc->isRunning());
 }
 
-void INDIDriver::processstd(KProcess *proc, char* buffer, int buflen)
-{
-  //fprintf(stderr, "Receving the following error from child \n\n %s\n", buffer);
-
-  /*typedef QValueList<QCString> strlist;
-
-  strlist list(proc->args());
-
-  strlist::iterator it;
-
-  for (it = list.begin(); it != list.end(); ++it)
-  {
-    QString thing((*it));
-    fprintf(stderr, "%s ", thing.ascii());
-  }*/
-}
-
-void INDIDriver::removeDevice(INDIDriver::IDevice *dev)
+void INDIDriver::removeDevice(IDevice *dev)
 {
 
   for (unsigned int i=0 ; i < devices.size(); i++)
@@ -444,7 +521,7 @@ bool INDIDriver::buildDeviceGroup(XMLEle *root, char errmsg[])
   XMLAtt *ap;
   XMLEle *ep;
   QString groupName;
-  int groupType;
+  int groupType = KSTARS_TELESCOPE;
 
   // Get device grouping name
   ap = findXMLAtt(root, "group");
@@ -465,6 +542,8 @@ bool INDIDriver::buildDeviceGroup(XMLEle *root, char errmsg[])
     groupType = KSTARS_TELESCOPE;
   else if (groupName.find("CCDs") != -1)
     groupType = KSTARS_CCD;
+  else if (groupName.find("Video") != -1)
+    groupType = KSTARS_VIDEO;
   else if (groupName.find("Focusers") != -1)
     groupType = KSTARS_FOCUSER;
   else if (groupName.find("Domes") != -1)
@@ -538,12 +617,13 @@ bool INDIDriver::buildDriverElement(XMLEle *root, QListViewItem *DGroup, int gro
 
   device->setText(0, QString(label));
   device->setPixmap(1, stopPix);
-  device->setText(2, QString(version));
+  device->setText(3, QString(version));
 
   lastDevice = device;
 
   dv = new IDevice(QString(label), QString(driver), QString(exec), QString(version));
   dv->deviceType = groupType;
+  connect(dv, SIGNAL(newServerInput()), this, SLOT(updateLocalButtons()));
   
   devices.push_back(dv);
 
@@ -556,49 +636,12 @@ bool INDIDriver::buildDriverElement(XMLEle *root, QListViewItem *DGroup, int gro
   return true;
 }
 
-INDIDriver::IDevice::IDevice(QString inLabel, QString inDriver, QString inExec, QString inVersion)
-{
-  label = inLabel;;
-  driver = inDriver;;
-  exec = inExec;
-  version = inVersion;
-
-  // Initially off
-  state = 0;
-
-  // No port initially
-  indiPort = -1;
-
-  // not yet managed by DeviceManager
-  managed = false;
-
-  mgrID = -1;
-
-  proc = NULL;
-
-}
-
-INDIDriver::~INDIDriver()
-{
-
-  for (uint i=0; i < devices.size(); i++)
-   delete (devices[i]);
-
-}
-
-INDIDriver::IDevice::~IDevice()
-{
-  if (proc)
-      proc->kill();
-
-}
-
 int INDIDriver::activeDriverCount()
 {
   int count = 0;
 
   for (uint i=0; i < devices.size(); i++)
-    if (devices[i]->state)
+    if (devices[i]->state && devices[i]->mode == IDevice::M_LOCAL)
       count++;
 
   for (uint i=0; i < ksw->data()->INDIHostsList.count(); i++)
@@ -610,23 +653,6 @@ int INDIDriver::activeDriverCount()
 
 }
 
-void INDIDriver::IDevice::restart()
-{
-
-  mgrID = -1;
-
-  state = 0;
-
-  indiPort = -1;
-
-  if (proc)
-  	proc->kill();
-
-  proc = NULL;
-
-}
-
-
 void INDIDriver::addINDIHost()
 {
   INDIHostConf hostConf(this);
@@ -752,7 +778,7 @@ void INDIDriver::saveHosts()
  if ( !file.open( IO_WriteOnly))
  {
   QString message = i18n( "unable to write to file 'indihosts.xml'\nAny changes to INDI hosts configurations will not be saved." );
- KMessageBox::sorry( 0, message, i18n( "Could not Open File" ) );
+ KMessageBox::sorry( 0, message, i18n( "Could Not Open File" ) );
   return;
  }
 
@@ -777,4 +803,64 @@ void INDIDriver::saveHosts()
 
 }
 
+INDIDriver::~INDIDriver()
+{
+
+  for (uint i=0; i < devices.size(); i++)
+   delete (devices[i]);
+
+}
+
+IDevice::IDevice(QString inLabel, QString inDriver, QString inExec, QString inVersion)
+{
+  label = inLabel;;
+  driver = inDriver;;
+  exec = inExec;
+  version = inVersion;
+
+  // Initially off
+  state = 0;
+
+  // No port initially
+  indiPort = -1;
+
+  // not yet managed by DeviceManager
+  managed = false;
+
+  mgrID = -1;
+
+  proc = NULL;
+
+}
+
+void IDevice::processstd(KProcess */*proc*/, char* buffer, int /*buflen*/)
+{
+  serverBuffer.append(buffer);
+  emit newServerInput();
+}
+
+
+IDevice::~IDevice()
+{
+  if (proc)
+      proc->kill();
+
+}
+
+void IDevice::restart()
+{
+
+  mgrID = -1;
+
+  state = 0;
+
+  indiPort = -1;
+
+  if (proc)
+  	proc->kill();
+
+  proc = NULL;
+
+}
+
 #include "indidriver.moc"
