@@ -22,16 +22,18 @@
 #include <qstring.h>
 #include <qptrlist.h>
 #include <qimage.h>
-#include <qwmatrix.h>
 
 #include <kdebug.h>
 
 #include "skyobject.h"
 #include "dms.h"
-#include "ksnumbers.h"
 
 #define MAXTRAIL 400  //maximum number of points in a planet trail
 
+class QPoint;
+class KSNumbers;
+class KSPopupMenu;
+
 /**@class EclipticPosition
 	*@short The ecliptic position of a planet (Longitude, Latitude, and distance from Sun).
 	*@author Mark Hollomon
@@ -57,12 +59,12 @@ class EclipticPosition {
 };
 
 /**@class KSPlanetBase
-	*@short Provides necessary information about objects in the solar system.
-	*@author Mark Hollomon
-	*@version 1.0
 	*A subclass of SkyObject that provides additional information
 	*needed for solar system objects. This is a base class for KSPlanet,
 	* KSPluto, KSSun and KSMoon.
+	*@short Provides necessary information about objects in the solar system.
+	*@author Mark Hollomon
+	*@version 1.0
 	*/
 
 class KStarsData;
@@ -73,15 +75,15 @@ public:
 	*coordinates=0.0, mag=0.0, primary name s, and all other QStrings empty.
 	*@param s Name of planet
 	*@param im the planet's image
+	*@param pSize the planet's physical size, in km
 	*/
-	KSPlanetBase( KStarsData *kd, QString s = i18n("unnamed"), QString image_file="" );
+	KSPlanetBase( KStarsData *kd, QString s = i18n("unnamed"), QString image_file="", double pSize=0 );
 
 /**
 	*Destructor (empty)
 	*/
 	virtual ~KSPlanetBase() {}
 
-
 /**@return pointer to Ecliptic Longitude coordinate
 	*/
 	const dms* ecLong( void ) const { return &ep.longitude; };
@@ -209,7 +211,7 @@ public:
 
 /**@return the Planet's position angle.
 	*/
-		double pa() const { return PositionAngle; }
+		virtual double pa() const { return PositionAngle; }
 
 /**@short Set the Planet's position angle.
 	*@param p the new position angle
@@ -220,10 +222,19 @@ public:
 	*/
 		double angSize() const { return AngularSize; }
 
-/**@short Set the Planet's angular size in arcminutes
-	*@param a the new angular size
+/**@short set the planet's angular size, in km.
+	*@p size the planet's size, in km
 	*/
-		void setAngSize( double a ) { AngularSize = a; }
+	void setAngularSize( double size ) { AngularSize = size; }
+
+/**@return the Planet's physical size, in km
+	*/
+		double physicalSize() const { return PhysicalSize; }
+
+/**@short set the planet's physical size, in km.
+	*@p size the planet's size, in km
+	*/
+	void setPhysicalSize( double size ) { PhysicalSize = size; }
 
 /**@return whether the planet has a trail
 	*/
@@ -261,6 +272,13 @@ public:
 	*/
 	void scaleRotateImage( int scale, double imageAngle );
 
+/**Show Solar System object popup menu.  Overloaded from virtual 
+	*SkyObject::showPopupMenu()
+	*@param pmenu pointer to the KSPopupMenu object
+	*@param pos QPojnt holding the x,y coordinates for the menu
+	*/
+	virtual void showPopupMenu( KSPopupMenu *pmenu, QPoint pos ) { pmenu->createPlanetMenu( this ); pmenu->popup( pos ); }
+
 protected:
 	virtual bool loadData(QString n) {
 		kdDebug() << "didn't reimplement for " << n << endl; return false;
@@ -281,7 +299,7 @@ protected:
 	*/
 	void findPA( const KSNumbers *num );
 
-		// Geocentric ecliptic position, but distance to the Sun
+	// Geocentric ecliptic position, but distance to the Sun
 	EclipticPosition ep;
 
 	// Heliocentric ecliptic position referred to the equinox of the epoch 
@@ -302,7 +320,7 @@ private:
 	void localizeCoords( const KSNumbers *num, const dms *lat, const dms *LST );
 
 	QImage Image0, Image;
-	double PositionAngle, ImageAngle, AngularSize;
+	double PositionAngle, ImageAngle, AngularSize, PhysicalSize;
 	KStarsData *data;
 };
 
