@@ -19,54 +19,70 @@
 #include <sys/stat.h>
 
 #include <kdebug.h>
+#include <kaction.h>
+#include <kactionclasses.h>
+#include <klineedit.h>
 #include <kshortcut.h>
 #include <kiconloader.h>
 #include <kio/netaccess.h>
 #include <kmessagebox.h>
-#include <kprinter.h>
 #include <ktempfile.h>
 #include <ktip.h>
+#include <kstandarddirs.h>
+#include <kconfigdialog.h>
 #include <kfiledialog.h>
-#include <kpopupmenu.h>
-#include <kprocess.h>
-#include <qpaintdevicemetrics.h>
-#include <qradiobutton.h>
-#include <qcheckbox.h>
-
-//keep KDE 3.0.x and 3.1.x compatibility
-//KDE_VERSION changed from decimal to hex during KDE 3.1.x, so have to use
-//the MAJOR/MINOR/RELEASE triplet.  We can assume KDE_VERSION_MAJOR >= 3.
-//for KDE_VERSION_RELEASE, I believe the post 3_1_BRANCH stuff started at 90,
-//but I'll use 20 just in case (the highest 3.1.x will likely be x=4).
-#include <kdeversion.h>
-#if ( KDE_VERSION_MINOR >= 1 && KDE_VERSION_RELEASE > 20 )
 #include <kinputdialog.h>
-#else
-#include <klineeditdlg.h>
-#include <qvalidator.h>
-#endif
+#include <kpopupmenu.h>
+#include <kstatusbar.h>
+#include <kprocess.h>
+#include <qcheckbox.h>
+#include <qdir.h>
+#include <kdeversion.h>
 
+#include "opscatalog.h"
+#include "opsguides.h"
+#include "opssolarsystem.h"
+#include "opscolors.h"
+#include "opsadvanced.h"
+
+#include "Options.h"
 #include "kstars.h"
+#include "kstarsdata.h"
+#include "kstarsdatetime.h"
+#include "skymap.h"
+#include "skyobject.h"
+#include "skyobjectname.h"
+#include "ksplanetbase.h"
+#include "ksasteroid.h"
+#include "kscomet.h"
+#include "ksmoon.h"
+#include "simclock.h"
+#include "infoboxes.h"
+#include "toggleaction.h"
 #include "timedialog.h"
 #include "locationdialog.h"
 #include "finddialog.h"
 #include "focusdialog.h"
 #include "fovdialog.h"
-#include "viewopsdialog.h"
-#include "astrocalc.h"
-#include "lcgenerator.h"
-#include "infoboxes.h"
-#include "ksutils.h"
-#include "altvstime.h"
-#include "wutdialog.h"
-#include "indimenu.h"
+#include "kswizard.h"
+#include "tools/lcgenerator.h"
+#include "tools/astrocalc.h"
+#include "tools/altvstime.h"
+#include "tools/wutdialog.h"
+#include "tools/scriptbuilder.h"
+#include "tools/planetviewer.h"
+#include "tools/jmoontool.h"
 #include "devmanager.h"
+#include "indimenu.h"
 #include "indidriver.h"
-#include "scriptbuilder.h"
-#include "indiconf.h"
-#include "planetviewer.h"
-#include "jmoontool.h"
+#include "indifitsconf.h"
 #include "telescopewizardprocess.h"
+#include "fitsviewer.h"
+
+#if ( KDE_IS_VERSION( 3, 2, 90 ) )
+#include "ksnewstuff.h"
+#endif  // KDE >= 3.2.90
+#include "imagesequence.h"
 
 //This file contains function definitions for Actions declared in kstars.h
 
@@ -75,21 +91,23 @@
 void KStars::slotViewToolBar() {
 
 	if ( sender()->name() == QString( "show_stars" ) ) {
-		options()->drawSAO = !options()->drawSAO;
+		Options::setShowStars( !Options::showStars() );
 	} else if ( sender()->name() == QString( "show_deepsky" ) ) {
-		options()->drawDeepSky = !options()->drawDeepSky;
+		Options::setShowDeepSky( ! Options::showDeepSky() );
 	} else if ( sender()->name() == QString( "show_planets" ) ) {
-		options()->drawPlanets = !options()->drawPlanets;
+		Options::setShowPlanets( ! Options::showPlanets() );
 	} else if ( sender()->name() == QString( "show_clines" ) ) {
-		options()->drawConstellLines = !options()->drawConstellLines;
+		Options::setShowCLines( !Options::showCLines() );
 	} else if ( sender()->name() == QString( "show_cnames" ) ) {
-		options()->drawConstellNames = !options()->drawConstellNames;
+		Options::setShowCNames( !Options::showCNames() );
+	} else if ( sender()->name() == QString( "show_cbounds" ) ) {
+		Options::setShowCBounds( !Options::showCBounds() );
 	} else if ( sender()->name() == QString( "show_mw" ) ) {
-		options()->drawMilkyWay = !options()->drawMilkyWay;
+		Options::setShowMilkyWay( !Options::showMilkyWay() );
 	} else if ( sender()->name() == QString( "show_grid" ) ) {
-		options()->drawGrid = !options()->drawGrid;
+		Options::setShowGrid( !Options::showGrid() );
 	} else if ( sender()->name() == QString( "show_horizon" ) ) {
-		options()->drawGround = !options()->drawGround;
+		Options::setShowGround( !Options::showGround() );
 	}
 
 	// update time for all objects because they might be not initialized
@@ -107,6 +125,51 @@ void KStars::slotCalculator() {
 	astrocalc.exec();
 }
 
+void KStars::slotWizard() {
+	KSWizard wizard(this);
+	if ( wizard.exec() == QDialog::Accepted ) {
+		Options::setRunStartupWizard( false );  //don't run on startup next time
+		
+		data()->setLocation( wizard.geo() );
+
+		// reset infoboxes
+		infoBoxes()->geoChanged( geo() );
+
+		// adjust local time to keep UT the same.
+		// create new LT without DST offset
+		KStarsDateTime ltime = geo()->UTtoLT( data()->ut() );
+
+		// reset timezonerule to compute next dst change
+		geo()->tzrule()->reset_with_ltime( ltime, geo()->TZ0(), data()->isTimeRunningForward() );
+
+		// reset next dst change time
+		data()->setNextDSTChange( geo()->tzrule()->nextDSTChange() );
+
+		// reset local sideral time
+		data()->syncLST();
+
+		// Make sure Numbers, Moon, planets, and sky objects are updated immediately
+		data()->setFullTimeUpdate();
+
+		// If the sky is in Horizontal mode and not tracking, reset focus such that
+		// Alt/Az remain constant.
+		if ( ! Options::isTracking() && Options::useAltAz() ) {
+			map()->focus()->HorizontalToEquatorial( LST(), geo()->lat() );
+		}
+
+		// recalculate new times and objects
+		data()->setSnapNextFocus();
+		updateTime();
+	}
+}
+
+void KStars::slotDownload() {
+#if ( KDE_IS_VERSION( 3, 2, 90 ) )
+	if (!kns) kns = new KSNewStuff( this );
+	kns->download();
+#endif //KDE >= 3.2.90
+}
+
 void KStars::slotLCGenerator() {
 	if (AAVSODialog == NULL)
 		AAVSODialog = new LCGenerator(this);
@@ -139,6 +202,15 @@ void KStars::slotJMoonTool() {
 	jmt.exec();
 }
 
+void KStars::slotImageSequence()
+{
+  if (indiseq == NULL)
+    indiseq = new imagesequence(this);
+  
+  if (indiseq->updateStatus())
+    indiseq->show();
+}
+
 void KStars::slotTelescopeWizard()
 {
   telescopeWizardProcess twiz(this);
@@ -161,19 +233,32 @@ void KStars::slotINDIDriver() {
 
 void KStars::slotINDIConf() {
 
-   INDIConf indiconf(this);
+   INDIFITSConf indiconf(this);
 
-   indiconf.timeCheck->setChecked( options()->indiAutoTime );
-   indiconf.GeoCheck->setChecked( options()->indiAutoGeo );
-   indiconf.crosshairCheck->setChecked( options()->indiCrosshairs);
-   indiconf.messagesCheck->setChecked ( options()->indiMessages);
+   indiconf.timeCheck->setChecked( Options::indiAutoTime() );
+   indiconf.GeoCheck->setChecked( Options::indiAutoGeo() );
+   indiconf.crosshairCheck->setChecked( Options::indiCrosshairs() );
+   indiconf.messagesCheck->setChecked ( Options::indiMessages() );
+   indiconf.telPort_IN->setText ( Options::indiTelescopePort());
+   indiconf.vidPort_IN->setText ( Options::indiVideoPort());
+   
+   if (Options::fitsSaveDirectory().isEmpty())
+   {
+     indiconf.fitsDIR_IN->setText (QDir:: homeDirPath());
+     Options::setFitsSaveDirectory( indiconf.fitsDIR_IN->text());
+   }
+   else
+   indiconf.fitsDIR_IN->setText ( Options::fitsSaveDirectory());
 
    if (indiconf.exec() == QDialog::Accepted)
    {
-     options()->indiAutoTime = indiconf.timeCheck->isChecked();
-     options()->indiAutoGeo  = indiconf.GeoCheck->isChecked();
-     options()->indiCrosshairs = indiconf.crosshairCheck->isChecked();
-     options()->indiMessages = indiconf.messagesCheck->isChecked();
+     Options::setIndiAutoTime( indiconf.timeCheck->isChecked() );
+     Options::setIndiAutoGeo( indiconf.GeoCheck->isChecked() );
+     Options::setIndiCrosshairs( indiconf.crosshairCheck->isChecked() );
+     Options::setIndiMessages( indiconf.messagesCheck->isChecked() );
+     Options::setIndiTelescopePort ( indiconf.telPort_IN->text());
+     Options::setIndiVideoPort( indiconf.vidPort_IN->text());
+     Options::setFitsSaveDirectory( indiconf.fitsDIR_IN->text());
 
      map()->forceUpdateNow();
    }
@@ -186,66 +271,83 @@ void KStars::slotGeoLocator() {
 		if ( ii >= 0 ) {
 			// set new location in options
 			GeoLocation *newLocation = data()->geoList.at(ii);
-			options()->setLocation( *newLocation );
+			data()->setLocation( *newLocation );
 
 			// reset infoboxes
 			infoBoxes()->geoChanged( newLocation );
 
-			// call changeTime to reset DST change times
-			// However, adjust local time to keep UT the same.
+			// adjust local time to keep UT the same.
 			// create new LT without DST offset
-			QDateTime ltime = data()->UTime.addSecs( int( 3600 * newLocation->TZ0()) );
+			KStarsDateTime ltime = newLocation->UTtoLT( data()->ut() );
 
 			// reset timezonerule to compute next dst change
 			newLocation->tzrule()->reset_with_ltime( ltime, newLocation->TZ0(), data()->isTimeRunningForward() );
 
 			// reset next dst change time
-			data()->setNextDSTChange( KSUtils::UTtoJD( newLocation->tzrule()->nextDSTChange() ) );
+			data()->setNextDSTChange( newLocation->tzrule()->nextDSTChange() );
 
 			// reset local sideral time
-			data()->setLST();
+			data()->syncLST();
 
 			// Make sure Numbers, Moon, planets, and sky objects are updated immediately
 			data()->setFullTimeUpdate();
 
 			// If the sky is in Horizontal mode and not tracking, reset focus such that
 			// Alt/Az remain constant.
-			if ( ! options()->isTracking && options()->useAltAz ) {
+			if ( ! Options::isTracking() && Options::useAltAz() ) {
 				map()->focus()->HorizontalToEquatorial( LST(), geo()->lat() );
 			}
 
 			// recalculate new times and objects
-			options()->setSnapNextFocus();
+			data()->setSnapNextFocus();
 			updateTime();
 		}
 	}
 }
 
 void KStars::slotViewOps() {
-	// save options for cancel
-	data()->backupOptions();
+	KStandardDirs stdDirs;
+ 
+	//An instance of your dialog could be already created and could be cached, 
+	//in which case you want to display the cached dialog instead of creating 
+	//another one 
+	if ( KConfigDialog::showDialog( "settings" ) ) return; 
+ 
+	//KConfigDialog didn't find an instance of this dialog, so lets create it : 
+	KConfigDialog* dialog = new KConfigDialog( this, "settings", 
+					     Options::self() ); 
 
-	ViewOpsDialog viewopsdialog (this);
-	// connect caching funktions
-	QObject::connect( &viewopsdialog, SIGNAL( clearCache() ), this, SLOT( clearCachedFindDialog() ) );
+	connect( dialog, SIGNAL( applyClicked() ), this, SLOT( slotApplySettings() ) );
+	connect( dialog, SIGNAL( okClicked() ), this, SLOT( slotApplySettings() ) );
 
-	// ask for the new options
-	if ( viewopsdialog.exec() != QDialog::Accepted ) {
-		// cancelled
-		data()->restoreOptions();
-		map()->forceUpdate();
-	}
-	else
-		data()->saveOptions(this);
+	OpsCatalog *opcatalog    = new OpsCatalog( this, "catalogs" ); 
+	OpsGuides  *opguides     = new OpsGuides( this, "guides" ); 
+	OpsSolarSystem *opsolsys = new OpsSolarSystem( this, "solarsystem" ); 
+	OpsColors  *opcolors     = new OpsColors( this, "colors" ); 
+	OpsAdvanced *opadvanced  = new OpsAdvanced( this, "advanced" ); 
+ 
+	dialog->addPage( opcatalog,  i18n("Catalogs"), stdDirs.findResource( "data", "kstars/opscatalog.png" ) ); 
+	dialog->addPage( opsolsys,   i18n("Solar System"), stdDirs.findResource( "data", "kstars/opssolarsystem.png" ) ); 
+	dialog->addPage( opguides,   i18n("Guides"), stdDirs.findResource( "data", "kstars/opsguides.png" ) ); 
+	dialog->addPage( opcolors,   i18n("Colors"), stdDirs.findResource( "data", "kstars/opscolors.png" ) ); 
+	dialog->addPage( opadvanced, i18n("Advanced"), stdDirs.findResource( "data", "kstars/opsadvanced.png" ) ); 
+
+	dialog->show();
+}
+
+void KStars::slotApplySettings() {
+	Options::writeConfig();
+	data()->setFullTimeUpdate();
+	map()->forceUpdate();
 }
 
 void KStars::slotSetTime() {
-	TimeDialog timedialog ( data()->LTime, this );
+	TimeDialog timedialog ( data()->lt(), this );
 
 	if ( timedialog.exec() == QDialog::Accepted ) {
-		data()->changeTime( timedialog.selectedDate(), timedialog.selectedTime() );
+		data()->changeDateTime( geo()->LTtoUT( timedialog.selectedDateTime() ) );
 
-		if ( options()->useAltAz ) {
+		if ( Options::useAltAz() ) {
 			map()->focus()->HorizontalToEquatorial( LST(), geo()->lat() );
 		}
 
@@ -289,43 +391,23 @@ void KStars::closeWindow() {
 	close();
 }
 
+void KStars::slotOpenFITS()
+{
+
+  KURL fileURL = KFileDialog::getOpenURL( QDir::homeDirPath(), "*.fits *.fit *.fts|Flexible Image Transport System");
+  
+  if (fileURL.isEmpty())
+    return;
+    
+  FITSViewer * fv = new FITSViewer(&fileURL, this);
+  fv->show();
+  
+}
+
 void KStars::slotExportImage() {
 	KURL fileURL = KFileDialog::getSaveURL( QDir::homeDirPath(), "image/png image/jpeg image/gif image/x-portable-pixmap image/x-bmp" );
-	KTempFile tmpfile;
-	QString fname;
-	tmpfile.setAutoDelete(true);
-	QPixmap skyimage( map()->width(), map()->height() );
-
-	if ( fileURL.isValid() ) {
-		if ( fileURL.isLocalFile() ) {
-			fname = fileURL.path();
-		} else {
-			fname = tmpfile.name();
-		}
-
-		//Determine desired image format from filename extension
-		QString ext = fname.mid( fname.findRev(".")+1 );
-		const char* format = "PNG";
-		if ( ext.lower() == "png" ) { format = "PNG"; }
-		else if ( ext.lower() == "jpg" || ext.lower() == "jpeg" ) { format = "JPG"; }
-		else if ( ext.lower() == "gif" ) { format = "GIF"; }
-		else if ( ext.lower() == "pnm" ) { format = "PNM"; }
-		else if ( ext.lower() == "bmp" ) { format = "BMP"; }
-		else { kdWarning() << i18n( "Could not parse image format of %1; assuming PNG!" ).arg( fname ) << endl; }
-
-		map()->exportSkyImage( &skyimage );
-		kapp->processEvents(10000);
-
-		if ( ! skyimage.save( fname, format ) ) kdWarning() << i18n( "Unable to save image: %1 " ).arg( fname ) << endl;
-		else kdDebug() << i18n( "Saved to file: %1" ).arg( fname ) << endl;
-
-		if ( tmpfile.name() == fname ) { //attempt to upload image to remote location
-			if ( ! KIO::NetAccess::upload( tmpfile.name(), fileURL ) ) {
-				QString message = i18n( "Could not upload image to remote location: %1" ).arg( fileURL.prettyURL() );
-				KMessageBox::sorry( 0, message, i18n( "Could not upload file" ) );
-			}
-		}
-	}
+	
+	exportImage( fileURL.url(), map()->width(), map()->height() );
 }
 
 void KStars::slotRunScript() {
@@ -336,10 +418,10 @@ void KStars::slotRunScript() {
 	if ( fileURL.isValid() ) {
 		if ( ! fileURL.isLocalFile() ) {
 			//Warn the user about executing remote code.
-			QString message = i18n( "Warning!  You are about to execute a remote shell script on your machine. " );
-			message += i18n( "If you absolutely trust the source of this script, press Continue to execute the script. " );
-			message += i18n( "To save the file without executing it, press Save. " );
-			message += i18n( "To cancel the download, press Cancel. " );
+			QString message = i18n( "Warning:  You are about to execute a remote shell script on your machine. " );
+			message += i18n( "If you absolutely trust the source of this script, press Continue to execute the script; " );
+			message += i18n( "to save the file without executing it, press Save; " );
+			message += i18n( "to cancel the download, press Cancel. " );
 
 			int result = KMessageBox::warningYesNoCancel( 0, message, i18n( "Really Execute Remote Script?" ),
 					KStdGuiItem::cont(), KStdGuiItem::save() );
@@ -351,8 +433,8 @@ void KStars::slotRunScript() {
 				tmpfile.setAutoDelete(true);
 
 				while ( ! saveURL.isValid() ) {
-					message = i18n( "Save location is invalid.  Try another location?" );
-					if ( KMessageBox::warningYesNo( 0, message, i18n( "Invalid save location" ) ) == KMessageBox::No ) return;
+					message = i18n( "Save location is invalid. Try another location?" );
+					if ( KMessageBox::warningYesNo( 0, message, i18n( "Invalid Save Location" ) ) == KMessageBox::No ) return;
 					saveURL = KFileDialog::getSaveURL( QDir::homeDirPath(), "*.kstars|KStars Scripts (*.kstars)" );
 				}
 
@@ -362,11 +444,11 @@ void KStars::slotRunScript() {
 					fname = tmpfile.name();
 				}
 
-				if( KIO::NetAccess::download( fileURL, fname ) ) {
+				if( KIO::NetAccess::download( fileURL, fname, this ) ) {
 					chmod( fname.ascii(), S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH ); //make it executable
 
 					if ( tmpfile.name() == fname ) { //upload to remote location
-						if ( ! KIO::NetAccess::upload( tmpfile.name(), fileURL ) ) {
+						if ( ! KIO::NetAccess::upload( tmpfile.name(), fileURL, this ) ) {
 							QString message = i18n( "Could not upload image to remote location: %1" ).arg( fileURL.prettyURL() );
 							KMessageBox::sorry( 0, message, i18n( "Could not upload file" ) );
 						}
@@ -385,7 +467,7 @@ void KStars::slotRunScript() {
 
 		if ( ! fileURL.isLocalFile() ) {
 			fname = tmpfile.name();
-			if( KIO::NetAccess::download( fileURL, fname ) ) {
+			if( KIO::NetAccess::download( fileURL, fname, this ) ) {
 				chmod( fname.ascii(), S_IRUSR|S_IWUSR|S_IXUSR|S_IRGRP|S_IXGRP|S_IROTH|S_IXOTH );
 				f.setName( fname );
 			}
@@ -419,7 +501,7 @@ void KStars::slotRunScript() {
 
 		if ( ! fileOK ) {
 			KMessageBox::sorry( 0, i18n( "The selected file appears to be an invalid KStars script." ),
-					i18n( "Script Validation Failed!" ) );
+					i18n( "Script Validation Failed" ) );
 		} else {
 			//file is OK, run it!
 			KProcess p;
@@ -433,112 +515,29 @@ void KStars::slotRunScript() {
 
 void KStars::slotPrint() {
 	bool switchColors(false);
-	// save current colorscheme using copy constructor
-	ColorScheme cs( * options()->colorScheme() );
 
-	KPrinter printer( true, QPrinter::HighResolution );
-
-//Suggest Chart color scheme
-	if ( options()->colorScheme()->colorNamed( "SkyColor" ) != "#FFFFFF" ) {
-		QString message = i18n( "You can save printer ink by using the \"Star Chart\" color scheme, which uses a white background. Would you like to switch to the Star Chart color scheme for printing?" );
+	//Suggest Chart color scheme
+	if ( data()->colorScheme()->colorNamed( "SkyColor" ) != "#FFFFFF" ) {
+		QString message = i18n( "You can save printer ink by using the \"Star Chart\" "
+				"color scheme, which uses a white background. Would you like to "
+				"temporarily switch to the Star Chart color scheme for printing?" );
 
 		int answer;
 		answer = KMessageBox::questionYesNoCancel( 0, message, i18n( "Switch to Star Chart Colors?" ),
 			KStdGuiItem::yes(), KStdGuiItem::no(), "askAgainPrintColors" );
 
 		if ( answer == KMessageBox::Cancel ) return;
-
-		if ( answer == KMessageBox::Yes ) {
-			switchColors = true;
-			map()->setColors( "chart.colors" );
-		//	map()->forceUpdate( true );
-		}
+		if ( answer == KMessageBox::Yes ) switchColors = true;
 	}
 
-	printer.setFullPage( false );
-	if( printer.setup( this, i18n("Print Sky") ) ) {
-		kapp->setOverrideCursor( waitCursor );
-
-		map()->setMapGeometry();
-		map()->exportSkyImage( &printer );
-
-/*
-		QPainter p;
-
-		//shortcuts to inform wheter to draw different objects
-		bool drawPlanets( options()->drawPlanets );
-		bool drawMW( options()->drawMilkyWay );
-		bool drawCNames( options()->drawConstellNames );
-		bool drawCLines( options()->drawConstellLines );
-		bool drawGrid( options()->drawGrid );
-
-		p.begin( &printer );
-		QPaintDeviceMetrics pdm( p.device() );
-
-		//scale image such that it fills 90% of the x or y dimension on the paint device
-		double xscale = pdm.width() / map()->width();
-		double yscale = pdm.height() / map()->height();
-		double scale = (xscale < yscale) ? xscale : yscale;
-
-		int pdWidth = int( scale * map()->width() );
-		int pdHeight = int( scale * map()->height() );
-		int x1 = int( 0.5*(pdm.width()  - pdWidth) );
-		int y1 = int( 0.5*(pdm.height()  - pdHeight) );
-
-		p.setClipRect( QRect( x1, y1, pdWidth, pdHeight ) );
-		p.setClipping( true );
-
-		//Fil background with sky color
-		p.fillRect( x1, y1, pdWidth, pdHeight, QBrush( options()->colorScheme()->colorNamed( "SkyColor" ) ) );
-
-		p.translate( x1, y1 );
-
-		QFont stdFont = p.font();
-		QFont smallFont = p.font();
-		smallFont.setPointSize( stdFont.pointSize() - 2 );
-
-		if ( drawMW ) map()->drawMilkyWay( p, scale );
-		if ( drawGrid ) map()->drawCoordinateGrid( p, scale );
-		if ( options()->drawEquator ) map()->drawEquator( p, scale );
-		if ( options()->drawEcliptic ) map()->drawEcliptic( p, scale );
-		if ( drawCLines ) map()->drawConstellationLines( p, scale );
-		if ( drawCNames ) map()->drawConstellationNames( p, stdFont, scale );
-
-		// stars and planets use the same font size
-		if ( options()->ZoomFactor < 10.*MINZOOM ) {
-			p.setFont( smallFont );
-		} else {
-			p.setFont( stdFont );
-		}
-		map()->drawStars( p, scale );
-
-		map()->drawDeepSkyObjects( p, scale );
-		map()->drawSolarSystem( p, drawPlanets, scale );
-		map()->drawAttachedLabels( p, scale );
-		map()->drawHorizon( p, stdFont, scale );
-
-		p.end();
-*/
-
-		kapp->restoreOverrideCursor();
-	}
-
-	// restore old color scheme if necessary
-	// if printing will aborted the colorscheme will restored too
-	if ( switchColors ) {
-		options()->colorScheme()->copy( cs );
-		// restore colormode in skymap
-		map()->setStarColorMode( cs.starColorMode() );
-		map()->forceUpdate();
-	}
+	printImage( true, switchColors );
 }
 
 //Set Time to CPU clock
 void KStars::slotSetTimeToNow() {
-	QDateTime now = QDateTime::currentDateTime();
-	data()->changeTime( now.date(), now.time() );
+	data()->changeDateTime( geo()->LTtoUT( KStarsDateTime::currentDateTime() ) );
 
-	if ( options()->useAltAz ) {
+	if ( Options::useAltAz() ) {
 		map()->focus()->HorizontalToEquatorial( LST(), geo()->lat() );
 	}
 
@@ -555,7 +554,7 @@ void KStars::slotToggleTimer() {
 		data()->clock()->stop();
 		updateTime();
 	} else {
-		if ( fabs( data()->clock()->scale() ) > options()->slewTimeScale )
+		if ( fabs( data()->clock()->scale() ) > Options::slewTimeScale() )
 			data()->clock()->setManualMode( true );
 		data()->clock()->start();
 		if ( data()->clock()->isManualMode() ) map()->forceUpdate();
@@ -579,8 +578,8 @@ void KStars::slotPointFocus() {
 }
 
 void KStars::slotTrack() {
-	if ( options()->isTracking ) {
-		options()->isTracking = false;
+	if ( Options::isTracking() ) {
+		Options::setIsTracking( false );
 		actionCollection()->action("track_object")->setText( i18n( "Engage &Tracking" ) );
 		actionCollection()->action("track_object")->setIconSet( BarIcon( "decrypted" ) );
 		if ( map()->focusObject() && map()->focusObject()->isSolarSystem() && data()->temporaryTrail ) {
@@ -593,7 +592,10 @@ void KStars::slotTrack() {
 		map()->setFocusPoint( NULL );
 	} else {
 		map()->setClickedPoint( map()->focus() );
-		options()->isTracking = true;
+		map()->setClickedObject( NULL );
+		map()->setFocusObject( NULL );//no longer tracking focusObject
+		map()->setFocusPoint( map()->clickedPoint() );
+		Options::setIsTracking( true );
 		actionCollection()->action("track_object")->setText( i18n( "Stop &Tracking" ) );
 		actionCollection()->action("track_object")->setIconSet( BarIcon( "encrypted" ) );
 	}
@@ -603,25 +605,53 @@ void KStars::slotTrack() {
 
 void KStars::slotManualFocus() {
 	FocusDialog focusDialog( this ); // = new FocusDialog( this );
-	if ( options()->useAltAz ) focusDialog.activateAzAltPage();
+	if ( Options::useAltAz() ) focusDialog.activateAzAltPage();
 
 	if ( focusDialog.exec() == QDialog::Accepted ) {
+		//If the requested position is very near the pole, we need to point first
+		//to an intermediate location just below the pole in order to get the longitudinal
+		//position (RA/Az) right.
+		double realAlt( focusDialog.point()->alt()->Degrees() );
+		double realDec( focusDialog.point()->dec()->Degrees() );
+		if ( Options::useAltAz() && realAlt > 89.0 ) {
+			focusDialog.point()->setAlt( 89.0 );
+		}
+		if ( ! Options::useAltAz() && realDec > 89.0 ) {
+			focusDialog.point()->setDec( 89.0 );
+		}
+
 		//Do we need to convert Az/Alt to RA/Dec?
 		if ( focusDialog.usedAltAz() )
 			focusDialog.point()->HorizontalToEquatorial( LST(), geo()->lat() );
 
-		//If we are correcting for atmospheric refraction, correct the coordinates for that effect
-		if ( options()->useAltAz && options()->useRefraction ) {
+		//Do we need to convert RA/Dec to Alt/Az?
+		if ( ! focusDialog.usedAltAz() )
 			focusDialog.point()->EquatorialToHorizontal( LST(), geo()->lat() );
-			focusDialog.point()->setAlt( map()->refract( focusDialog.point()->alt(), true ) );
-			focusDialog.point()->HorizontalToEquatorial( LST(), geo()->lat() );
-		}
 
 		map()->setClickedPoint( focusDialog.point() );
-		if ( options()->isTracking ) slotTrack();
+		if ( Options::isTracking() ) slotTrack();
 
 		map()->slotCenter();
 
+		//The slew takes some time to complete, and this often causes the final focus point to be slightly 
+		//offset from the user's requested coordinates (because EquatorialToHorizontal() is called 
+		//throughout the process, which depends on the sidereal time).  So we now "polish" the final
+		//position by resetting the final focus to the focusDialog point.
+		//
+		//Also, if the requested position was within 1 degree of the coordinate pole, this will 
+		//automatically correct the final pointing from the intermediate offset position to the final position
+		if ( Options::useAltAz() ) {
+			data()->setSnapNextFocus();
+			map()->setDestinationAltAz( focusDialog.point()->alt()->Degrees(), focusDialog.point()->az()->Degrees() );
+		} else {
+			data()->setSnapNextFocus();
+			map()->setDestination( focusDialog.point()->ra()->Hours(), focusDialog.point()->dec()->Degrees() );
+		}
+		
+		//Now, if the requested point was near a pole, we need to reset the Alt/Dec of the focus.
+		if ( Options::useAltAz() && realAlt > 89.0 ) map()->focus()->setAlt( realAlt );
+		if ( ! Options::useAltAz() && realDec > 89.0 ) map()->focus()->setDec( realAlt );
+		
 		//Don't track if we set Alt/Az coordinates.  This way, Alt/Az remain constant.
 		if ( focusDialog.usedAltAz() ) map()->stopTracking();
 	}
@@ -630,11 +660,11 @@ void KStars::slotManualFocus() {
 //View Menu
 void KStars::slotZoomIn() {
 	actionCollection()->action("zoom_out")->setEnabled (true);
-	if ( options()->ZoomFactor < MAXZOOM )
-		options()->ZoomFactor *= DZOOM;
+	if ( Options::zoomFactor() < MAXZOOM )
+		Options::setZoomFactor( Options::zoomFactor()*DZOOM );
 
-	if ( options()->ZoomFactor >= MAXZOOM ) {
-		options()->ZoomFactor = MAXZOOM;
+	if ( Options::zoomFactor() >= MAXZOOM ) {
+		Options::setZoomFactor( MAXZOOM );
 		actionCollection()->action("zoom_in")->setEnabled (false);
 	}
 
@@ -643,11 +673,11 @@ void KStars::slotZoomIn() {
 
 void KStars::slotZoomOut() {
 	actionCollection()->action("zoom_in")->setEnabled (true);
-	if ( options()->ZoomFactor > MINZOOM )
-		options()->ZoomFactor /= DZOOM;
+	if ( Options::zoomFactor() > MINZOOM )
+		Options::setZoomFactor( Options::zoomFactor()/DZOOM );
 
-	if ( options()->ZoomFactor <= MINZOOM ) {
-		options()->ZoomFactor = MINZOOM;
+	if ( Options::zoomFactor() <= MINZOOM ) {
+		Options::setZoomFactor( MINZOOM );
 		actionCollection()->action("zoom_out")->setEnabled (false);
 	}
 
@@ -655,48 +685,38 @@ void KStars::slotZoomOut() {
 }
 
 void KStars::slotDefaultZoom() {
-	options()->ZoomFactor = DEFAULTZOOM;
+	Options::setZoomFactor( DEFAULTZOOM );
 	map()->forceUpdate();
 
-	if ( options()->ZoomFactor > MINZOOM )
+	if ( Options::zoomFactor() > MINZOOM )
 		actionCollection()->action("zoom_out")->setEnabled (true);
-	if ( options()->ZoomFactor < MAXZOOM )
+	if ( Options::zoomFactor() < MAXZOOM )
 		actionCollection()->action("zoom_in")->setEnabled (true);
 }
 
 void KStars::slotSetZoom() {
 	bool ok( false );
-	double currentAngle = map()->width() / ( options()->ZoomFactor * dms::DegToRad );
+	double currentAngle = map()->width() / ( Options::zoomFactor() * dms::DegToRad );
 	double angSize = currentAngle;
 	double minAngle = map()->width() / ( MAXZOOM * dms::DegToRad );
 	double maxAngle = map()->width() / ( MINZOOM * dms::DegToRad );
 
-	//keep KDE 3.0.x and 3.1.x compatibility
-	#if ( KDE_VERSION_MINOR >= 1 && KDE_VERSION_RELEASE > 20 )
 	angSize = KInputDialog::getDouble( i18n( "The user should enter an angle for the field-of-view of the display",
 			"Enter Desired Field-of-View Angle" ), i18n( "Enter a field-of-view angle in degrees: " ),
 			currentAngle, minAngle, maxAngle, 0.1, 1, &ok );
-	#else
-	QString sCurrent = QString("%1").arg( currentAngle, 0, 'f', 1 );
-	QString entry = KLineEditDlg::getText( i18n( "The user should enter an angle for the field-of-view of the display",
-			"Enter Desired Field-of-View Angle" ), i18n( "Enter a field-of-view angle in degrees: " ),
-			sCurrent, &ok, 0, &QDoubleValidator( minAngle, maxAngle, 1, 0 ) );
-
-	if ( ok ) angSize = entry.toDouble( &ok );
-	#endif
 
 	if ( ok ) {
-		options()->ZoomFactor = map()->width() / ( angSize * dms::DegToRad );
+		Options::setZoomFactor( map()->width() / ( angSize * dms::DegToRad ) );
 
-		if ( options()->ZoomFactor <= MINZOOM ) {
-			options()->ZoomFactor = MINZOOM;
+		if ( Options::zoomFactor() <= MINZOOM ) {
+			Options::setZoomFactor( MINZOOM );
 			actionCollection()->action("zoom_out")->setEnabled( false );
 		} else {
 			actionCollection()->action("zoom_out")->setEnabled( true );
 		}
 
-		if ( options()->ZoomFactor >= MAXZOOM ) {
-			options()->ZoomFactor = MAXZOOM;
+		if ( Options::zoomFactor() >= MAXZOOM ) {
+			Options::setZoomFactor( MAXZOOM );
 			actionCollection()->action("zoom_in")->setEnabled( false );
 		} else {
 			actionCollection()->action("zoom_in")->setEnabled( true );
@@ -707,11 +727,11 @@ void KStars::slotSetZoom() {
 }
 
 void KStars::slotCoordSys() {
-	if ( options()->useAltAz ) {
-		options()->useAltAz = false;
+	if ( Options::useAltAz() ) {
+		Options::setUseAltAz( false );
 		actCoordSys->turnOn();
 	} else {
-		options()->useAltAz = true;
+		Options::setUseAltAz( true );
 		actCoordSys->turnOff();
 	}
 	map()->forceUpdate();
@@ -721,16 +741,21 @@ void KStars::slotCoordSys() {
 void KStars::slotColorScheme() {
 	//use mid(3) to exclude the leading "cs_" prefix from the action name
 	QString filename = QString( sender()->name() ).mid(3) + ".colors";
-	map()->setColors( filename );
+	loadColorScheme( filename );
 }
 
 void KStars::slotTargetSymbol() {
 	QString symbolName( sender()->name() );
-	options()->setTargetSymbol( symbolName );
-	data()->fovSymbol.setName( symbolName );
-	data()->fovSymbol.setSize( options()->FOVSize );
-	data()->fovSymbol.setShape( options()->FOVShape );
-	data()->fovSymbol.setColor( options()->FOVColor );
+	FOV f( symbolName ); //read data from fov.dat
+	
+	Options::setFOVName( f.name() );
+	Options::setFOVSize( f.size() );
+	Options::setFOVShape( f.shape() );
+	Options::setFOVColor( f.color() );
+	data()->fovSymbol.setName( Options::fOVName() );
+	data()->fovSymbol.setSize( Options::fOVSize() );
+	data()->fovSymbol.setShape( Options::fOVShape() );
+	data()->fovSymbol.setColor( Options::fOVColor().name() );
 
 //Careful!!  If the user selects a small FOV (like HST), this basically crashes kstars :(
 //	//set ZoomLevel to match the FOV symbol
@@ -752,7 +777,7 @@ void KStars::slotFOVEdit() {
 			initFOV();
 		} else {
 			if ( ! f.open( IO_WriteOnly ) ) {
-				kdDebug() << i18n( "Could not open fov.dat for writing!" ) << endl;
+				kdDebug() << i18n( "Could not open fov.dat for writing." ) << endl;
 			} else {
 				QTextStream ostream(&f);
 
@@ -775,7 +800,10 @@ void KStars::slotFOVEdit() {
 
 				if ( fields.count() == 4 ) {
 					QString nm = fields[0].stripWhiteSpace();
-					fovActionMenu->insert( new KAction( nm, 0, this, SLOT( slotTargetSymbol() ), actionCollection(), nm.utf8() ) );
+					KToggleAction *kta = new KToggleAction( nm, 0, this, SLOT( slotTargetSymbol() ), 
+							actionCollection(), nm.utf8() );
+					kta->setExclusiveGroup( "fovsymbol" );
+					fovActionMenu->insert( kta );
 				}
 			}
 		} else {
@@ -783,15 +811,16 @@ void KStars::slotFOVEdit() {
 		}
 
 		fovActionMenu->popupMenu()->insertSeparator();
-		fovActionMenu->insert( new KAction( i18n( "Edit FOV Symbols..." ), 0, this, SLOT( slotFOVEdit() ), actionCollection(), "edit_fov" ) );
+		fovActionMenu->insert( new KAction( i18n( "Edit FOV Symbols..." ), 0, this, 
+				SLOT( slotFOVEdit() ), actionCollection(), "edit_fov" ) );
 
 		//set FOV to whatever was highlighted in FOV dialog
 		if ( fovdlg.FOVList.count() > 0 ) {
-			options()->setTargetSymbol( fovdlg.FOVList.at( fovdlg.currentItem() )->name() );
-			data()->fovSymbol.setName( options()->FOVName );
-			data()->fovSymbol.setSize( options()->FOVSize );
-			data()->fovSymbol.setShape( options()->FOVShape );
-			data()->fovSymbol.setColor( options()->FOVColor );
+			Options::setFOVName( fovdlg.FOVList.at( fovdlg.currentItem() )->name() );
+			data()->fovSymbol.setName( Options::fOVName() );
+			data()->fovSymbol.setSize( Options::fOVSize() );
+			data()->fovSymbol.setShape( Options::fOVShape() );
+			data()->fovSymbol.setColor( Options::fOVColor().name() );
 		}
 
 //Careful!!  If the user selects a small FOV (like HST), this basically crashes kstars :(
@@ -805,30 +834,111 @@ void KStars::slotTipOfDay() {
 	KTipDialog::showTip("kstars/tips", true);
 }
 
+// Toggle to and from full screen mode
+void KStars::slotFullScreen()
+{
+  if ( topLevelWidget()->isFullScreen() ) {
+    topLevelWidget()->showNormal();
+    }
+  else {
+    topLevelWidget()->showFullScreen();
+    }
+}
+
+void KStars::slotClearAllTrails() {
+	//Exclude object with temporary trail
+	SkyObject *exOb( NULL );
+	if ( map()->focusObject() && map()->focusObject()->isSolarSystem() && data()->temporaryTrail ) {
+		exOb = map()->focusObject();
+	}
+	
+	//Major bodies
+	if ( !( exOb && exOb->name() == "Moon" ) )    data()->Moon->clearTrail();
+	if ( !( exOb && exOb->name() == "Sun" ) )     data()->PCat->findByName("Sun")->clearTrail();
+	if ( !( exOb && exOb->name() == "Mercury" ) ) data()->PCat->findByName("Mercury")->clearTrail();
+	if ( !( exOb && exOb->name() == "Venus" ) )   data()->PCat->findByName("Venus")->clearTrail();
+	if ( !( exOb && exOb->name() == "Mars" ) )    data()->PCat->findByName("Mars")->clearTrail();
+	if ( !( exOb && exOb->name() == "Jupiter" ) ) data()->PCat->findByName("Jupiter")->clearTrail();
+	if ( !( exOb && exOb->name() == "Saturn" ) )  data()->PCat->findByName("Saturn")->clearTrail();
+	if ( !( exOb && exOb->name() == "Uranus" ) )  data()->PCat->findByName("Uranus")->clearTrail();
+	if ( !( exOb && exOb->name() == "Neptune" ) ) data()->PCat->findByName("Neptune")->clearTrail();
+	if ( !( exOb && exOb->name() == "Pluto" ) )   data()->PCat->findByName("Pluto")->clearTrail();
+	
+	//Asteroids
+	for ( KSAsteroid *ast = data()->asteroidList.first(); ast; ast = data()->asteroidList.next() ) 
+		if ( !( exOb && exOb->name() == ast->name() ) ) ast->clearTrail();
+
+	//Comets
+	for ( KSComet *com = data()->cometList.first(); com; com = data()->cometList.next() ) 
+		if ( !( exOb && exOb->name() == com->name() ) ) com->clearTrail();
+
+	map()->forceUpdate();
+}
+
 //toggle display of GUI Items on/off
 void KStars::slotShowGUIItem( bool show ) {
 //Toolbars
 	if ( sender()->name() == QString( "show_mainToolBar" ) ) {
-		options()->showMainToolBar = show;
+		Options::setShowMainToolBar( show );
 		if ( show ) toolBar( "mainToolBar" )->show();
 		else toolBar( "mainToolBar" )->hide();
 	}
 	if ( sender()->name() == QString( "show_viewToolBar" ) ) {
-		options()->showViewToolBar = show;
+		Options::setShowViewToolBar( show );
 		if ( show ) toolBar( "viewToolBar" )->show();
 		else toolBar( "viewToolBar" )->hide();
 	}
 
+	if ( sender()->name() == QString( "show_statusBar" ) ) {
+		Options::setShowStatusBar( show );
+		if ( show ) statusBar()->show();
+		else  statusBar()->hide();
+	}
+
+	if ( sender()->name() == QString( "show_sbAzAlt" ) ) {
+		Options::setShowAltAzField( show );
+		if ( show ) {
+			//To preserve the order (AzAlt before RADec), we have to remove 
+			//the RADec field and then add both back.
+			if ( Options::showRADecField() ) statusBar()->removeItem( 2 );
+			
+			QString s = "000d 00m 00s,   +00d 00\' 00\""; //only need this to set the width
+			statusBar()->insertFixedItem( s, 1, true );
+			statusBar()->setItemAlignment( 1, AlignRight | AlignVCenter );
+			statusBar()->changeItem( "", 1 );
+
+			if ( Options::showRADecField() ) {
+				statusBar()->insertFixedItem( s, 2, true );
+				statusBar()->setItemAlignment( 2, AlignRight | AlignVCenter );
+				statusBar()->changeItem( "", 2 );
+			}
+		} else {
+			statusBar()->removeItem( 1 );
+		}
+	}
+	
+	if ( sender()->name() == QString( "show_sbRADec" ) ) {
+		Options::setShowRADecField( show );
+		if ( show ) {
+			QString s = "000d 00m 00s,   +00d 00\' 00\""; //only need this to set the width
+			statusBar()->insertFixedItem( s, 2, true );
+			statusBar()->setItemAlignment( 2, AlignRight | AlignVCenter );
+			statusBar()->changeItem( "", 2 );
+		} else {
+			statusBar()->removeItem( 2 );
+		}
+	}
+
 //InfoBoxes: we only change options here; these are also connected to slots in
 //InfoBoxes that actually toggle the display.
 	if ( sender()->name() == QString( "show_boxes" ) )
-		options()->showInfoBoxes = show;
+		Options::setShowInfoBoxes( show );
 	if ( sender()->name() == QString( "show_time_box" ) )
-		options()->showTimeBox = show;
+		Options::setShowTimeBox( show );
 	if ( sender()->name() == QString( "show_location_box" ) )
-		options()->showGeoBox = show;
+		Options::setShowGeoBox( show );
 	if ( sender()->name() == QString( "show_focus_box" ) )
-		options()->showFocusBox = show;
+		Options::setShowFocusBox( show );
 }
 
 void KStars::addColorMenuItem( QString name, QString actionName ) {
