@@ -14,21 +14,34 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+
+#include <qlayout.h>
+#include <qfile.h>
+#include <qdir.h>
 #include <dcopclient.h>
 #include <kshortcut.h>
 #include <kiconloader.h>
 #include <kpopupmenu.h>
 #include <kstatusbar.h>
 #include <ktip.h>
-
 #include <kmessagebox.h>
+#include <kstandarddirs.h>
+#include <kdeversion.h>
 
-//#include "infopanel.h"
-#include "infoboxes.h"
+#include "Options.h"
 #include "kstars.h"
+#include "kstarsdata.h"
+#include "kstarssplash.h"
+#include "skymap.h"
+#include "skyobject.h"
+#include "ksplanetbase.h"
 #include "ksutils.h"
+#include "ksnumbers.h"
+#include "infoboxes.h"
 #include "toggleaction.h"
 #include "indimenu.h"
+#include "simclock.h"
+#include "timestepbox.h"
 
 //This file contains functions that kstars calls at startup (except constructors).
 //These functions are declared in kstars.h
@@ -39,17 +52,20 @@ void KStars::initActions() {
 			this, SLOT( newWindow() ), actionCollection(), "new_window");
 	new KAction(i18n("&Close Window"), "fileclose", KShortcut( "Ctrl+W"  ),
 			this, SLOT( closeWindow() ), actionCollection(), "close_window");
+	new KAction( i18n( "&Download Data..." ), "lknewstuff", KShortcut( "Ctrl+D" ),
+			this, SLOT( slotDownload() ), actionCollection(), "get_data" );
+	new KAction( i18n( "Open FITS..."), "fileopen", KShortcut( "Ctrl+O"), this, SLOT( slotOpenFITS()), actionCollection(), "open_file");
 	new KAction( i18n( "&Save Sky Image..." ), "fileexport", KShortcut( "Ctrl+I" ),
 			this, SLOT( slotExportImage() ), actionCollection(), "export_image" );
 	new KAction( i18n( "&Run Script..." ), "launch", KShortcut( "Ctrl+R" ),
 			this, SLOT( slotRunScript() ), actionCollection(), "run_script" );
-  KStdAction::print(this, SLOT( slotPrint() ), actionCollection(), "print" );
+	KStdAction::print(this, SLOT( slotPrint() ), actionCollection(), "print" );
 	KStdAction::quit(this, SLOT( close() ), actionCollection(), "quit" );
 
 //Time Menu:
 	new KAction( i18n( "Set Time to &Now" ), KShortcut( "Ctrl+E"  ),
 		this, SLOT( slotSetTimeToNow() ), actionCollection(), "time_to_now" );
-	new KAction( i18n( "set clock to a new time", "&Set Time..." ), "clock", KShortcut( "Ctrl+S"  ),
+	new KAction( i18n( "set Clock to New Time", "&Set Time..." ), "clock", KShortcut( "Ctrl+S"  ),
 		this, SLOT( slotSetTime() ), actionCollection(), "time_dialog" );
 	ToggleAction *actTimeRun = new ToggleAction( i18n( "Stop &Clock" ), BarIcon("player_pause"),
 				i18n("Start &Clock"), BarIcon("1rightarrow"),
@@ -76,10 +92,10 @@ void KStars::initActions() {
 												actionCollection(), "find_object" );
 	tmpAction->setText( i18n( "&Find Object..." ) );
 	tmpAction->setToolTip( i18n( "Find object" ) );
-	
+
 	new KAction( i18n( "Engage &Tracking" ), "decrypted", KShortcut( "Ctrl+T"  ),
 		this, SLOT( slotTrack() ), actionCollection(), "track_object" );
-	if ( options()->isTracking ) { 
+	if ( Options::isTracking() ) {
 		actionCollection()->action("track_object")->setText( i18n( "Stop &Tracking" ) );
 		actionCollection()->action("track_object")->setIconSet( BarIcon( "encrypted" ) );
 	}
@@ -96,7 +112,9 @@ void KStars::initActions() {
 		this, SLOT( slotSetZoom() ), actionCollection(), "zoom_set" );
 	actCoordSys = new ToggleAction( i18n("Horizontal &Coordinates"), i18n( "Equatorial &Coordinates" ),
 			Key_Space, this, SLOT( slotCoordSys() ), actionCollection(), "coordsys" );
-	if ( options()->useAltAz ) actCoordSys->turnOff();
+	if ( Options::useAltAz() ) actCoordSys->turnOff();
+	KStdAction::fullScreen( this, SLOT( slotFullScreen() ), actionCollection(), 0 );
+
 
 //Settings Menu:
 	//
@@ -108,38 +126,79 @@ void KStars::initActions() {
 	//Info Boxes option actions
 	KToggleAction *a = new KToggleAction(i18n( "Show the information boxes", "Show &Info Boxes"),
 			0, 0, 0, actionCollection(), "show_boxes");
-	a->setChecked( options()->showInfoBoxes );
+#if KDE_IS_VERSION( 3, 2, 90 )
+	a->setCheckedState(i18n("Hide &Info Boxes"));
+#endif
+	a->setChecked( Options::showInfoBoxes() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(setVisible(bool)));
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
-	infoBoxes()->setVisible( options()->showInfoBoxes );
+	infoBoxes()->setVisible( Options::showInfoBoxes() );
 
 	a = new KToggleAction(i18n( "Show time-related info box", "Show &Time Box"),
 			0, 0, 0, actionCollection(), "show_time_box");
-	a->setChecked( options()->showTimeBox );
+#if KDE_IS_VERSION( 3, 2, 90 )
+	a->setCheckedState(i18n("Hide &Time Box"));
+#endif
+	a->setChecked( Options::showTimeBox() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(showTimeBox(bool)));
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 
 	a = new KToggleAction(i18n( "Show focus-related info box", "Show &Focus Box"),
 			0, 0, 0, actionCollection(), "show_focus_box");
-	a->setChecked( options()->showFocusBox );
+#if KDE_IS_VERSION( 3, 2, 90 )
+	a->setCheckedState(i18n("Hide &Focus Box"));
+#endif
+	a->setChecked( Options::showFocusBox() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(showFocusBox(bool)));
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 
 	a = new KToggleAction(i18n( "Show location-related info box", "Show &Location Box"),
 			0, 0, 0, actionCollection(), "show_location_box");
-	a->setChecked( options()->showGeoBox );
+#if KDE_IS_VERSION( 3, 2, 90 )
+	a->setCheckedState(i18n("Hide &Location Box"));
+#endif
+	a->setChecked( Options::showGeoBox() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), infoBoxes(), SLOT(showGeoBox(bool)));
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 
 //Toolbar view options
 	a = new KToggleAction(i18n( "Show Main Toolbar" ),
 			0, 0, 0, actionCollection(), "show_mainToolBar");
-	a->setChecked( options()->showMainToolBar );
+#if KDE_IS_VERSION( 3, 2, 90 )
+	a->setCheckedState(i18n("Hide Main Toolbar"));
+#endif
+	a->setChecked( Options::showMainToolBar() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 
 	a = new KToggleAction(i18n( "Show View Toolbar" ),
 			0, 0, 0, actionCollection(), "show_viewToolBar");
-	a->setChecked( options()->showViewToolBar );
+#if KDE_IS_VERSION( 3, 2, 90 )
+	a->setCheckedState(i18n("Hide View Toolbar"));
+#endif
+	a->setChecked( Options::showViewToolBar() );
+	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
+
+//Statusbar view options
+	a = new KToggleAction(i18n( "Show Statusbar" ),
+			0, 0, 0, actionCollection(), "show_statusBar");
+#if KDE_IS_VERSION( 3, 2, 90 )
+	a->setCheckedState(i18n("Hide Statusbar"));
+#endif
+	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
+	a->setChecked( Options::showStatusBar() );
+	a = new KToggleAction(i18n( "Show Az/Alt Field" ),
+			0, 0, 0, actionCollection(), "show_sbAzAlt");
+#if KDE_IS_VERSION( 3, 2, 90 )
+	a->setCheckedState(i18n("Hide Az/Alt Field"));
+#endif
+	a->setChecked( Options::showAltAzField() );
+	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
+	a = new KToggleAction(i18n( "Show RA/Dec Field" ),
+			0, 0, 0, actionCollection(), "show_sbRADec");
+#if KDE_IS_VERSION( 3, 2, 90 )
+	a->setCheckedState(i18n("Hide RA/Dec Field"));
+#endif
+	a->setChecked( Options::showRADecField() );
 	QObject::connect(a, SIGNAL( toggled(bool) ), this, SLOT(slotShowGUIItem(bool)));
 
 //Color scheme actions.  These are added to the "colorschemes" KActionMenu.
@@ -177,21 +236,6 @@ void KStars::initActions() {
 	fovActionMenu = new KActionMenu( i18n( "&FOV Symbols" ), actionCollection(), "fovsymbols" );
 	initFOV();
 
-// 	new KAction( i18n( "do not use a target symbol", "No Symbol" ), 0,
-// 			this, SLOT( slotTargetSymbol() ), actionCollection(), "target_symbol_none" );
-//
-// 	new KAction( i18n( "use a circle target symbol", "Circle" ), 0,
-// 			this, SLOT( slotTargetSymbol() ), actionCollection(), "target_symbol_circle" );
-//
-// 	new KAction( i18n( "use a crosshairs target symbol", "Crosshairs" ), 0,
-// 			this, SLOT( slotTargetSymbol() ), actionCollection(), "target_symbol_crosshairs" );
-//
-// 	new KAction( i18n( "use a bullseye target symbol", "Bullseye" ), 0,
-// 			this, SLOT( slotTargetSymbol() ), actionCollection(), "target_symbol_bullseye" );
-//
-// 	new KAction( i18n( "use a rectangle target symbol", "Rectangle" ), 0,
-// 			this, SLOT( slotTargetSymbol() ), actionCollection(), "target_symbol_rectangle" );
-
 	//use custom icon earth.png for the geoLocator icon.  If it is not installed
   //for some reason, use standard icon gohome.png instead.
 	QFile tempFile;
@@ -207,7 +251,9 @@ void KStars::initActions() {
 	}
 
 	KStdAction::preferences( this, SLOT( slotViewOps() ), actionCollection(), "configure" );
-	actionCollection()->action( "configure" )->setShortcut( KShortcut( "Ctrl+O" ) );
+
+	new KAction(i18n( "Startup Wizard..." ), 0, this, SLOT( slotWizard() ),
+		actionCollection(), "startwizard" );
 
 //Tools Menu:
 	new KAction(i18n( "Calculator..."), KShortcut( "Ctrl+C"),
@@ -232,7 +278,13 @@ void KStars::initActions() {
 // devices Menu
 	new KAction(i18n("Telescope Wizard..."), 0, this, SLOT(slotTelescopeWizard()), actionCollection(), "telescope_wizard");
 	new KAction(i18n("Device Manager..."), 0, this, SLOT(slotINDIDriver()), actionCollection(), "device_manager");
-	new KAction(i18n("INDI Control Panel"), 0, this, SLOT(slotINDIPanel()), actionCollection(), "indi_control_panel");
+	
+	tmpAction = new KAction(i18n("Capture Image Sequence..."), 0, this, SLOT(slotImageSequence()), actionCollection(), "capture_sequence");
+	tmpAction->setEnabled(false);
+	
+	tmpAction = new KAction(i18n("INDI Control Panel..."), 0, this, SLOT(slotINDIPanel()), actionCollection(), "indi_control_panel");
+	tmpAction->setEnabled(false);
+	
 	new KAction(i18n("Configure INDI..."), 0, this, SLOT(slotINDIConf()), actionCollection(), "configure_indi");
 
 
@@ -254,12 +306,12 @@ void KStars::initActions() {
 		KToggleAction *a = new KToggleAction( i18n( "Toggle Stars" ),
 				tempFile.name(), 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_stars" );
-		a->setChecked( options()->drawSAO );
+		a->setChecked( Options::showStars() );
 		tempFile.close();
 	} else {
 		KToggleAction *a = new KToggleAction( i18n( "Toggle Stars" ), "wizard", 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_stars" );
-		a->setChecked( options()->drawSAO );
+		a->setChecked( Options::showStars() );
 	}
 
 //show_deepsky:
@@ -267,12 +319,12 @@ void KStars::initActions() {
 		KToggleAction *a = new KToggleAction( i18n( "Toggle Deep Sky Objects" ),
 				tempFile.name(), 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_deepsky" );
-		a->setChecked( options()->drawDeepSky );
+		a->setChecked( Options::showDeepSky() );
 		tempFile.close();
 	} else {
 		KToggleAction *a = new KToggleAction( i18n( "Toggle Deep Sky Objects" ), "wizard", 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_deepsky" );
-		a->setChecked( options()->drawDeepSky );
+		a->setChecked( Options::showDeepSky() );
 	}
 
 //show_planets:
@@ -280,12 +332,12 @@ void KStars::initActions() {
 		KToggleAction *a = new KToggleAction( i18n( "Toggle Solar System" ),
 				tempFile.name(), 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_planets" );
-		a->setChecked( options()->drawPlanets );
+		a->setChecked( Options::showPlanets() );
 		tempFile.close();
 	} else {
 		KToggleAction *a = new KToggleAction( i18n( "Toggle Solar System" ), "wizard", 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_planets" );
-		a->setChecked( options()->drawPlanets );
+		a->setChecked( Options::showPlanets() );
 	}
 
 //show_clines:
@@ -293,12 +345,12 @@ void KStars::initActions() {
 		KToggleAction *a = new KToggleAction( i18n( "Toggle Constellation Lines" ),
 				tempFile.name(), 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_clines" );
-		a->setChecked( options()->drawConstellLines );
+		a->setChecked( Options::showCLines() );
 		tempFile.close();
 	} else {
 		KToggleAction *a = new KToggleAction( i18n( "Toggle Constellation Lines" ), "wizard", 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_clines" );
-		a->setChecked( options()->drawConstellLines );
+		a->setChecked( Options::showCLines() );
 	}
 
 //show_cnames:
@@ -306,12 +358,25 @@ void KStars::initActions() {
 		KToggleAction *a = new KToggleAction( i18n( "Toggle Constellation Names" ),
 				tempFile.name(), 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_cnames" );
-		a->setChecked( options()->drawConstellNames );
+		a->setChecked( Options::showCNames() );
 		tempFile.close();
 	} else {
 		KToggleAction *a = new KToggleAction( i18n( "Toggle Constellation Lines" ), "wizard", 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_cnames" );
-		a->setChecked( options()->drawConstellNames );
+		a->setChecked( Options::showCNames() );
+	}
+
+//show_cbound:
+	if (KSUtils::openDataFile( tempFile, "show_cbound.png" ) ) {
+		KToggleAction *a = new KToggleAction( i18n( "Toggle Constellation Boundaries" ),
+				tempFile.name(), 0,
+				this, SLOT( slotViewToolBar() ), actionCollection(), "show_cbounds" );
+		a->setChecked( Options::showCBounds() );
+		tempFile.close();
+	} else {
+		KToggleAction *a = new KToggleAction( i18n( "Toggle Constellation Boundaries" ), "wizard", 0,
+				this, SLOT( slotViewToolBar() ), actionCollection(), "show_cbounds" );
+		a->setChecked( Options::showCBounds() );
 	}
 
 //show_mw:
@@ -319,12 +384,12 @@ void KStars::initActions() {
 		KToggleAction *a = new KToggleAction( i18n( "Toggle Milky Way" ),
 				tempFile.name(), 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_mw" );
-		a->setChecked( options()->drawMilkyWay );
+		a->setChecked( Options::showMilkyWay() );
 		tempFile.close();
 	} else {
 		KToggleAction *a = new KToggleAction( i18n( "Toggle Milky Way" ), "wizard", 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_mw" );
-		a->setChecked( options()->drawMilkyWay );
+		a->setChecked( Options::showMilkyWay() );
 	}
 
 //show_grid:
@@ -333,11 +398,11 @@ void KStars::initActions() {
 				tempFile.name(), 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_grid" );
 		tempFile.close();
-		a->setChecked( options()->drawGrid );
+		a->setChecked( Options::showGrid() );
 	} else {
 		KToggleAction *a = new KToggleAction( i18n( "Toggle Coordinate Grid" ), "wizard", 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_grid" );
-		a->setChecked( options()->drawGrid );
+		a->setChecked( Options::showGrid() );
 	}
 
 //show_horizon:
@@ -346,12 +411,15 @@ void KStars::initActions() {
 				tempFile.name(), 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_horizon" );
 		tempFile.close();
-		a->setChecked( options()->drawGround );
+		a->setChecked( Options::showGround() );
 	} else {
 		KToggleAction *a = new KToggleAction( i18n( "Toggle Ground" ), "wizard", 0,
 				this, SLOT( slotViewToolBar() ), actionCollection(), "show_horizon" );
-		a->setChecked( options()->drawGround );
+		a->setChecked( Options::showGround() );
 	}
+	
+        if (Options::fitsSaveDirectory().isEmpty())
+            Options::setFitsSaveDirectory(QDir:: homeDirPath());
 }
 
 void KStars::initFOV() {
@@ -368,7 +436,7 @@ void KStars::initFOV() {
 
 	if ( ! f.exists() ) {
 		if ( ! f.open( IO_WriteOnly ) ) {
-			kdDebug() << i18n( "Could not open fov.dat!" ) << endl;
+			kdDebug() << i18n( "Could not open fov.dat." ) << endl;
 		} else {
 			QTextStream ostream(&f);
 			ostream << i18n( "Do not use a field-of-view indicator", "No FOV" ) <<  ":0.0:0:#AAAAAA" << endl;
@@ -388,7 +456,11 @@ void KStars::initFOV() {
 
 			if ( fields.count() == 4 ) {
 				nm = fields[0].stripWhiteSpace();
-				fovActionMenu->insert( new KAction( nm, 0, this, SLOT( slotTargetSymbol() ), actionCollection(), nm.utf8() ) );
+				KToggleAction *kta = new KToggleAction( nm, 0, this, SLOT( slotTargetSymbol() ), 
+						actionCollection(), nm.utf8() );
+				kta->setExclusiveGroup( "fovsymbol" );
+				if ( nm == Options::fOVName() ) kta->setChecked( true );
+				fovActionMenu->insert( kta );
 			}
 		}
 	} else {
@@ -402,11 +474,22 @@ void KStars::initFOV() {
 void KStars::initStatusBar() {
 	statusBar()->insertItem( i18n( " Welcome to KStars " ), 0, 1, true );
 	statusBar()->setItemAlignment( 0, AlignLeft | AlignVCenter );
-	QString s = "00h 00m 00s,   +00d 00\' 00\"";
 
-	statusBar()->insertItem( s, 1, 1, true );
-	statusBar()->setItemAlignment( 1, AlignRight | AlignVCenter );
-	statusBar()->setItemFixed( 1, -1 );
+	QString s = "000d 00m 00s,   +00d 00\' 00\""; //only need this to set the width
+
+	if ( Options::showAltAzField() ) {
+		statusBar()->insertFixedItem( s, 1, true );
+		statusBar()->setItemAlignment( 1, AlignRight | AlignVCenter );
+		statusBar()->changeItem( "", 1 );
+	}
+
+	if ( Options::showRADecField() ) {
+		statusBar()->insertFixedItem( s, 2, true );
+		statusBar()->setItemAlignment( 2, AlignRight | AlignVCenter );
+		statusBar()->changeItem( "", 2 );
+	}
+
+	if ( ! Options::showStatusBar() ) statusBar()->hide();
 }
 
 void KStars::datainitFinished(bool worked) {
@@ -427,19 +510,26 @@ void KStars::datainitFinished(bool worked) {
 	data()->clock()->start();
 
 //Initialize FOV symbol from options
-	data()->fovSymbol.setName( options()->FOVName );
-	data()->fovSymbol.setSize( options()->FOVSize );
-	data()->fovSymbol.setShape( options()->FOVShape );
-	data()->fovSymbol.setColor( options()->FOVColor );
+	data()->fovSymbol.setName( Options::fOVName() );
+	data()->fovSymbol.setSize( Options::fOVSize() );
+	data()->fovSymbol.setShape( Options::fOVShape() );
+	data()->fovSymbol.setColor( Options::fOVColor().name() );
 
 	show();
 
-//Check whether initial position is below the horizon.
-//We used to just call slotCenter() in buildGUI() which performs this check.
-//However, on some systems, if the messagebox is shown before show() is called,
-//the program exits.  It does not crash (at least there are no error messages),
-//it simply exits.  Very strange.
-	if ( options()->useAltAz && options()->drawGround &&
+	//If this is the first startup, show the wizard
+	if ( Options::runStartupWizard() ) {
+		slotWizard();
+		//reset the clock to the system CPU
+		slotSetTimeToNow();
+	}
+
+	//Check whether initial position is below the horizon.
+	//We used to just call slotCenter() in buildGUI() which performs this check.
+	//However, on some systems, if the messagebox is shown before show() is called,
+	//the program exits.  It does not crash (at least there are no error messages),
+	//it simply exits.  Very strange.
+	if ( Options::useAltAz() && Options::showGround() &&
 			map()->focus()->alt()->Degrees() < -1.0 ) {
 		QString caption = i18n( "Initial Position is Below Horizon" );
 		QString message = i18n( "The initial position is below the horizon.\nWould you like to reset to the default position?" );
@@ -447,8 +537,9 @@ void KStars::datainitFinished(bool worked) {
 				KStdGuiItem::yes(), KStdGuiItem::no(), "dag_start_below_horiz" ) == KMessageBox::Yes ) {
 			map()->setClickedObject( NULL );
 			map()->setFocusObject( NULL );
-			options()->isTracking = false;
-			options()->setSnapNextFocus(true);
+			Options::setIsTracking( false );
+
+			data()->setSnapNextFocus(true);
 
 			SkyPoint DefaultFocus;
 			DefaultFocus.setAz( 180.0 );
@@ -460,7 +551,7 @@ void KStars::datainitFinished(bool worked) {
 
 	//If there is a focusObject() and it is a SS body, add a temporary Trail to it.
 	if ( map()->focusObject() && map()->focusObject()->isSolarSystem()
-			&& options()->useAutoTrail ) {
+			&& Options::useAutoTrail() ) {
 		((KSPlanetBase*)map()->focusObject())->addToTrail();
 		data()->temporaryTrail = true;
 	}
@@ -482,10 +573,13 @@ void KStars::privatedata::buildGUI() {
 
 	//INDI driver set to null
 	ks->indidriver = 0;
+	
+	//INDI img sequence, set to null
+	ks->indiseq = 0;
 
 	ks->skymap = new SkyMap( ks->data(), ks->centralWidget );
 	// update skymap if KStarsData send update signal
-	QObject::connect(kstarsData, SIGNAL( update() ), ks->skymap, SLOT( forceUpdate() ) );
+	QObject::connect(kstarsData, SIGNAL( update() ), ks->skymap, SLOT( forceUpdateNow() ) );
 
 	// get focus of keyboard and mouse actions (for example zoom in with +)
 	ks->map()->QWidget::setFocus();
@@ -501,14 +595,14 @@ void KStars::privatedata::buildGUI() {
 	ks->createGUI("kstarsui.rc", false);
 
 	//Do not show text on the view toolbar buttons
-	//FIXME: after strings freeze, remove this and make the 
+	//FIXME: after strings freeze, remove this and make the
 	//text of each button shorter
 	ks->toolBar( "viewToolBar" )->setIconText( KToolBar::IconOnly );
 
 	//Initialize show/hide state of toolbars.
 	//These were in initActions, but they must appear after createGUI...
-	if ( !ks->options()->showMainToolBar ) ks->toolBar( "mainToolBar" )->hide();
-	if ( !ks->options()->showViewToolBar ) ks->toolBar( "viewToolBar" )->hide();
+	if ( !Options::showMainToolBar() ) ks->toolBar( "mainToolBar" )->hide();
+	if ( !Options::showViewToolBar() ) ks->toolBar( "viewToolBar" )->hide();
 
 	ks->TimeStep = new TimeStepBox( ks->toolBar() );
 	ks->toolBar()->insertWidget( 0, 6, ks->TimeStep, 15 );
@@ -521,13 +615,13 @@ void KStars::privatedata::buildGUI() {
 	connect( ks->data()->clock(), SIGNAL( scaleChanged( float ) ), ks->map(), SLOT( slotClockSlewing() ) );
 	connect( ks->TimeStep, SIGNAL( scaleChanged( float ) ), ks, SLOT( mapGetsFocus() ) );
 
-	ks->resize( ks->options()->windowWidth, ks->options()->windowHeight );
+	ks->resize( Options::windowWidth(), Options::windowHeight() );
 
 	// initialize clock with current time/date
 	ks->slotSetTimeToNow();
 
 	//Define the celestial equator, horizon and ecliptic
-	KSNumbers tempnum(ks->data()->clock()->JD());
+	KSNumbers tempnum(ks->data()->ut().djd());
 	ks->data()->initGuides(&tempnum);
 
 	//Connect the clock.
@@ -539,17 +633,17 @@ void KStars::privatedata::buildGUI() {
 
 	SkyPoint newPoint;
 	if ( ks->data()->useDefaultOptions ) {
-		newPoint.setAz( ks->options()->focusRA );
-		newPoint.setAlt( ks->options()->focusDec + 0.0001 );
+		newPoint.setAz( Options::focusRA() );
+		newPoint.setAlt( Options::focusDec() + 0.0001 );
 		newPoint.HorizontalToEquatorial( ks->LST(), ks->geo()->lat() );
 	} else {
-		newPoint.set( ks->options()->focusRA, ks->options()->focusDec );
+		newPoint.set( Options::focusRA(), Options::focusDec() );
 	}
 
 //need to set focusObject before updateTime, otherwise tracking is set to false
-	if ( (ks->options()->focusObject != i18n( "star" ) ) &&
-		     (ks->options()->focusObject != i18n( "nothing" ) ) )
-			ks->map()->setFocusObject( ks->data()->objectNamed( ks->options()->focusObject ) );
+	if ( (Options::focusObject() != i18n( "star" ) ) &&
+		     (Options::focusObject() != i18n( "nothing" ) ) )
+			ks->map()->setFocusObject( ks->data()->objectNamed( Options::focusObject() ) );
 
 	ks->updateTime();
 
@@ -562,14 +656,15 @@ void KStars::privatedata::buildGUI() {
 //	ks->map()->setDestination( &DefaultFocus );
 
 	//if user was tracking last time, track on same object now.
-	if ( ks->options()->isTracking ) {
-		if ( (ks->options()->focusObject== i18n( "star" ) ) ||
-		     (ks->options()->focusObject== i18n( "nothing" ) ) ) {
+	if ( Options::isTracking() ) {
+		if ( (Options::focusObject() == i18n( "star" ) ) ||
+		     (Options::focusObject() == i18n( "nothing" ) ) ) {
 			ks->map()->setFocusPoint( &newPoint );
 		} else {
-			ks->map()->setClickedObject( ks->data()->objectNamed( ks->options()->focusObject ) );
+			ks->map()->setClickedObject( ks->data()->objectNamed( Options::focusObject() ) );
 			if ( ks->map()->clickedObject() ) {
 				ks->map()->setFocusPoint( ks->map()->clickedObject() );
+				ks->map()->setFocusObject( ks->map()->clickedObject() );
 			} else {
 				ks->map()->setFocusPoint( &newPoint );
 			}
@@ -580,16 +675,17 @@ void KStars::privatedata::buildGUI() {
 //		ks->map()->slotCenter();
 	}
 
-	if ( ks->options()->focusObject== i18n( "star" ) ) ks->options()->focusObject = i18n( "nothing" );
+//	if ( Options::focusObject() == i18n( "star" ) ) Options::setFocusObject( i18n( "nothing" ) );
 
 	ks->map()->setDestination( ks->map()->focusPoint() );
 	ks->map()->destination()->EquatorialToHorizontal( ks->LST(), ks->geo()->lat() );
 	ks->map()->setFocus( ks->map()->destination() );
 	ks->map()->focus()->EquatorialToHorizontal( ks->LST(), ks->geo()->lat() );
 
-	ks->infoBoxes()->focusObjChanged( ks->options()->focusObject );
-	ks->infoBoxes()->focusCoordChanged( ks->map()->focus() );
-
+//	ks->infoBoxes()->focusObjChanged( Options::focusObject() );
+//	ks->infoBoxes()->focusCoordChanged( ks->map()->focus() );
+	ks->map()->showFocusCoords();
+	
 	ks->data()->setHourAngle( ks->LST()->Hours() - ks->map()->focus()->ra()->Hours() );
 
 	ks->map()->setOldFocus( ks->map()->focus() );
@@ -597,8 +693,8 @@ void KStars::privatedata::buildGUI() {
 	ks->map()->oldfocus()->setAlt( ks->map()->focus()->alt()->Degrees() );
 
 	// check zoom in/out buttons
-	if ( ks->options()->ZoomFactor >= MAXZOOM ) ks->actionCollection()->action("zoom_in")->setEnabled( false );
-	if ( ks->options()->ZoomFactor <= MINZOOM ) ks->actionCollection()->action("zoom_out")->setEnabled( false );
+	if ( Options::zoomFactor() >= MAXZOOM ) ks->actionCollection()->action("zoom_in")->setEnabled( false );
+	if ( Options::zoomFactor() <= MINZOOM ) ks->actionCollection()->action("zoom_out")->setEnabled( false );
 
 	kapp->dcopClient()->resume();
 }
