@@ -18,13 +18,23 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-
 #include <kmessagebox.h>
-
-#include "kstars.h"
-#include "locationdialog.h"
-
 #include <kstandarddirs.h>
+#include <klineedit.h>
+
+#include <qlayout.h>
+#include <qpushbutton.h>
+#include <qgroupbox.h>
+#include <qlabel.h>
+#include <qlistbox.h>
+#include <qcombobox.h>
+#include <qfile.h>
+
+#include "locationdialog.h"
+#include "kstars.h"
+#include "kstarsdata.h"
+#include "mapcanvas.h"
+#include "dmsbox.h"
 
 LocationDialog::LocationDialog( QWidget* parent )
     : KDialogBase( KDialogBase::Plain, i18n( "Set Geographic Location" ), Ok|Cancel, Ok, parent ) {
@@ -101,8 +111,9 @@ LocationDialog::LocationDialog( QWidget* parent )
 	for ( int i=0; i<25; ++i )
 		TZBox->insertItem( QString("%1").arg( (double)(i-12), 0, 'f', 2 ) );
 
-	QMap<QString, TimeZoneRule>::Iterator it;
-	for ( it = p->data()->Rulebook.begin(); it != p->data()->Rulebook.end(); ++it )
+	QMap<QString, TimeZoneRule>::Iterator it = p->data()->Rulebook.begin();
+	QMap<QString, TimeZoneRule>::Iterator itEnd = p->data()->Rulebook.end();
+	for ( ; it != itEnd; ++it )
 		TZRuleBox->insertItem( it.key() );
 
 	ClearFields = new QPushButton( i18n( "Clear Fields" ), CoordBox, "ClearFields" );
@@ -219,7 +230,7 @@ void LocationDialog::initCityList( void ) {
 
 		//If TZ is not even integer value, add it to listbox 
 		if ( loc->TZ0() - int( loc->TZ0() ) && ! TZBox->listBox()->findItem( QString("%1").arg( loc->TZ0(), 0, 'f', 2 ) ) ) {
-			for ( unsigned int i=0; i<TZBox->count(); ++i ) {
+			for ( unsigned int i=0; i<((unsigned int) TZBox->count()); ++i ) {
 				if ( TZBox->text( i ).toDouble() > loc->TZ0() ) {
 					TZBox->insertItem( QString("%1").arg( loc->TZ0(), 0, 'f', 2 ), i-1 );
 					break;
@@ -542,4 +553,12 @@ void LocationDialog::slotOk( void ) {
 	if ( bOkToClose ) accept();
 }
 
+QString LocationDialog::selectedCity() { return NewCityName->text(); }
+
+QString LocationDialog::selectedProvince() { return NewProvinceName->text(); }
+
+QString LocationDialog::selectedCountry() { return NewCountryName->text(); }
+
+bool LocationDialog::addCityEnabled() { return AddCityButton->isEnabled(); }
+
 #include "locationdialog.moc"
