@@ -17,20 +17,27 @@
 
 //This file contains Event handlers for the SkyMap class.
 
+#include <stdlib.h>
+#include <math.h> //using fabs()
+
 #include <qcursor.h>
+#include <qpainter.h>
+#include <qfile.h>
 
 #include <kiconloader.h>
 #include <kstatusbar.h>
 #include <kshortcut.h> //KKey class
-#include <stdlib.h>
-#include <math.h> //using fabs()
 
-#include "infoboxes.h"
-#include "kstars.h"
 #include "skymap.h"
+#include "Options.h"
+#include "kstars.h"
+#include "kstarsdata.h"
 #include "ksutils.h"
+#include "simclock.h"
+#include "infoboxes.h"
 #include "ksfilereader.h"
 #include "kspopupmenu.h"
+#include "ksmoon.h"
 
 void SkyMap::resizeEvent( QResizeEvent * )
 {
@@ -48,7 +55,7 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
 	QString s;
 	bool arrowKeyPressed( false );
 	float step = 1.0;
-	if ( e->state() & ShiftButton ) step = 2.0;
+	if ( e->state() & ShiftButton ) step = 10.0;
 
 	//If the DCOP resume key was pressed, we process it here
 	if ( ! data->resumeKey.isNull() && e->key() == data->resumeKey.keyCodeQt() ) {
@@ -59,11 +66,11 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
 
 	switch ( e->key() ) {
 		case Key_Left :
-			if ( data->options->useAltAz ) {
-				focus()->setAz( focus()->az()->Degrees() - step * MINZOOM/zoomFactor() );
+			if ( Options::useAltAz() ) {
+				focus()->setAz( dms( focus()->az()->Degrees() - step * MINZOOM/Options::zoomFactor() ).reduce() );
 				focus()->HorizontalToEquatorial( data->LST, data->geo()->lat() );
 			} else {
-				focus()->setRA( focus()->ra()->Hours() + 0.05*step * MINZOOM/zoomFactor() );
+				focus()->setRA( focus()->ra()->Hours() + 0.05*step * MINZOOM/Options::zoomFactor() );
 				focus()->EquatorialToHorizontal( data->LST, data->geo()->lat() );
 			}
 
@@ -73,11 +80,11 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
 			break;
 
 		case Key_Right :
-			if ( data->options->useAltAz ) {
-				focus()->setAz( focus()->az()->Degrees() + step * MINZOOM/zoomFactor() );
+			if ( Options::useAltAz() ) {
+				focus()->setAz( dms( focus()->az()->Degrees() + step * MINZOOM/Options::zoomFactor() ).reduce() );
 				focus()->HorizontalToEquatorial( data->LST, data->geo()->lat() );
 			} else {
-				focus()->setRA( focus()->ra()->Hours() - 0.05*step * MINZOOM/zoomFactor() );
+				focus()->setRA( focus()->ra()->Hours() - 0.05*step * MINZOOM/Options::zoomFactor() );
 				focus()->EquatorialToHorizontal( data->LST, data->geo()->lat() );
 			}
 
@@ -87,12 +94,12 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
 			break;
 
 		case Key_Up :
-			if ( data->options->useAltAz ) {
-				focus()->setAlt( focus()->alt()->Degrees() + step * MINZOOM/zoomFactor() );
+			if ( Options::useAltAz() ) {
+				focus()->setAlt( focus()->alt()->Degrees() + step * MINZOOM/Options::zoomFactor() );
 				if ( focus()->alt()->Degrees() > 90.0 ) focus()->setAlt( 90.0 );
 				focus()->HorizontalToEquatorial( data->LST, data->geo()->lat() );
 			} else {
-				focus()->setDec( focus()->dec()->Degrees() + step * MINZOOM/zoomFactor() );
+				focus()->setDec( focus()->dec()->Degrees() + step * MINZOOM/Options::zoomFactor() );
 				if (focus()->dec()->Degrees() > 90.0) focus()->setDec( 90.0 );
 				focus()->EquatorialToHorizontal( data->LST, data->geo()->lat() );
 			}
@@ -103,12 +110,12 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
 			break;
 
 		case Key_Down:
-			if ( data->options->useAltAz ) {
-				focus()->setAlt( focus()->alt()->Degrees() - step * MINZOOM/zoomFactor() );
+			if ( Options::useAltAz() ) {
+				focus()->setAlt( focus()->alt()->Degrees() - step * MINZOOM/Options::zoomFactor() );
 				if ( focus()->alt()->Degrees() < -90.0 ) focus()->setAlt( -90.0 );
 				focus()->HorizontalToEquatorial( data->LST, data->geo()->lat() );
 			} else {
-				focus()->setDec( focus()->dec()->Degrees() - step * MINZOOM/zoomFactor() );
+				focus()->setDec( focus()->dec()->Degrees() - step * MINZOOM/Options::zoomFactor() );
 				if (focus()->dec()->Degrees() < -90.0) focus()->setDec( -90.0 );
 				focus()->EquatorialToHorizontal( data->LST, data->geo()->lat() );
 			}
@@ -214,16 +221,42 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
 			slotCenter();
 			break;
 
-//DUMP_HORIZON
-/*
-		case Key_X: //Spit out coords of horizon polygon
-			dumpHorizon = true;
+		case Key_BracketLeft:   // Begin measuring angular distance
+			if ( !isAngleMode() ) {
+				slotBeginAngularDistance();
+			}
+
+			break;
+
+		case Key_BracketRight:  // End measuring angular distance
+			if ( isAngleMode() ) {
+				slotEndAngularDistance();
+			}
+
+			break;
+
+		case Key_Escape:        // Cancel angular distance measurement
+			if  (isAngleMode() ) {
+				slotCancelAngularDistance();
+			}
+			break;
+
+		case Key_Comma:  //advance one step backward in time
+		case Key_Less:
+			if ( data->clock()->isActive() ) data->clock()->stop();
+			data->clock()->setScale( -1.0 * data->clock()->scale() ); //temporarily need negative time step
+			data->clock()->manualTick( true );
+			data->clock()->setScale( -1.0 * data->clock()->scale() ); //reset original sign of time step
+			update();
+			break;
+
+		case Key_Period: //advance one step forward in time
+			if ( data->clock()->isActive() ) data->clock()->stop();
+			data->clock()->manualTick( true );
+			update();
 			break;
-*/
-//END_DUMP_HORIZON
 
 //TIMING
-
 		case Key_T: //loop through all objects, get Sin, Cos, Rad
 		{
 
@@ -296,7 +329,6 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
 			kdDebug() << "time taken for reading deep sky data old code  (1 times): (msec): " << t4.elapsed() << endl;
 
 */
-
 			break;
 		}
 
@@ -325,7 +357,7 @@ void SkyMap::keyPressEvent( QKeyEvent *e ) {
 }
 
 void SkyMap::stopTracking() {
-	if ( ksw && data->options->isTracking ) ksw->slotTrack();
+	if ( ksw && Options::isTracking() ) ksw->slotTrack();
 }
 
 void SkyMap::keyReleaseEvent( QKeyEvent *e ) {
@@ -337,9 +369,10 @@ void SkyMap::keyReleaseEvent( QKeyEvent *e ) {
 			slewing = false;
 			scrollCount = 0;
 
-			setDestination( focus() );
-			if ( data->options->useAltAz )
-				destination()->EquatorialToHorizontal( data->LST, data->options->Location()->lat() );
+			if ( Options::useAltAz() ) 
+				setDestinationAltAz( focus()->alt()->Degrees(), focus()->az()->Degrees() );
+			else
+				setDestination( focus() );
 
 			showFocusCoords();
 			forceUpdate();	// Need a full update to draw faint objects that are not drawn while slewing.
@@ -348,6 +381,33 @@ void SkyMap::keyReleaseEvent( QKeyEvent *e ) {
 }
 
 void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
+	if ( Options::useHoverLabel() ) {
+		//First of all, if the transientObject() pointer is not NULL, then 
+		//we just moved off of a hovered object.  Begin fading the label.
+		if ( transientObject() && ! TransientTimer.isActive() ) {
+			fadeTransientLabel();
+		}
+		
+		//Start a single-shot timer to monitor whether we are currently hovering.  
+		//The idea is that whenever a moveEvent occurs, the timer is reset.  It
+		//will only timeout if there are no move events for HOVER_INTERVAL ms
+		HoverTimer.start( HOVER_INTERVAL, true );
+	}
+	
+	// Are we in angularDistanceMode?: Then draw a line
+	if ( isAngleMode() ) {
+
+		// We put this instruction here so that the first point of the 
+		// ruler is recomputed when moving the mouse. The initial 
+		// point of the ruler may change if the time step is high.
+
+		if ( Options::useAltAz() ) PreviousClickedPoint.EquatorialToHorizontal( data->LST, data->geo()->lat() );
+		beginRulerPoint = getXY( previousClickedPoint(), Options::useAltAz(), Options::useRefraction() );
+
+		endRulerPoint =  QPoint(e->x(), e->y());
+	}
+		
+	
 	//Are we dragging an infoBox?
 	if ( infoBoxes()->dragBox( e ) ) {
 		update();
@@ -381,14 +441,16 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
 		}
 	}
 
-	double dx = ( 0.5*width()  - e->x() )/zoomFactor();
-	double dy = ( 0.5*height() - e->y() )/zoomFactor();
+	double dx = ( 0.5*width()  - e->x() )/Options::zoomFactor();
+	double dy = ( 0.5*height() - e->y() )/Options::zoomFactor();
 	double dyPix = 0.5*height() - e->y();
 
 	if (unusablePoint (dx, dy)) return;	// break if point is unusable
 
 	//determine RA, Dec of mouse pointer
-	setMousePoint( dXdYToRaDec( dx, dy, data->options->useAltAz, data->LST, data->geo()->lat() ) );
+	setMousePoint( dXdYToRaDec( dx, dy, Options::useAltAz(), data->LST, data->geo()->lat() ) );
+	mousePoint()->EquatorialToHorizontal( data->LST, data->geo()->lat() );
+
 
 	if ( midMouseButtonDown ) { //zoom according to y-offset
 		float yoff = dyPix - y0;
@@ -409,11 +471,11 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
 		if (!slewing) {
 			slewing = true;
 			infoBoxes()->focusObjChanged( i18n( "nothing" ) );
-			if ( ksw && data->options->isTracking ) ksw->slotTrack(); //toggle tracking off
+			if ( ksw && Options::isTracking() ) ksw->slotTrack(); //toggle tracking off
 		}
 
 		//Update focus such that the sky coords at mouse cursor remain approximately constant
-		if ( data->options->useAltAz ) {
+		if ( Options::useAltAz() ) {
 			mousePoint()->EquatorialToHorizontal( data->LST, data->geo()->lat() );
 			clickedPoint()->EquatorialToHorizontal( data->LST, data->geo()->lat() );
 			dms dAz = mousePoint()->az()->Degrees() - clickedPoint()->az()->Degrees();
@@ -421,8 +483,8 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
 			focus()->setAz( focus()->az()->Degrees() - dAz.Degrees() ); //move focus in opposite direction
 			focus()->setAlt( focus()->alt()->Degrees() - dAlt.Degrees() );
 
-			if ( focus()->alt()->Degrees() >90.0 ) focus()->setAlt( 89.9999 );
-			if ( focus()->alt()->Degrees() <-90.0 ) focus()->setAlt( -89.9999 );
+			if ( focus()->alt()->Degrees() >90.0 ) focus()->setAlt( 90.0 );
+			if ( focus()->alt()->Degrees() <-90.0 ) focus()->setAlt( -90.0 );
 			focus()->setAz( focus()->az()->reduce() );
 			focus()->HorizontalToEquatorial( data->LST, data->geo()->lat() );
 		} else {
@@ -450,17 +512,24 @@ void SkyMap::mouseMoveEvent( QMouseEvent *e ) {
 		data->HourAngle->setH( dHA );
 
 		//redetermine RA, Dec of mouse pointer, using new focus
-		setMousePoint( dXdYToRaDec( dx, dy, data->options->useAltAz, data->LST, data->geo()->lat() ) );
+		setMousePoint( dXdYToRaDec( dx, dy, Options::useAltAz(), data->LST, data->geo()->lat() ) );
 		setClickedPoint( mousePoint() );
 
 		forceUpdate();  // must be new computed
 	} else {
 
-		QString sRA, sDec, s;
-		sRA = mousePoint()->ra()->toHMSString();
-		sDec = mousePoint()->dec()->toDMSString(true); //true = force +/- symbol
-		s = sRA + ",  " + sDec;
-		if ( ksw ) ksw->statusBar()->changeItem( s, 1 );
+		if ( ksw ) {
+			QString sX, sY, s;
+			sX = mousePoint()->az()->toDMSString(true);  //true = force +/- symbol
+			sY = mousePoint()->alt()->toDMSString(true); //true = force +/- symbol
+			s = sX + ",  " + sY;
+			ksw->statusBar()->changeItem( s, 1 );
+			
+			sX = mousePoint()->ra()->toHMSString();
+			sY = mousePoint()->dec()->toDMSString(true); //true = force +/- symbol
+			s = sX + ",  " + sY;
+			ksw->statusBar()->changeItem( s, 2 );
+		}
 	}
 }
 
@@ -480,21 +549,23 @@ void SkyMap::mouseReleaseEvent( QMouseEvent * ) {
 		//of the sky pixmap's width to the Zoom Circle's diameter
 		float factor = float(width()) / float(ZoomRect.width());
 
-		double dx = ( 0.5*width()  - ZoomRect.center().x() )/zoomFactor();
-		double dy = ( 0.5*height() - ZoomRect.center().y() )/zoomFactor();
+		double dx = ( 0.5*width()  - ZoomRect.center().x() )/Options::zoomFactor();
+		double dy = ( 0.5*height() - ZoomRect.center().y() )/Options::zoomFactor();
 
-		SkyPoint newcenter = dXdYToRaDec( dx, dy, data->options->useAltAz, data->LST, data->geo()->lat() );
+		SkyPoint newcenter = dXdYToRaDec( dx, dy, Options::useAltAz(), data->LST, data->geo()->lat() );
 		setClickedPoint( &newcenter );
 		setClickedObject( NULL );
 		setFocusObject( NULL );
 		setFocus( &newcenter );
 		setDestination( &newcenter );
 		setOldFocus( &newcenter );
-		ksw->zoom( zoomFactor() * factor );
-
+		ksw->zoom( Options::zoomFactor() * factor );
+		
+		setDefaultMouseCursor();
 		ZoomRect = QRect(); //invalidate ZoomRect
 		forceUpdate();
 	} else {
+		setDefaultMouseCursor();
 		ZoomRect = QRect(); //just in case user Ctrl+clicked + released w/o dragging...
 	}
 
@@ -502,8 +573,12 @@ void SkyMap::mouseReleaseEvent( QMouseEvent * ) {
 	if (mouseButtonDown) { //false if double-clicked, because it's unset there.
 		mouseButtonDown = false;
 		if ( slewing ) {
-			setDestination( focus() );
 			slewing = false;
+			
+			if ( Options::useAltAz() ) 
+				setDestinationAltAz( focus()->alt()->Degrees(), focus()->az()->Degrees() );
+			else
+				setDestination( focus() );
 		}
 
 		setOldFocus( focus() );
@@ -523,6 +598,7 @@ void SkyMap::mousePressEvent( QMouseEvent *e ) {
 
 	if ( (e->state() & ControlButton) && (e->button() == LeftButton) ) {
 		ZoomRect.moveCenter( e->pos() );
+		setZoomMouseCursor();
 		update(); //refresh without redrawing skymap
 		return;
 	}
@@ -531,8 +607,8 @@ void SkyMap::mousePressEvent( QMouseEvent *e ) {
 	QTimer t;
 	t.singleShot (500, this, SLOT (setMouseMoveCursor()));
 
-	double dx = ( 0.5*width()  - e->x() )/zoomFactor();
-	double dy = ( 0.5*height() - e->y() )/zoomFactor();
+	double dx = ( 0.5*width()  - e->x() )/Options::zoomFactor();
+	double dy = ( 0.5*height() - e->y() )/Options::zoomFactor();
 	if (unusablePoint (dx, dy)) return;	// break if point is unusable
 
 	if ( !midMouseButtonDown && e->button() == MidButton ) {
@@ -547,272 +623,22 @@ void SkyMap::mousePressEvent( QMouseEvent *e ) {
 		}
 
 		//determine RA, Dec of mouse pointer
-		setMousePoint( dXdYToRaDec( dx, dy, data->options->useAltAz,
-				data->LST, data->geo()->lat(), data->options->useRefraction ) );
+		setMousePoint( dXdYToRaDec( dx, dy, Options::useAltAz(),
+				data->LST, data->geo()->lat(), Options::useRefraction() ) );
 		setClickedPoint( mousePoint() );
 
-		double r0 = 200.0/zoomFactor();  //the maximum search radius
-		double rmin = r0;
+		//Find object nearest to clickedPoint()
+		setClickedObject( objectNearest( clickedPoint() ) );
 
-		//Search stars database for nearby object.
-		double rstar_min = r0;
-		double starmag_min = 20.0;      //absurd initial value
-		int istar_min = -1;
-
-		if ( data->options->drawSAO ) { //Can only click on a star if it's being drawn!
-
-			//test RA and dec to see if this star is roughly nearby
-
-			for ( register unsigned int i=0; i<data->starList.count(); ++i ) {
-				SkyObject *test = (SkyObject *)data->starList.at(i);
-
-				double dRA = test->ra()->Hours() - clickedPoint()->ra()->Hours();
-				double dDec = test->dec()->Degrees() - clickedPoint()->dec()->Degrees();
-				//determine angular distance between this object and mouse cursor
-				double f = 15.0*cos( test->dec()->radians() );
-				double r = f*f*dRA*dRA + dDec*dDec; //no need to take sqrt, we just want to ID smallest value.
-				if (r < r0 && test->mag() < starmag_min ) {
-					istar_min = i;
-					rstar_min = r;
-					starmag_min = test->mag();
-				}
+		if ( clickedObject() ) {
+			setClickedPoint( clickedObject() );
+			
+			if ( e->button() == RightButton ) {
+				clickedObject()->showPopupMenu( pmenu, QCursor::pos() );
 			}
-		}
-
-//Next, find the nearest solar system body within r0
-		double r = 0.0;
-		double rsolar_min = r0;
-		SkyObject *solarminobj = NULL;
-
-		if ( data->options->drawPlanets )
-			solarminobj = data->PCat->findClosest(clickedPoint(), r);
-
-		if ( r < r0 ) {
-			rsolar_min = r;
-		} else {
-			solarminobj = NULL;
-		}
-
-		//Moon
-		if ( data->options->drawMoon ) {
-			double dRA = data->Moon->ra()->Hours() - clickedPoint()->ra()->Hours();
-			double dDec = data->Moon->dec()->Degrees() - clickedPoint()->dec()->Degrees();
-			double f = 15.0*cos( data->Moon->dec()->radians() );
-			r = f*f*dRA*dRA + dDec*dDec; //no need to take sqrt, we just want to ID smallest value.
-			if (r < rsolar_min) {
-				solarminobj= data->Moon;
-				rsolar_min = r;
-			}
-		}
-
-		//Asteroids
-		if ( data->options->drawAsteroids ) {
-			for ( KSAsteroid *ast = data->asteroidList.first(); ast; ast = data->asteroidList.next() ) {
-				//test RA and dec to see if this object is roughly nearby
-				double dRA = ast->ra()->Hours() - clickedPoint()->ra()->Hours();
-				double dDec = ast->dec()->Degrees() - clickedPoint()->dec()->Degrees();
-				double f = 15.0*cos( ast->dec()->radians() );
-				double r = f*f*dRA*dRA + dDec*dDec; //no need to take sqrt, we just want to ID smallest value.
-				if ( r < rsolar_min && ast->mag() < data->options->magLimitAsteroid ) {
-					solarminobj = ast;
-					rsolar_min = r;
-				}
-			}
-		}
-
-		//Comets
-		if ( data->options->drawComets ) {
-			for ( KSComet *com = data->cometList.first(); com; com = data->cometList.next() ) {
-				//test RA and dec to see if this object is roughly nearby
-				double dRA = com->ra()->Hours() - clickedPoint()->ra()->Hours();
-				double dDec = com->dec()->Degrees() - clickedPoint()->dec()->Degrees();
-				double f = 15.0*cos( com->dec()->radians() );
-				double r = f*f*dRA*dRA + dDec*dDec; //no need to take sqrt, we just want to ID smallest value.
-				if ( r < rsolar_min ) {
-					solarminobj = com;
-					rsolar_min = r;
-				}
-			}
-		}
-
-//Next, search for nearest deep-sky object within r0
-		double rmess_min = r0;
-		double rngc_min = r0;
-		double ric_min = r0;
-		double rother_min = r0;
-		int imess_min = -1;
-		int ingc_min = -1;
-		int iic_min = -1;
-		int iother_min = -1;
-
-		for ( DeepSkyObject *o = data->deepSkyList.first(); o; o = data->deepSkyList.next() ) {
-			bool checkObject = false;
-			if ( o->isCatalogM() &&
-					( data->options->drawMessier || data->options->drawMessImages ) ) checkObject = true;
-			if ( o->isCatalogNGC() && data->options->drawNGC ) checkObject = true;
-			if ( o->isCatalogIC() && data->options->drawIC ) checkObject = true;
-			if ( o->catalog().isEmpty() && data->options->drawOther ) checkObject = true;
-
-			if ( checkObject ) {
-				//test RA and dec to see if this object is roughly nearby
-				double dRA = o->ra()->Hours() - clickedPoint()->ra()->Hours();
-				double dDec = o->dec()->Degrees() - clickedPoint()->dec()->Degrees();
-				double f = 15.0*cos( o->dec()->radians() );
-				double r = f*f*dRA*dRA + dDec*dDec; //no need to take sqrt, we just want to ID smallest value.
-				if ( o->isCatalogM() && r < rmess_min) {
-					imess_min = data->deepSkyList.at();
-					rmess_min = r;
-				}
-				if ( o->isCatalogNGC() && r < rngc_min) {
-					ingc_min = data->deepSkyList.at();
-					rngc_min = r;
-				}
-				if ( o->isCatalogIC() && r < ric_min) {
-					iic_min = data->deepSkyList.at();
-					ric_min = r;
-				}
-				if ( o->catalog().isEmpty() && r < rother_min) {
-					iother_min = data->deepSkyList.at();
-					rother_min = r;
-				}
-			}
-		}
-
-//Next, search for nearest object within r0 among the custom catalogs
-		double rcust_min = r0;
-		int icust_min = -1;
-		int icust_cat = -1;
-
-		for ( register unsigned int j=0; j<data->options->CatalogCount; ++j ) {
-			if ( data->options->drawCatalog[j] ) {
-				QPtrList<DeepSkyObject> cat = data->CustomCatalogs[ data->options->CatalogName[j] ];
-
-				for ( register unsigned int i=0; i<cat.count(); ++i ) {
-					//test RA and dec to see if this object is roughly nearby
-					SkyObject *test = (SkyObject *)cat.at(i);
-					double dRA = test->ra()->Hours()-clickedPoint()->ra()->Hours();
-					double dDec = test->dec()->Degrees()-clickedPoint()->dec()->Degrees();
-					double f = 15.0*cos( test->dec()->radians() );
-					double r = f*f*dRA*dRA + dDec*dDec; //no need to take sqrt, we just want to ID smallest value.
-					if (r < rcust_min) {
-						icust_cat = j;
-						icust_min = i;
-						rcust_min = r;
-					}
-				}
-			}
-		}
-
-		int jmin(-1);
-		int icat(-1);
-		setClickedObject( NULL );
-		StarObject *starobj = NULL;
-
-		//Among the objects selected within r0, prioritize the selection by catalog:
-		//Planets, Messier, NGC, IC, stars
-		if ( istar_min >= 0 && rstar_min < r0 ) {
-			rmin = rstar_min;
-			icat = 0; //set catalog to star
-		}
-
-		//IC object overrides star, unless star is twice as close as IC object
-		if ( iic_min >= 0 && ric_min < r0 && rmin > 0.5*ric_min ) {
-			rmin = ric_min;
-			icat = 1; //set catalog to Deep Sky
-			jmin = iic_min;
-		}
-
-		//NGC object overrides previous selection, unless previous is twice as close
-		if ( ingc_min >= 0 && rngc_min < r0 && rmin > 0.5*rngc_min ) {
-			rmin = rngc_min;
-			icat = 1; //set catalog to Deep Sky
-			jmin = ingc_min;
-		}
-
-		//"other" object overrides previous selection, unless previous is twice as close
-		if ( iother_min >= 0 && rother_min < r0 && rmin > 0.5*rother_min ) {
-			rmin = rother_min;
-			icat = 1; //set catalog to Deep Sky
-			jmin = iother_min;
-		}
-
-		//Messier object overrides previous selection, unless previous is twice as close
-		if ( imess_min >= 0 && rmess_min < r0 && rmin > 0.5*rmess_min ) {
-			rmin = rmess_min;
-			icat = 1; //set catalog to Deep Sky
-			jmin = imess_min;
-		}
-
-		//Custom object overrides previous selection, unless previous is twice as close
-		if ( icust_min >= 0 && rcust_min < r0 && rmin > 0.5*rcust_min ) {
-			rmin = rcust_min;
-			icat = 2; //set catalog to Custom
-		}
-
-		//Solar system body overrides previous selection, unless previous selection is twice as close
-		if ( solarminobj != NULL && rmin > 0.5*rsolar_min ) {
-			rmin = rsolar_min;
-			icat = 3; //set catalog to solar system
-		}
-
-		if ( icat >= 0 && rmin < r0 ) { //was any object found within r0?
-			QPtrList<DeepSkyObject> cat;
-
-			switch (icat) {
-				case 0: //star
-					starobj = (StarObject *)data->starList.at(istar_min);
-					setClickedObject( (SkyObject *)data->starList.at(istar_min) );
-
-					setClickedPoint( clickedObject() );
-
-					if ( e->button() == RightButton ) {
-						pmenu->createStarMenu( starobj );
-						pmenu->popup( QCursor::pos() );
-					}
-					break;
-
-				case 1: //Deep-Sky Objects
-					setClickedObject( (SkyObject *)data->deepSkyList.at(jmin) );
-					setClickedPoint( clickedObject());
-
-					if (e->button() == RightButton ) {
-						pmenu->createDeepSkyObjectMenu( clickedObject() );
-						pmenu->popup( QCursor::pos() );
-					}
-					break;
-
-				case 2: //Custom Catalog Object
-					cat = data->CustomCatalogs[ data->options->CatalogName[icust_cat] ];
-					setClickedObject( (SkyObject *)cat.at(icust_min) );
-					setClickedPoint( clickedObject() );
-
-					if ( e->button() == RightButton ) {
-						pmenu->createCustomObjectMenu( clickedObject() );
-						pmenu->popup( QCursor::pos() );
-					}
-					break;
-
-				case 3: //solar system object
-					setClickedObject(solarminobj);
-					if ( clickedObject() != NULL ) setClickedPoint( clickedObject() );
-
-					if ( e->button() == RightButton ) {
-						pmenu->createPlanetMenu( clickedObject() );
-						pmenu->popup( QCursor::pos() );
-					}
-					break;
-			}
-
+			
 			if ( ksw && e->button() == LeftButton ) {
-				//Display name in status bar
-				//STAR_IDENTIFICATION
-				//if ( icat == 0 ) {
-				//	ksw->statusBar()->changeItem( i18n(clickedObject()->longname().utf8()) + "  " +
-				//			QString("%1").arg(data->starList.at()/1000) + ": " +
-				//			QString("%1").arg(data->starList.at()%1000 + 1), 0 );
-				//} else {
-					ksw->statusBar()->changeItem( i18n(clickedObject()->longname().utf8()), 0 );
-				//}
+				ksw->statusBar()->changeItem( clickedObject()->translatedLongName(), 0 );
 			}
 		} else {
 			//Empty sky selected.  If left-click, display "nothing" in the status bar.
@@ -848,8 +674,8 @@ void SkyMap::mouseDoubleClickEvent( QMouseEvent *e ) {
 			return;
 		}
 
-		double dx = ( 0.5*width()  - e->x() )/zoomFactor();
-		double dy = ( 0.5*height() - e->y() )/zoomFactor();
+		double dx = ( 0.5*width()  - e->x() )/Options::zoomFactor();
+		double dy = ( 0.5*height() - e->y() )/Options::zoomFactor();
 		if (unusablePoint (dx, dy)) return;	// break if point is unusable
 
 		if (mouseButtonDown ) mouseButtonDown = false;
@@ -859,9 +685,11 @@ void SkyMap::mouseDoubleClickEvent( QMouseEvent *e ) {
 
 void SkyMap::paintEvent( QPaintEvent * )
 {
-	KStarsOptions* options = data->options;
-
-// if the skymap should be only repainted and constellations need not to be new computed; call this with update() (default)
+	//If computeSkymap is false, then we just refresh the window using the stored sky pixmap 
+	//and draw the "overlays" on top.  This lets us update the overlay information rapidly
+	//without needing to recompute the entire skymap.
+	//use update() to trigger this "short" paint event; to force a full "recompute" 
+	//of the skymap, use forceUpdate().
 	if (!computeSkymap)
 	{
 		QPixmap *sky2 = new QPixmap( *sky );
@@ -871,26 +699,25 @@ void SkyMap::paintEvent( QPaintEvent * )
 		return ; // exit because the pixmap is repainted and that's all what we want
 	}
 
-// if the sky should be recomputed (this is not every paintEvent call needed, explicitly call with forceUpdate())
 	QPainter psky;
-
 	setMapGeometry();
 
-//checkSlewing combines the slewing flag (which is true when the display is actually in motion),
-//the hideOnSlew option (which is true if slewing should hide objects),
-//and clockSlewing (which is true if the timescale exceeds options()->slewTimeScale)
+	//checkSlewing combines the slewing flag (which is true when the display is actually in motion),
+	//the hideOnSlew option (which is true if slewing should hide objects),
+	//and clockSlewing (which is true if the timescale exceeds Options::slewTimeScale)
 	bool checkSlewing = ( ( slewing || ( clockSlewing && data->clock()->isActive() ) )
-				&& options->hideOnSlew );
+				&& Options::hideOnSlew() );
 
-//shortcuts to inform wheter to draw different objects
-	bool drawPlanets( options->drawPlanets && !(checkSlewing && options->hidePlanets) );
-	bool drawMW( options->drawMilkyWay && !(checkSlewing && options->hideMW) );
-	bool drawCNames( options->drawConstellNames && !(checkSlewing && options->hideCNames) );
-	bool drawCLines( options->drawConstellLines &&!(checkSlewing && options->hideCLines) );
-	bool drawGrid( options->drawGrid && !(checkSlewing && options->hideGrid) );
+	//shortcuts to inform wheter to draw different objects
+	bool drawPlanets( Options::showPlanets() && !(checkSlewing && Options::hidePlanets() ) );
+	bool drawMW( Options::showMilkyWay() && !(checkSlewing && Options::hideMilkyWay() ) );
+	bool drawCNames( Options::showCNames() && !(checkSlewing && Options::hideCNames() ) );
+	bool drawCLines( Options::showCLines() &&!(checkSlewing && Options::hideCLines() ) );
+	bool drawCBounds( Options::showCBounds() &&!(checkSlewing && Options::hideCBounds() ) );
+	bool drawGrid( Options::showGrid() && !(checkSlewing && Options::hideGrid() ) );
 
 	psky.begin( sky );
-	psky.fillRect( 0, 0, width(), height(), QBrush( options->colorScheme()->colorNamed( "SkyColor" ) ) );
+	psky.fillRect( 0, 0, width(), height(), QBrush( data->colorScheme()->colorNamed( "SkyColor" ) ) );
 
 	QFont stdFont = psky.font();
 	QFont smallFont = psky.font();
@@ -898,13 +725,16 @@ void SkyMap::paintEvent( QPaintEvent * )
 
 	if ( drawMW ) drawMilkyWay( psky );
 	if ( drawGrid ) drawCoordinateGrid( psky );
-	if ( data->options->drawEquator ) drawEquator( psky );
-	if ( options->drawEcliptic ) drawEcliptic( psky );
+	
+	if ( drawCBounds ) drawConstellationBoundaries( psky );
 	if ( drawCLines ) drawConstellationLines( psky );
 	if ( drawCNames ) drawConstellationNames( psky, stdFont );
 
+	if ( Options::showEquator() ) drawEquator( psky );
+	if ( Options::showEcliptic() ) drawEcliptic( psky );
+
 	// stars and planets use the same font size
-	if ( zoomFactor() < 10.*MINZOOM ) {
+	if ( Options::zoomFactor() < 10.*MINZOOM ) {
 		psky.setFont( smallFont );
 	} else {
 		psky.setFont( stdFont );
