@@ -15,146 +15,162 @@
  *                                                                         *
  ***************************************************************************/
 
-//DEBUG
-#include <kglobal.h>
+#include <iostream>
 
+#include <kglobal.h>
+#include <qpoint.h>
 #include <qregexp.h>
+
 #include "skyobject.h"
-#include "ksutils.h"
+#include "ksnumbers.h"
 #include "dms.h"
 #include "geolocation.h"
-#include <iostream>
+#include "kstarsdatetime.h"
+
+QString SkyObject::emptyString = QString("");
+QString SkyObject::unnamedString = QString(i18n("unnamed"));
+QString SkyObject::unnamedObjectString = QString(i18n("unnamed object"));
+QString SkyObject::starString = QString("star");
 
 SkyObject::SkyObject( SkyObject &o ) : SkyPoint( o ) {
 	setType( o.type() );
 	Magnitude = o.mag();
-	Name = o.name();
-	Name2 = o.name2();
-	LongName = o.longname();
+	setName(o.name());
+	setName2(o.name2());
+	setLongName(o.longname());
 	ImageList = o.ImageList;
 	ImageTitle = o.ImageTitle;
 	InfoList = o.InfoList;
 	InfoTitle = o.InfoTitle;
-	setLongName(o.longname());
 }
 
 SkyObject::SkyObject( int t, dms r, dms d, float m,
 						QString n, QString n2, QString lname ) : SkyPoint( r, d) {
 	setType( t );
 	Magnitude = m;
-	Name = n;
-	Name2 = n2;
-	setLongName( lname );
+	Name = 0;
+	setName(n);
+	Name2 = 0;
+	setName2(n2);
+	LongName = 0;
+	setLongName(lname);
 }
 
 SkyObject::SkyObject( int t, double r, double d, float m,
 						QString n, QString n2, QString lname ) : SkyPoint( r, d) {
 	setType( t );
 	Magnitude = m;
-	Name = n;
-	Name2 = n2;
-	setLongName( lname );
+	Name = 0;
+	setName(n);
+	Name2 = 0;
+	setName2(n2);
+	LongName = 0;
+	setLongName(lname);
+}
+
+SkyObject::~SkyObject() {
+	delete Name;
+	delete Name2;
+	delete LongName;
 }
 
 void SkyObject::setLongName( const QString &longname ) {
+	delete LongName;
 	if ( longname.isEmpty() ) {
-		if ( translatedName().length() )
-			LongName = translatedName();
-		else if ( Name2.length() )
-			LongName = Name2;
+		if ( hasName() )
+			LongName = new QString(translatedName());
+		else if ( hasName2() )
+			LongName = new QString(*Name2);
 		else
-			LongName = i18n( "unnamed object" );
+			LongName = 0;
 	} else {
-		LongName = longname;
+		LongName = new QString(longname);
 	}
 }
 
-QTime SkyObject::riseSetTime( long double jd, const GeoLocation *geo, bool rst ) {
+QTime SkyObject::riseSetTime( const KStarsDateTime &dt, const GeoLocation *geo, bool rst ) {
 	//this object does not rise or set; return an invalid time
 	if ( checkCircumpolar(geo->lat()) )
 		return QTime( 25, 0, 0 );
 
-	QTime UT = riseSetTimeUT( jd, geo, rst );
-
-	//convert UT to LT;
-	return UT.addSecs( int( 3600.0*geo->TZ() ) );
+	//First of all, if the object is below the horizon at date/time dt, adjust the time 
+	//to bring it above the horizon
+	KStarsDateTime dt2 = dt;
+	SkyPoint p = recomputeCoords( dt, geo );
+	dms d( geo->GSTtoLST( dt.gst() ) );
+	p.EquatorialToHorizontal( &d, geo->lat() );
+	if ( p.alt()->Degrees() < 0.0 ) {
+		if ( p.az()->Degrees() < 180.0 ) { //object has not risen yet
+			dt2 = dt.addSecs( 12.*3600. );
+		} else { //object has already set
+			dt2 = dt.addSecs( -12.*3600. );
+		}
+	}
+	
+	return geo->UTtoLT( KStarsDateTime( dt2.date(), riseSetTimeUT( dt2, geo, rst ) ) ).time();
 }
 
-QTime SkyObject::riseSetTimeUT( long double jd, const GeoLocation *geo, bool riseT) {
+QTime SkyObject::riseSetTimeUT( const KStarsDateTime &dt, const GeoLocation *geo, bool riseT ) {
 	// First trial to calculate UT
+	QTime UT = auxRiseSetTimeUT( dt, geo, ra(), dec(), riseT );
 	
-	QTime UT = auxRiseSetTimeUT(jd, geo, ra(), dec(), riseT);
-
 	// We iterate once more using the calculated UT to compute again
 	// the ra and dec for that time and hence the rise/set time.
-
-	long double jd0 = newJDfromJDandUT( jd, UT );
-	SkyPoint sp = computeCoordsForJD( jd0, geo );
-
-	UT = auxRiseSetTimeUT(jd0, geo, sp.ra(), sp.dec(), riseT);
+	// Also, adjust the date by +/- 1 day, if necessary
+	KStarsDateTime dt0 = dt;
+	dt0.setTime( UT );
+	if ( riseT && dt0 > dt ) {
+		dt0 = dt0.addDays( -1 );
+	} else if ( ! riseT && dt0 < dt ) {
+		dt0 = dt0.addDays( 1 );
+	}
+	
+	SkyPoint sp = recomputeCoords( dt0, geo );
+	UT = auxRiseSetTimeUT( dt0, geo, sp.ra(), sp.dec(), riseT );
 
 	// We iterate a second time (For the Moon the second iteration changes
 	// aprox. 1.5 arcmin the coordinates).
-	
-	jd0 = newJDfromJDandUT( jd0, UT );
-	sp = computeCoordsForJD( jd0, geo );
-
-	UT = auxRiseSetTimeUT(jd0, geo, sp.ra(), sp.dec(), riseT);
-
+	dt0.setTime( UT );
+	sp = recomputeCoords( dt0, geo );
+	UT = auxRiseSetTimeUT( dt0, geo, sp.ra(), sp.dec(), riseT );
 	return UT;
 }
 
-dms SkyObject::riseSetTimeLST( long double jd, const GeoLocation *geo, bool riseT) {
-	QTime UT = riseSetTimeUT(jd, geo, riseT);
-	QDateTime utTime = KSUtils::JDtoUT( jd );
-	utTime.setTime( UT );
-	return KSUtils::UTtoLST( utTime, geo->lng() );
+dms SkyObject::riseSetTimeLST( const KStarsDateTime &dt, const GeoLocation *geo, bool riseT ) {
+	KStarsDateTime rst( dt.date(), riseSetTimeUT( dt, geo, riseT) );
+	return geo->GSTtoLST( rst.gst() );
 }
 
-QTime SkyObject::auxRiseSetTimeUT( long double jd, const GeoLocation *geo,
+QTime SkyObject::auxRiseSetTimeUT( const KStarsDateTime &dt, const GeoLocation *geo,
 			const dms *righta, const dms *decl, bool riseT) {
-
-	// if riseT = true => rise Time, else setTime
-
-	dms LST = auxRiseSetTimeLST(geo->lat(), righta, decl, riseT );
-	QDateTime dt = KSUtils::JDtoUT(jd);
-	QTime UT = KSUtils::LSTtoUT( LST, dt, geo->lng());
-
-	return UT;
+	dms LST = auxRiseSetTimeLST( geo->lat(), righta, decl, riseT );
+	return dt.GSTtoUT( geo->LSTtoGST( LST ) );
 }
 
 dms SkyObject::auxRiseSetTimeLST( const dms *gLat, const dms *righta, const dms *decl, bool riseT ) {
-
-//	double r = -1.0 * tan( gLat.radians() ) * tan( decl.radians() );
-//	double H = acos( r )*180./acos(-1.0); //180/Pi converts radians to degrees
 	dms h0 = elevationCorrection();
-	double H = approxHourAngle (&h0, gLat, decl);
-
+	double H = approxHourAngle ( &h0, gLat, decl );
 	dms LST;
 
-	// rise Time or setTime
-
-	if (riseT)
+	if ( riseT )
 		LST.setH( 24.0 + righta->Hours() - H/15.0 );
 	else
 		LST.setH( righta->Hours() + H/15.0 );
 
-	LST = LST.reduce();
-
-	return LST;
+	return LST.reduce();
 }
 
 
-dms SkyObject::riseSetTimeAz(long double jd, const GeoLocation *geo, bool riseT) {
-
+dms SkyObject::riseSetTimeAz( const KStarsDateTime &dt, const GeoLocation *geo, bool riseT ) {
 	dms Azimuth;
 	double AltRad, AzRad;
 	double sindec, cosdec, sinlat, coslat, sinHA, cosHA;
 	double sinAlt, cosAlt;
 
-	QTime UT = riseSetTimeUT( jd, geo, riseT );
-	long double jd0 = newJDfromJDandUT( jd, UT );
-	SkyPoint sp = computeCoordsForJD( jd0, geo );
+	QTime UT = riseSetTimeUT( dt, geo, riseT );
+	KStarsDateTime dt0 = dt;
+	dt0.setTime( UT );
+	SkyPoint sp = recomputeCoords( dt0, geo );
 	const dms *ram = sp.ra0();
 	const dms *decm = sp.dec0();
 
@@ -170,46 +186,42 @@ dms SkyObject::riseSetTimeAz(long double jd, const GeoLocation *geo, bool riseT)
 	cosAlt = cos( AltRad );
 
 	AzRad = acos( ( sindec - sinlat*sinAlt )/( coslat*cosAlt ) );
-	// AzRad = acos( sindec /( coslat*cosAlt ) );
 	if ( sinHA > 0.0 ) AzRad = 2.0*dms::PI - AzRad; // resolve acos() ambiguity
 	Azimuth.setRadians( AzRad );
 
 	return Azimuth;
 }
 
-QTime SkyObject::transitTimeUT(long double jd, const GeoLocation *geo ) {
-
-	QDateTime utDateTime = KSUtils::JDtoUT( jd );
-	dms LST = KSUtils::UTtoLST( utDateTime, geo->lng() );
+QTime SkyObject::transitTimeUT( const KStarsDateTime &dt, const GeoLocation *geo ) {
+	dms LST = geo->GSTtoLST( dt.gst() );
 
 	//dSec is the number of seconds until the object transits.
-	dms HourAngle = dms ( LST.Degrees() - ra()->Degrees() );
+	dms HourAngle = dms( LST.Degrees() - ra()->Degrees() );
 	int dSec = int( -3600.*HourAngle.Hours() );
 
-	//UT0 is the first guess at the transit time.
-	QTime UT0 = utDateTime.time().addSecs( dSec );
-	long double jd0 = newJDfromJDandUT(jd, UT0);
+	//dt0 is the first guess at the transit time.
+	KStarsDateTime dt0 = dt.addSecs( dSec );
 
 	//recompute object's position at UT0 and then find
 	//transit time of this refined position
-	SkyPoint sp = computeCoordsForJD( jd0, geo );
+	SkyPoint sp = recomputeCoords( dt0, geo );
 	const dms *ram = sp.ra0();
 
 	HourAngle = dms ( LST.Degrees() - ram->Degrees() );
 	dSec = int( -3600.*HourAngle.Hours() );
 
-	return utDateTime.time().addSecs( dSec );
+	return dt.addSecs( dSec ).time();
 }
 
-QTime SkyObject::transitTime( long double jd, const GeoLocation *geo ) {
-	QTime UT = transitTimeUT(jd, geo );
-	return UT.addSecs( int( 3600.*geo->TZ() ) );
+QTime SkyObject::transitTime( const KStarsDateTime &dt, const GeoLocation *geo ) {
+	return geo->UTtoLT( KStarsDateTime( dt.date(), transitTimeUT( dt, geo ) ) ).time();
 }
 
-dms SkyObject::transitAltitude( long double jd, const GeoLocation *geo ) {
-	QTime UT = transitTimeUT( jd, geo );
-	long double jd0 = newJDfromJDandUT(jd, UT);
-	SkyPoint sp = computeCoordsForJD( jd0, geo );
+dms SkyObject::transitAltitude( const KStarsDateTime &dt, const GeoLocation *geo ) {
+	KStarsDateTime dt0 = dt;
+	QTime UT = transitTimeUT( dt, geo );
+	dt0.setTime( UT );
+	SkyPoint sp = recomputeCoords( dt0, geo );
 	const dms *decm = sp.dec0();
 
 	dms delta;
@@ -221,7 +233,7 @@ dms SkyObject::transitAltitude( long double jd, const GeoLocation *geo ) {
 	return delta;
 }
 
-double SkyObject::approxHourAngle ( const dms *h0, const dms *gLat, const dms *dec ) {
+double SkyObject::approxHourAngle( const dms *h0, const dms *gLat, const dms *dec ) {
 
 	double sh0 = sin ( h0->radians() );
 	double r = (sh0 - sin( gLat->radians() ) * sin(dec->radians() ))
@@ -261,27 +273,20 @@ dms SkyObject::elevationCorrection(void) {
 		return dms(-0.5667);
 }
 
-long double SkyObject::newJDfromJDandUT(long double jd, QTime UT) {
-	QDateTime dt = KSUtils::JDtoUT(jd);
-	dt.setTime( UT );
-	return KSUtils::UTtoJD( dt );
-}
-
-SkyPoint SkyObject::computeCoordsForJD(long double jd, const GeoLocation *geo ) {
+SkyPoint SkyObject::recomputeCoords( const KStarsDateTime &dt, const GeoLocation *geo ) {
 	//store current position
 	SkyPoint original( ra(), dec() );
 
 	// compute coords for new time jd
-	KSNumbers num(jd);
+	KSNumbers num( dt.djd() );
 	if ( isSolarSystem() && geo ) {
-//		KSPlanetBase *ksp = ksp(,);
-		dms LST = KSUtils::UTtoLST( KSUtils::JDtoUT( jd ), geo->lng() );
+		dms LST = geo->GSTtoLST( dt.gst() );
 		updateCoords( &num, true, geo->lat(), &LST );
 	} else {
 		updateCoords( &num );
 	}
 
-	//the coordinates for the date jd:
+	//the coordinates for the date dt:
 	SkyPoint sp = SkyPoint( ra(), dec() );
 
 	// restore original coords
@@ -299,7 +304,7 @@ bool SkyObject::checkCircumpolar( const dms *gLat ) {
 }
 
 QString SkyObject::typeName( void ) const {
-        if ( Type==0 ) return i18n( "Star" );
+	if ( Type==0 ) return i18n( "Star" );
 	else if ( Type==1 ) return i18n( "Catalog Star" );
 	else if ( Type==2 ) return i18n( "Planet" );
 	else if ( Type==3 ) return i18n( "Open Cluster" );
@@ -312,3 +317,39 @@ QString SkyObject::typeName( void ) const {
 	else if ( Type==10 ) return i18n( "Asteroid" );
 	else return i18n( "Unknown Type" );
 }
+void SkyObject::setName( const QString &name ) {
+//	if (name == "star" ) kdDebug() << "name == star" << endl;
+	delete Name;
+	if (!name.isEmpty())
+		Name = new QString(name);
+	else
+		{ Name = 0; /*kdDebug() << "name saved" << endl;*/ }
+}
+
+void SkyObject::setName2( const QString &name2 ) {
+	delete Name2;
+	if (!name2.isEmpty())
+		Name2 = new QString(name2);
+	else
+		{ Name2 = 0; /*kdDebug() << "name2 saved" << endl;*/ }
+}
+
+QString SkyObject::messageFromTitle( const QString &imageTitle ) {
+	QString message = imageTitle;
+	if ( imageTitle == i18n( "Show HST Image" ) || imageTitle.contains("HST") ) {
+		message = i18n( "%1: Hubble Space Telescope, operated by STScI for NASA [public domain]" ).arg( longname() );  
+	} else if ( imageTitle == i18n( "Show SEDS Image" ) ) {
+		message = i18n( "%1: SEDS, http://www.seds.org [free for non-commercial use]" ).arg( longname() );
+	} else if ( imageTitle == i18n( "Show KPNO AOP Image" ) ) {
+		message = i18n( "%1: Advanced Observing Program at Kitt Peak National Observatory [free for non-commercial use; no physical reproductions]" ).arg( longname() );
+	} else if ( imageTitle == i18n( "Show NOAO Image" ) ){
+		message = i18n( "%1: National Optical Astronomy Observatories and AURA [free for non-commercial use]" ).arg( longname() );
+	} else if ( imageTitle.contains( "VLT" ) ) {
+		message = i18n( "%1: Very Large Telescope, operated by the European Southern Observatory [free for non-commercial use; no reproductions]" ).arg( longname() );
+	} else if ( imageTitle.startsWith( i18n( "Show" ) ) ) {
+		message = imageTitle.mid( imageTitle.find( " " ) + 1 ); //eat first word, "Show"
+		message = longname() + ": " + message;
+	}
+	
+	return message;
+}
