@@ -15,23 +15,14 @@
  *                                                                         *
  ***************************************************************************/
 
-
-
-
 #ifndef SKYPOINT_H
 #define SKYPOINT_H
 
 #include <qstring.h>
 
-#include "ksnumbers.h"
 #include "dms.h"
 
-
 /**@class SkyPoint
-	*@short Stores dms coordinates for a point in the sky, and functions
-	*for converting between coordinate systems.
-	*@author Jason Harris
-	*@version 1.0
 	*
 	*The sky coordinates of a point in the sky.  The
 	*coordinates are stored in both Equatorial (Right Ascension,
@@ -44,8 +35,14 @@
 	*(RA0, Dec0), which were the true coordinates on Jan 1, 2000.
 	*The true coordinates (RA, Dec) at any other epoch can be found
 	*from the catalog coordinates using updateCoords().
+	*@short Stores dms coordinates for a point in the sky.
+	*for converting between coordinate systems.
+	*@author Jason Harris
+	*@version 1.0
 	*/
 
+class KSNumbers;
+
 class SkyPoint {
 public:
 /**Default constructor: Sets RA, Dec and RA0, Dec0 according
@@ -53,7 +50,7 @@ public:
 	*@param r Right Ascension
 	*@param d Declination
 	*/
-	SkyPoint( dms r, dms d ) { set( r, d ); }
+	SkyPoint( const dms& r, const dms& d ) { set( r, d ); }
 
 /**Alternate constructor using pointer arguments, for convenience.
 	*It behaves essentially like the default constructor.
@@ -83,14 +80,14 @@ public:
 	*@param r Right Ascension
 	*@param d Declination
 	*/
-	void set( dms r, dms d );
+	void set( const dms& r, const dms& d );
 
 /**Overloaded member function, provided for convenience.
 	*It behaves essentially like the above function.
 	*@param r Right Ascension
 	*@param d Declination
 	*/
-	void set( const dms *r, const dms *d ) { set( dms(*r), dms(*d) ); }
+	void set( const dms *r, const dms *d ) { set( *r, *d ); }
 
 /**Overloaded member function, provided for convenience.
 	*It behaves essentially like the above function.
@@ -168,24 +165,24 @@ public:
 /**Sets Galactic Longitude.
 	*@param glo Galactic Longitude.
 	*/
-	void setGalLong( dms glo ) { galLong.set( glo ); }
+//	void setGalLong( dms glo ) { galLong.set( glo ); }
 
 /**Overloaded member function, provided for convenience.
 	*It behaves essentially like the above function.
 	*@param glo Galactic Longitude, expressed as a double.
 	*/
-	void setGalLong( double glo ) { galLong.setD( glo ); }
+//	void setGalLong( double glo ) { galLong.setD( glo ); }
 
 /**Sets Galactic Longitude.
 	*@param gla Galactic Longitude.
 	*/
-	void setGalLat( dms gla ) { galLat.set( gla ); }
+//	void setGalLat( dms gla ) { galLat.set( gla ); }
 
 /**Overloaded member function, provided for convenience.
 	*It behaves essentially like the above function.
 	*@param gla Galactic Longitude, expressed as a double.
 	*/
-	void setGalLat( double gla ) { galLat.setD( gla ); }
+//	void setGalLat( double gla ) { galLat.setD( gla ); }
 
 ////
 //// 2. Returning coordinates.
@@ -217,11 +214,11 @@ public:
 
 /**@return a pointer to the current galactic latitude.
 	*/
-	const dms* gLat() const { return &galLat; }
+//	const dms* gLat() const { return &galLat; }
 
 /**@return a pointer to the current galactic longitude.
 	*/
-	const dms* gLong() const { return &galLong; }
+//	const dms* gLong() const { return &galLong; }
 
 ////
 //// 3. Coordinate conversions.
@@ -243,6 +240,17 @@ public:
 	*/
 	void HorizontalToEquatorial( const dms* LST, const dms* lat );
 
+	/**@short Convert Right Ascension/Declination to Ecliptic logitude/latitude.
+	*@param Obliquity current Obliquity of the Ecliptic (angle from Equator)
+	*/
+	void EquatorialToEcliptic( const KSNumbers *num );
+
+	/**@short Convert Ecliptic logitude/latitude to Right Ascension/Declination.
+	*@param Obliquity current Obliquity of the Ecliptic (angle from Equator)
+	*/
+
+	void EclipticToEquatorial( const KSNumbers *num );
+
 /**Determine the Ecliptic coordinates of the SkyPoint, given the Julian Date.
 	*The ecliptic coordinates are returned as reference arguments (since
 	*they are not stored internally)
@@ -259,13 +267,13 @@ public:
 	* epoch 1950. RA and Dec are, therefore assumed to be B1950
 	* coordinates.
 	*/
-	void Equatorial1950ToGalactic(void);
+	void Equatorial1950ToGalactic(dms &galLong, dms &galLat);
 
 /** Computes equatorial coordinates referred to 1950 from galactic ones referred to
 	* epoch B1950. RA and Dec are, therefore assumed to be B1950
 	* coordinates.
 	*/
-	void GalacticToEquatorial1950(void);
+	void GalacticToEquatorial1950(const dms* galLong, const dms* galLat);
 
 ////
 //// 4. Coordinate update/corrections.
@@ -361,6 +369,23 @@ public:
 	*/
 	void subtractEterms(void);
 
+	/** Computes the angular distance between two SkyObjects. The algorithm
+	 *  to compute this distance is:
+	 *  cos(distance) = sin(d1)*sin(d2) + cos(d1)*cos(d2)*cos(a1-a2)
+	 *  where a1,d1 are the coordinates of the first object and a2,d2 are
+	 *  the coordinates of the second object.
+	 *  However this algorithm is not accurate when the angular separation
+	 *  is small.
+	 *  Meeus provides a different algorithm in page 111 which we 
+	 *  implement here.
+	 *  @param SkyPoint to which distance is to be calculated
+	 *  @return dms angle representing angular separation.
+	 **/
+
+	dms angularDistanceTo( SkyPoint *sp);
+
+	bool operator == ( SkyPoint &p ) { return ( ra()->Degrees() == p.ra()->Degrees() && dec()->Degrees() == p.dec()->Degrees() ); }
+
 ////
 //// 5. Calculating Rise/Set/Transit data.
 //// =====================================
@@ -380,7 +405,6 @@ private:
 	dms RA0, Dec0; //catalog coordinates
 	dms RA, Dec; //current true sky coordinates
 	dms Alt, Az;
-	dms galLat, galLong; // Galactic coordinates
 };
 
 #endif
