@@ -18,12 +18,14 @@
 #ifndef KSTARS_TOGGLEACTION_H
 #define KSTARS_TOGGLEACTION_H
 
-/**Subclass of Kaction that allows for the action to have a boolean state (on/off)
+/**@class ToggleAction
+	*Subclass of Kaction that allows for the action to have a boolean state (on/off)
 	*The class stores the current state, and changes the Action's iconset to reflect
 	*the state.
 	*@author Mark Hollomon
-	*@version 0.9
+	*@version 1.0
 	*/
+
 #include <qiconset.h>
 #include <kaction.h>
 
@@ -31,21 +33,25 @@ class ToggleAction : public KAction {
 	Q_OBJECT
 		
 	public:
-/**Constructor. */
+		/**Constructor. */
 		ToggleAction(const QString& ontext, const QIconSet& onpix, const QString& offtext, const QIconSet& offpix, int accel, const QObject* receiver, const char* slot, QObject* parent = 0, const char* name = 0 ) ;
-/**Constructor. Same as above, but without icons. */
+		/**Constructor. Same as above, but without icons. */
 		ToggleAction(const QString& ontext, const QString& offtext, int accel, const QObject* receiver, const char* slot, QObject* parent = 0, const char* name = 0 ) ;
 
-/**Sets the ToolTip text for the "on" state. */
+		/**Sets the ToolTip text for the "on" state. 
+			*@p tip the tooltip string
+			*/
 		void setOnToolTip(QString tip);
 
-/**Sets the ToolTip text for the "off" state. */
+		/**Sets the ToolTip text for the "off" state. 
+			*@p tip the tooltip string
+			*/
 		void setOffToolTip(QString tip);
 
 	public slots:
-/**Put the Action in the "off" state.  Update the icon and tooltip. */
+		/**Put the Action in the "off" state.  Update the icon and tooltip. */
 		void turnOff();
-/**Put the Action in the "on" state.  Update the icon and tooltip. */
+		/**Put the Action in the "on" state.  Update the icon and tooltip. */
 		void turnOn();
 
 	private:
