@@ -18,7 +18,7 @@
 #ifndef KVERBEDIT_H
 #define KVERBEDIT_H
 
-#include <qverbedit.h>
+#include "qverbedit.h"
 #include "kverbosdoc.h"
 
 /**
