@@ -22,7 +22,7 @@
 
 // include files for KDE
 #include <kfiledialog.h>
-#include <klineeditdlg.h>
+#include <kinputdialog.h>
 #include "kstartuplogo.h"
 #include <kstandarddirs.h>
 #include <kstatusbar.h>
@@ -37,6 +37,7 @@
 #include "kverbosoptions.h"
 #include "kresult.h"
 #include "kfeedercontrol.h"
+#include "prefs.h"
 
 // ID Nummern fr die Statuszeile
 #define ID_STATUS_MSG 1
@@ -67,7 +68,6 @@ KVerbosApp::KVerbosApp(QWidget* , const char* name):KMainWindow (0, name)
   initView();
 
   readOptions();
-  setAutoSaveSettings();
 
   ///////////////////////////////////////////////////////////////////
   // disable actions at startup
@@ -130,10 +130,8 @@ void KVerbosApp::initActions()
   editCopy = KStdAction::copy(this, SLOT(slotEditCopy()), actionCollection());
   editPaste = KStdAction::paste(this, SLOT(slotEditPaste()), actionCollection());
   editErfassen = new KAction(i18n("E&nter New Verb..."), 0, 0, this, SLOT(slotEditErfassen()), actionCollection(),"edit_erfassen");
-  editBearbeiten = new KAction(i18n("&Edit Verblist..."), 0, 0, this, SLOT(slotEditBearbeiten()), actionCollection(), "edit_bearbeiten");
+  editBearbeiten = new KAction(i18n("&Edit Verb List..."), 0, 0, this, SLOT(slotEditBearbeiten()), actionCollection(), "edit_bearbeiten");
 
-  setStandardToolBarMenuEnabled(true);
-  createStandardStatusBarAction();
   settingOptions = new KAction(i18n("&Configure KVerbos..."), 0, 0, this, SLOT(slotSettingsOptions()), actionCollection(), "settings_options");
   userUsername = new KAction(i18n("&Username..."), 0, 0, this, SLOT(slotSettingsUsername()), actionCollection(), "user_username");
   userResults = new KAction(i18n("&Results"), 0, 0, this, SLOT(slotUserResults()), actionCollection(), "user_results");
@@ -163,9 +161,8 @@ void KVerbosApp::initActions()
   settingOptions->setIcon("configure.png");
   userUsername->setIcon("kverbosuser.png");
   userResults->setIcon("kverbosuser.png");
-
-  // use the absolute path to your kverbosui.rc file for testing purpose in createGUI();
-  createGUI();
+  
+  setupGUI();
 }
 
 
@@ -423,7 +420,7 @@ void KVerbosApp::slotFileOpenRecent(const KURL& url)
 void KVerbosApp::slotFileOpenStandard()
 {
 	slotStatusMsg(i18n("Opening file..."));
-
+	QString userLanguage = Prefs::userLanguage();
 	if(!doc->saveModified())
 	{
 		// here saving wasn't successful
@@ -431,7 +428,7 @@ void KVerbosApp::slotFileOpenStandard()
 	}
 	else
 	{
-		KURL url(locate("appdata", "data/verbos.verbos"));
+		KURL url(locate("appdata", "data/"+userLanguage+"/verbos.verbos"));
 		if(!url.isEmpty())
 		{
 			doc->openDocument(url);
@@ -732,20 +729,17 @@ void KVerbosApp::getTimeOptions(bool op[][3])
 
 void KVerbosApp::slotSettingsUsername()
 {
-	KLineEditDlg dlg(i18n("Please enter your name:"), QString::null, this);
-	dlg.setCaption(i18n("Enter User Name"));
-	if (dlg.exec())
-	{
-		QString n = dlg.text().simplifyWhiteSpace();
-		if (!n.isEmpty())
-		{
-			statusBar()->changeItem(i18n("user: ") + n, ID_USERNAME_MSG);
-			doc->setNewUser(n);
-			userResults->setEnabled(true);
-			if (kfeederControl != 0)
-				kfeederControl->reset();
-		};
-	};
+	bool ok;
+	QString n = KInputDialog::getText(i18n("Enter User Name"), i18n("Please enter your name:"),
+                        QString::null , &ok, this).simplifyWhiteSpace();
+        if (ok)
+        {
+		statusBar()->changeItem(i18n("user: ") + n, ID_USERNAME_MSG);
+		doc->setNewUser(n);
+		userResults->setEnabled(true);
+		if (kfeederControl != 0)
+			kfeederControl->reset();
+        }
 }
 
 void KVerbosApp::slotUserResults()
