@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: ProgressDlg.cpp,v 1.9 2003/07/17 12:48:19 binner Exp $
+    $Id: ProgressDlg.cpp,v 1.10 2004/02/23 15:02:54 annma Exp $
 
                               progress dialog
 
@@ -34,8 +34,6 @@
 #include <qlabel.h>
 
 #include <kstandarddirs.h>
-#include <klocale.h>
-#include <kapplication.h>
 
 
 ProgressDlg::ProgressDlg
