@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: DocOptionsPage.cpp,v 1.6 2003/07/17 12:48:20 binner Exp $
+    $Id: DocOptionsPage.cpp,v 1.7 2004/02/23 15:02:54 annma Exp $
 
                    internal doc options dialog class
 
@@ -29,10 +29,8 @@
 
 #include "DocOptionsPage.h"
 
-#include <kapplication.h>
 #include <klocale.h>
 
-#include <qkeycode.h>
 #include <qcheckbox.h>
 
 DocOptionsPage::DocOptionsPage
