@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: TitlePage.cpp,v 1.8 2003/07/17 12:48:20 binner Exp $
+    $Id: TitlePage.cpp,v 1.9 2004/02/23 15:02:54 annma Exp $
 
                    enter document title and author
 
@@ -28,12 +28,10 @@
 
 #include "TitlePage.h"
 
-#include <kv_resource.h>
 
 #include <kapplication.h>
 #include <klocale.h>
 
-#include <qkeycode.h>
 #include <qlineedit.h>
 #include <qmultilineedit.h>
 #include <qlabel.h>
