@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: AuxInfoEntryPage.cpp,v 1.8 2003/07/17 12:48:20 binner Exp $
+    $Id: AuxInfoEntryPage.cpp,v 1.9 2004/02/23 15:02:55 annma Exp $
 
                        edit "additional" properties
 
@@ -27,12 +27,8 @@
  ***************************************************************************/
 
 
-#include <qkeycode.h>
 #include <qmultilineedit.h>
-#include <qlabel.h>
-#include <qlistbox.h>
 
-#include <kapplication.h>
 
 #include "AuxInfoEntryPage.h"
 #include "EntryDlg.h"
