@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: blockall.h,v 1.1 2001/10/05 15:40:37 arnold Exp $
+    $Id: blockall.h,v 1.2 2003/07/17 12:48:20 binner Exp $
 
                    dummy validator which blocks all
 
@@ -14,11 +14,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: blockall.h,v $
-    Revision 1.1  2001/10/05 15:40:37  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /***************************************************************************
