@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kv_resource.h,v 1.2 2002/04/22 19:12:15 binner Exp $
+    $Id: kv_resource.h,v 1.4 2003/06/21 14:31:22 deller Exp $
 
                   common #defines for kvoctrain gui
 
@@ -15,42 +15,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: kv_resource.h,v $
-    Revision 1.2  2002/04/22 19:12:15  binner
-    CVS_SILENT Capitalisation fixes.
-
-    Revision 1.1  2001/11/25 11:12:24  arnold
-    splitted kv_resource.h
-
-    Revision 1.8  2001/11/18 12:28:46  arnold
-    provided menu entry for example files
-
-    Revision 1.7  2001/11/16 19:50:26  arnold
-    added submenu to set language to main menu
-
-    Revision 1.6  2001/11/10 17:34:43  arnold
-    fixed language property dialog page
-
-    Revision 1.5  2001/11/02 10:18:31  arnold
-    fixed colum resizing and diplaying of grade colors
-
-    Revision 1.4  2001/10/28 10:16:08  arnold
-    quick 'n dirty fixes for new query dialogs
-
-    Revision 1.3  2001/10/22 06:39:21  waba
-    Show a cute little marker to indicate marked entries.
-    (Instead of using a bold type-face)
-
-    Revision 1.2  2001/10/17 21:41:15  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.1  2001/10/05 15:42:01  arnold
-    import of version 0.7.0pre8 to kde-edu
-
  ***************************************************************************/
 
 /***************************************************************************
@@ -156,24 +120,16 @@
 #define ID_REM_MSG                  2003
 #define ID_TYPE_MSG                 2004
 
-#define PREFIX_Type                 "T:"
-#define PREFIX_Remark               "R:"
-#define PREFIX_Pronunce             "P:"
-
-#ifdef __ONLY_TO_BE_SEEN_BY_XGETTEXT
-     i18n("Abbreviation for T)ype of word",  PREFIX_Type)
-     i18n("Abbreviation for R)emark",        PREFIX_Remark)
-     i18n("Abbreviation for P)ronouncation", PREFIX_Pronunce)
+#ifndef I18N_NOOP2
+#define I18N_NOOP2(context, str) context, str
 #endif
 
+#define PREFIX_Type                 I18N_NOOP2("Abbreviation for T)ype of word", "T:")
+#define PREFIX_Remark               I18N_NOOP2("Abbreviation for R)emark","R:")
+#define PREFIX_Pronunce             I18N_NOOP2("Abbreviation for P)ronouncation","P:")
+
 //#define IDS_DEFAULT                 (doc && doc->isModified() ? " * Ready." : " Ready.")
-#define IDS_DEFAULT                 i18n("Ready.")
-
-///////////////////////////////////////////////////////////////////
-// General application values
-#ifdef __ONLY_TO_BE_SEEN_BY_XGETTEXT
-     IDS_DEFAULT
-#endif
+#define IDS_DEFAULT                 I18N_NOOP("Ready.")
 
 ///////////////////////////////////////////////////////////////////
 // header-menu entries
@@ -221,10 +177,6 @@
 //#define KVOCTRAIN_TITLE i18n("Vocabulary Trainer")
 #define KVOCTRAIN_NAME "kvoctrain"
 
-#ifdef __ONLY_TO_BE_SEEN_BY_XGETTEXT
-  KVOCTRAIN_TITLE
-#endif
-
 #define MAX_RECENTFILES  10
 
 #define KVOCTRAIN_DEBUG_AREA  12002
