@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kva_config.cpp,v 1.16 2003/06/21 14:31:22 deller Exp $
+    $Id: kva_config.cpp,v 1.32 2004/07/11 13:32:17 annma Exp $
 
                      configuration part of kvoctrain
 
@@ -29,21 +29,20 @@
 #include "kvoctrain.h"
 #include <kvoctraincore.h>
 
-#include <qmessagebox.h>
 #include <qfile.h>
 
-#include <kconfig.h>
 #include <kstatusbar.h>
-#include <klocale.h>
+#include <kdebug.h>
 
 #include "common-dialogs/ProgressDlg.h"
+#include "prefs.h"
 
 void kvoctrainApp::saveOptions(bool all)
 {
   KConfig *config = KApplication::kApplication()->config();
 
   config->setGroup(CFG_GENERAL);
-  config->writePathEntry(CFG_RECENT, recent_files);
+  Prefs::setRecentFiles(recent_files);
   config->writeEntry(CFG_AUTOSAVEOPT, autosaveopts);
   config->writeEntry(CFG_ENTRYAUTOAPPLY, autoentryApply);
 
@@ -51,12 +50,13 @@ void kvoctrainApp::saveOptions(bool all)
   config->writeEntry(CFG_SHOW_TOOLBAR,toolBar()->isVisible());
   config->writeEntry(CFG_SHOW_STATUSBAR,statusBar()->isVisible());
   config->writeEntry(CFG_TOOLBAR_POS, (int)toolBar()->barPos());
-  config->writeEntry(CFG_INLINE_EDIT, inline_edit);
+  Prefs::setEnableInlineEdit(inline_edit);
 
   if (view) {
-    config->setGroup(CFG_GENERAL);
-    config->writeEntry(CFG_CUR_ROW, view->getTable()->currentRow());
-    config->writeEntry(CFG_CUR_COL, view->getTable()->currentColumn());
+    kdDebug() << "Rows: " << view->getTable()->currentRow() << endl;
+    Prefs::setCurrentRow(view->getTable()->currentRow());
+    Prefs::setCurrentCol(view->getTable()->currentColumn());
+    Prefs::writeConfig();
   }
 
   if (all || autosaveopts) {
@@ -76,18 +76,18 @@ void kvoctrainApp::saveOptions(bool all)
     config->writeEntry(CFG_IPA_FSIZE, ipafont.pointSize());
     config->writeEntry(CFG_FFAMILY, tablefont.family());
     config->writeEntry(CFG_FSIZE, tablefont.pointSize());
-    config->writeEntry(CFG_GC_USE, gradecols.use);
-    config->writeEntry(CFG_GCOL0, gradecols.col0);
-    config->writeEntry(CFG_GCOL1, gradecols.col1);
-    config->writeEntry(CFG_GCOL2, gradecols.col2);
-    config->writeEntry(CFG_GCOL3, gradecols.col3);
-    config->writeEntry(CFG_GCOL4, gradecols.col4);
-    config->writeEntry(CFG_GCOL5, gradecols.col5);
-    config->writeEntry(CFG_GCOL6, gradecols.col6);
-    config->writeEntry(CFG_GCOL7, gradecols.col7);
+    Prefs::setUseGradeCol(gradecols.use);
+    Prefs::setGradeCol0(gradecols.col0);
+    Prefs::setGradeCol1(gradecols.col1);
+    Prefs::setGradeCol2(gradecols.col2);
+    Prefs::setGradeCol3(gradecols.col3);
+    Prefs::setGradeCol4(gradecols.col4);
+    Prefs::setGradeCol5(gradecols.col5);
+    Prefs::setGradeCol6(gradecols.col6);
+    Prefs::setGradeCol7(gradecols.col7);
   
     config->setGroup(CFG_GENERAL);
-    config->writeEntry(CFG_SMART_APPEND, (bool) smartAppend);
+    Prefs::setSmartAppend((bool) smartAppend);
     config->writeEntry(CFG_HEADER_RESIZER, (int) header_resizer);
 
     s = separator;
@@ -95,11 +95,11 @@ void kvoctrainApp::saveOptions(bool all)
       s = TAB_REP;
     if (separator == "  ")
       s = SPC_REP;
-    config->writeEntry(CFG_SEPARATOR, s);
+    Prefs::setSeparator(s);
     config->writeEntry(CFG_PASTEORDER, paste_order);
-    config->writeEntry(CFG_USECURRENT, useCurrent);
-    config->writeEntry(CFG_ENTRIESLESSON, entriesPerLesson);
-    config->writeEntry(CFG_BACKTIME, backupTime);
+    Prefs::setUseCurrent(useCurrent);
+    Prefs::setEntriesPerLesson(entriesPerLesson);
+    Prefs::setBackupTime(backupTime);
   
     config->writeEntry(CFG_NUMLANGSET, langset.size() );
     for (int i = 0; i < (int) langset.size(); i++) {
@@ -121,12 +121,24 @@ void kvoctrainApp::saveOptions(bool all)
     }
 
     config->setGroup(CFG_QUERYPROP);
-    config->writeEntry(CFG_MAXTIME_PER, maxqueryTime);
-    config->writeEntry(CFG_SHOWCOUNTER, showcounter);
-    config->writeEntry(CFG_SWAP_DIR, swap_querydir);
-    config->writeEntry(CFG_BLOCK, block);
-    config->writeEntry(CFG_EXPIRE, expire);
-    config->writeEntry(CFG_QUERYTIMEOUT, type_querytimeout);
+    Prefs::setMaxTimePer(maxqueryTime);
+    Prefs::setShowcounter(showcounter);
+    Prefs::setSwapDir(swap_querydir);
+    Prefs::setAltLearn(alt_learn);
+    Prefs::setBlock(block);
+    Prefs::setExpire(expire);
+    Prefs::setQueryTimeout(type_querytimeout);
+    Prefs::setSuggestions(suggestions);
+    Prefs::setSplit(split);
+    Prefs::setPeriods(periods);
+    Prefs::setColons(colons);
+    Prefs::setSemicolons(semicolons);
+    Prefs::setCommas(commas);
+    Prefs::setFields(fields);
+    Prefs::setShowMore(show_more);
+    Prefs::setIKnow(i_know);
+    Prefs::writeConfig();
+   
     config->setGroup(CFG_QUERYMANAG);
     querymanager.saveConfig (config);
   }
@@ -155,7 +167,7 @@ void kvoctrainApp::readOptions()
   config->setGroup(CFG_APPEARANCE);
   bViewToolbar = config->readBoolEntry(CFG_SHOW_TOOLBAR, true);
   bViewStatusbar = config->readBoolEntry(CFG_SHOW_STATUSBAR, true);
-  inline_edit = config->readBoolEntry(CFG_INLINE_EDIT, false);
+  inline_edit = Prefs::enableInlineEdit();;
   tool_bar_pos = (KToolBar::BarPosition)config->readNumEntry(CFG_TOOLBAR_POS, KToolBar::Top);
 
   QFont fdefault;
@@ -173,41 +185,33 @@ void kvoctrainApp::readOptions()
   if (pron_label != 0)
     pron_label->setFont(ipafont);
 
-  gradecols.use = config->readBoolEntry(CFG_GC_USE, true);
-  QColor qc = KV_NORM_COLOR;
-  gradecols.col0 = config->readColorEntry(CFG_GCOL0, &qc);
-  qc = KV_LEV1_COLOR;
-  gradecols.col1 = config->readColorEntry(CFG_GCOL1, &qc);
-  qc = KV_LEV2_COLOR;
-  gradecols.col2 = config->readColorEntry(CFG_GCOL2, &qc);
-  qc = KV_LEV3_COLOR;
-  gradecols.col3 = config->readColorEntry(CFG_GCOL3, &qc);
-  qc = KV_LEV4_COLOR;
-  gradecols.col4 = config->readColorEntry(CFG_GCOL4, &qc);
-  qc = KV_LEV5_COLOR;
-  gradecols.col5 = config->readColorEntry(CFG_GCOL5, &qc);
-  qc = KV_LEV6_COLOR;
-  gradecols.col6 = config->readColorEntry(CFG_GCOL6, &qc);
-  qc = KV_LEV7_COLOR;
-  gradecols.col7 = config->readColorEntry(CFG_GCOL7, &qc);
+  gradecols.use = Prefs::useGradeCol();
+  gradecols.col0 = Prefs::gradeCol0();
+  gradecols.col1 = Prefs::gradeCol1();
+  gradecols.col2 = Prefs::gradeCol2();
+  gradecols.col3 = Prefs::gradeCol3();  
+  gradecols.col4 = Prefs::gradeCol4();
+  gradecols.col5 = Prefs::gradeCol5();
+  gradecols.col6 = Prefs::gradeCol6();
+  gradecols.col7 = Prefs::gradeCol7();
 
   config->setGroup(CFG_GENERAL);
-  smartAppend = config->readNumEntry(CFG_SMART_APPEND, 0);
+  smartAppend = Prefs::smartAppend();
   header_resizer = (kvoctrainView::Resizer) config->readNumEntry(CFG_HEADER_RESIZER, (int) kvoctrainView::Automatic);
   // initialize the recent file list
-  recent_files = config->readPathListEntry(CFG_RECENT);
+  recent_files = Prefs::recentFiles();//config->readPathListEntry(CFG_RECENT);
   autosaveopts = config->readBoolEntry(CFG_AUTOSAVEOPT, true);
   autoentryApply = config->readBoolEntry(CFG_ENTRYAUTOAPPLY, false);
 
   paste_order = config->readListEntry(CFG_PASTEORDER);
-  useCurrent = config->readBoolEntry(CFG_USECURRENT, true);
-  entriesPerLesson = config->readNumEntry(CFG_ENTRIESLESSON, 50);
-  separator = config->readEntry(CFG_SEPARATOR, "\t");
+  useCurrent = Prefs::useCurrent();
+  entriesPerLesson =Prefs::entriesPerLesson();
+  separator = Prefs::separator();
   if (separator == TAB_REP)
     separator = "\t";
   else if (separator == SPC_REP)
     separator = "  ";
-  backupTime = config->readNumEntry(CFG_BACKTIME, 15*60*1000);
+  backupTime = Prefs::backupTime();
 
   ls = config->readNumEntry(CFG_NUMLANGSET, 0);
   QString s;
@@ -240,13 +244,22 @@ void kvoctrainApp::readOptions()
   }
 
   config->setGroup(CFG_QUERYPROP);
-  type_querytimeout = (kvq_timeout_t) config->readNumEntry(CFG_QUERYTIMEOUT, (int) kvq_notimeout);
-  maxqueryTime = config->readNumEntry(CFG_MAXTIME_PER, 20*1000);
-  showcounter = config->readNumEntry(CFG_SHOWCOUNTER, false);
-  swap_querydir= config->readBoolEntry(CFG_SWAP_DIR, false);
-  block = config->readBoolEntry(CFG_BLOCK, true);
-  expire = config->readBoolEntry(CFG_EXPIRE, true);
-
+  type_querytimeout = (kvq_timeout_t) Prefs::queryTimeout();
+  maxqueryTime = Prefs::maxTimePer();
+  showcounter = Prefs::showcounter();
+  swap_querydir= Prefs::swapDir();
+  alt_learn= Prefs::altLearn();
+  block = Prefs::block();
+  expire = Prefs::expire();
+  suggestions = Prefs::suggestions();
+  split = Prefs::split();
+  periods = Prefs::periods();
+  colons = Prefs::colons();
+  semicolons = Prefs::semicolons();
+  commas = Prefs::commas();
+  fields = Prefs::fields();
+  show_more = Prefs::showMore();
+  i_know = Prefs::iKnow();
   config->setGroup(CFG_QUERYMANAG);
   querymanager.loadConfig (config);
 }
