@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kva_header.cpp,v 1.20 2003/06/21 14:31:22 deller Exp $
+    $Id: kva_header.cpp,v 1.24 2004/06/17 20:48:48 wheeler Exp $
 
                      header buttons part of kvoctrain
 
@@ -30,17 +30,15 @@
 #define SORT_NUM    I18N_NOOP("Sort by &index")
 
 #include "kvoctrain.h"
-#include "query-dialogs/QueryDlgBase.h"
 #include "query-dialogs/RandomQueryDlg.h"
 #include "query-dialogs/MCQueryDlg.h"
+#include "query-dialogs/AdjQueryDlg.h"
 #include "query-dialogs/VerbQueryDlg.h"
 #include "query-dialogs/ArtQueryDlg.h"
-#include "query-dialogs/AdjQueryDlg.h"
 #include "query-dialogs/SimpleQueryDlg.h"
 
+
 #include <kcombobox.h>
-#include <kglobal.h>
-#include <ksimpleconfig.h>
 #include <klocale.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
