@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kva_io.cpp,v 1.36 2003/07/17 12:26:55 binner Exp $
+    $Id: kva_io.cpp,v 1.40 2004/07/13 22:10:17 binner Exp $
 
                          i/o part of kvoctrain
 
@@ -28,10 +28,6 @@
 #include <unistd.h>
 
 #include <qtimer.h>
-#include <qprogressbar.h>
-#include <qfile.h>
-#include <qfileinfo.h>
-#include <qmessagebox.h>
 
 #include <kfiledialog.h>
 #include <kcombobox.h>
@@ -39,11 +35,9 @@
 #include <krecentdocument.h>
 #include <kstatusbar.h>
 #include <klocale.h>
-#include <kstdguiitem.h>
 #include <kstandarddirs.h>
 #include <kdebug.h>
 
-#include <kvoctraincore.h>
 #include "kvoctrain.h"
 #include "UsageManager.h"
 #include "common-dialogs/ProgressDlg.h"
@@ -283,32 +277,32 @@ void kvoctrainApp::slotFileOpen()
       s = recent_files[0];
     QString name = getFileName(kapp->makeStdCaption(i18n("Open Vocabulary File")),
                                s, FILTER_RPATTERN, parentWidget());
-    loadfileFromPath(name);
+    loadfileFromPath(KURL(name));
   }
   slotStatusMsg(IDS_DEFAULT);
 }
 
 
-void kvoctrainApp::loadfileFromPath(QString &name, bool addRecent)
+void kvoctrainApp::loadfileFromPath(const KURL & url, bool addRecent)
 {
-    if (!name.isEmpty() ) {
+    if (!url.path().isEmpty() ) {
       view->setView(0, langset, gradecols);
       delete doc;
       doc = 0;
 
       QString format = i18n("Loading %1");
-      QString msg = format.arg(name);
+      QString msg = format.arg(url.path());
 
       slotStatusMsg(msg);
       prepareProgressBar();
-      doc = new kvoctrainDoc (this, name, separator, &paste_order);
+      doc = new kvoctrainDoc (this, url.path(), separator, &paste_order);
       removeProgressBar();
       loadDocProps(doc);
       view->setView(doc, langset, gradecols);
       view->getTable()->setFont(tablefont);
       view->adjustContent();
       if (addRecent)
-         addRecentFile (name);
+         addRecentFile (url.path());
       connect (doc, SIGNAL (docModified(bool)), this, SLOT(slotModifiedDoc(bool)));
       doc->setModified(false);
     }
@@ -323,7 +317,7 @@ void kvoctrainApp::slotFileOpenExample()
     s = locate("data",  "kvoctrain/examples/");
     QString name = getFileName(kapp->makeStdCaption(i18n("Open Example Vocabulary File")),
                                s, FILTER_RPATTERN, parentWidget());
-    loadfileFromPath(name, false);
+    loadfileFromPath(KURL(name), false);
     if (doc)
        doc->setFileName(QString::null);
   }
