@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvoctrain.cpp,v 1.59.2.1 2004/04/14 16:24:06 binner Exp $
+    $Id: kvoctrain.cpp,v 1.66 2004/07/13 13:35:25 annma Exp $
 
                       main part of kvoctrain
 
@@ -30,33 +30,25 @@
 #include <klineedit.h>
 #include <kcombobox.h>
 #include <kprogress.h>
-#include <kapplication.h>
 #include <kconfig.h>
 #include <kstandarddirs.h>
 #include <klocale.h>
 #include <kdebug.h>
 
-#include <qcursor.h>
 #include <qinputdialog.h>
 #include <qtimer.h>
-#include <qfile.h>
-#include <qtooltip.h>
-#include <qprogressbar.h>
 
 #include <time.h>
 #include <ctype.h>
 
 #include <kvoctraincore.h>
-#include "kvoctraindoc.h"
-#include "langset.h"
 #include "kvoctrain.h"
 #include "entry-dialogs/EntryDlg.h"
 #include "option-dialogs/GeneralOptionsDlg.h"
 #include "docprop-dialogs/DocPropDlg.h"
 #include "docprop-dialogs/DocPropLangDlg.h"
-#include "common-dialogs/ProgressDlg.h"
 #include "statistik-dialogs/StatistikDlg.h"
-
+#include "prefs.h"
 
 void kvoctrainApp::slotSaveOptions()
 {
@@ -196,7 +188,7 @@ void kvoctrainApp::commitEntryDlg(bool force)
      if( KMessageBox::No == KMessageBox::warningYesNo(this,
                    i18n("The entry dialog contains unsaved changes.\n"
                         "Do you want to apply or discard your changes?"),
-                   kapp->makeStdCaption("Unsaved Changes"),
+                   kapp->makeStdCaption(i18n("Unsaved Changes")),
                    KStdGuiItem::apply(), KStdGuiItem::discard())) {
         return;
      }
@@ -262,7 +254,7 @@ void kvoctrainApp::commitEntryDlg(bool force)
    }
    else {
      col -= KV_EXTRA_COLS;
-     for (int ts = 0; ts < tabsel.size(); ++ts) {
+     for (uint ts = 0; ts < tabsel.size(); ++ts) {
        for (int er = tabsel[ts].topRow(); er <= tabsel[ts].bottomRow(); ++er) {
          kvoctrainExpr *expr = doc->getEntry(er);
 
@@ -307,7 +299,7 @@ void kvoctrainApp::commitEntryDlg(bool force)
      }
      entryDlg->setModified(false);
      doc->setModified(true);
-     for (int ts = 0; ts < tabsel.size(); ++ts)
+     for (uint ts = 0; ts < tabsel.size(); ++ts)
        for (int r = tabsel[ts].topRow(); r <= tabsel[ts].bottomRow(); ++r)
          for (int c = 0; c < view->getTable()->numCols(); ++c)
            view->getTable()->updateCell(r, c);
@@ -586,7 +578,7 @@ void kvoctrainApp::setDataEntryDlg (int row, int col)
    view->getTable()->updateCell(row, col);
    vector<QTableSelection> tabsel;
    if (hasSel) {
-     for (unsigned i = 0; i < view->getTable()->numSelections(); ++i)
+     for (int i = 0; i < view->getTable()->numSelections(); ++i)
        tabsel.push_back(view->getTable()->selection(i));
    }
    entryDlg->setCell(row, col+KV_EXTRA_COLS, tabsel);
@@ -918,6 +910,7 @@ void kvoctrainApp::slotCleanVocabulary ()
 void kvoctrainApp::slotCreateRandom()
 {
    bool ok = FALSE;
+   //shouldn't this dialog display the previous setting i.e Prefs::entriesPerLesson()?
    int res = QInputDialog::getInteger(
                 i18n( "Entries in Lesson" ),
                 i18n( "Enter number of entries in lesson:" ), 1, 1, 1000, 1, &ok, this );
@@ -1015,10 +1008,10 @@ void kvoctrainApp::slotGeneralOptionsPage(int index)
       gradecols = godlg.getGradeCols();
       header_resizer = godlg.getResizer();
 
-      // rather ugly hack to keep useCurrent "globally" up to date
-      KConfig *config = KApplication::kApplication()->config();
-      config->setGroup(CFG_GENERAL);
-      config->writeEntry(CFG_USECURRENT, useCurrent);
+       // rather ugly hack to keep useCurrent "globally" up to date
+      // is that necessary? anmma Feb 23rd 2004
+      Prefs::setUseCurrent( useCurrent);
+      Prefs::writeConfig();
 
       if (pron_label)
         pron_label->setFont(ipafont);
@@ -1344,7 +1337,7 @@ void kvoctrainApp::aboutToShowVocabulary() {
     voc_menu->removeItem (ID_SET_LANG);
     QPopupMenu *set_m = new QPopupMenu();
 
-    for (unsigned header = 0; header < doc->numLangs(); ++header ) {
+    for (int header = 0; header < doc->numLangs(); ++header ) {
       // select one of the available languages for the column
       QPopupMenu *langs_m = new QPopupMenu();
       // hack: ID => header-id + language
