@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvoctrain.h,v 1.28 2003/06/21 14:31:22 deller Exp $
+    $Id: kvoctrain.h,v 1.32 2004/07/11 22:34:19 hedlund Exp $
 
                          main part of kvoctrain
 
@@ -36,23 +36,16 @@
 
 // include files for QT
 #include <qpainter.h>
-#include <qcombobox.h>
 
 // include files for KDE 
 #include <kapplication.h> 
 #include <kmainwindow.h>
-#include <kaccel.h>
 #include <kmenubar.h>
-#include <ktoolbar.h>
-#include <kiconloader.h>
 #include <kmessagebox.h>
 #include <krandomsequence.h>
 
 // application specific includes
 #include "kvoctrainview.h"
-#include "kv_resource.h"
-#include "langset.h"
-#include "QueryManager.h"
 #include "queryoption-dialogs/GroupOptPage.h"
 #include "query-dialogs/QueryDlgBase.h"
 
@@ -207,7 +200,7 @@ public:
   void slotFileOpen();
   /** open a sample document */
   void slotFileOpenExample();
-  void loadfileFromPath(QString &path, bool addRecent=true);
+  void loadfileFromPath(const KURL &, bool addRecent=true);
   /** merge a document */
   void slotFileMerge();
   /** save a document */
@@ -291,6 +284,9 @@ private:
   friend class kvoctrainView;
 
   vector<QueryEntryRef> random_expr1, random_expr2;
+  // Vectors for use in Leitner style learning. There is no
+  // correct_0_times, we simply reuse random_expr1.
+  vector<QueryEntryRef> correct_1_times, correct_2_times, correct_3_times;
   QuerySelection queryList;
 
   QTimer          *btimer;
@@ -301,6 +297,7 @@ private:
   bool             querymode;
   bool             querying;
   bool             swap_querydir;
+  bool             alt_learn;
   bool             expire;
   bool             block;
   QString          def_lang;
@@ -351,6 +348,15 @@ private:
   bool             autosaveopts;
   bool             autoentryApply;
   KRandomSequence  random;
+  bool             suggestions;
+  bool             split;
+  bool             periods;
+  bool             colons;
+  bool             semicolons;
+  bool             commas;
+  int              fields;
+  bool             show_more;
+  bool             i_know;
 };
  
 #endif // KVOCTRAIN_H
