@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvoctrainview.cpp,v 1.30 2003/06/21 14:31:22 deller Exp $
+    $Id: kvoctrainview.cpp,v 1.32.2.1 2004/08/09 14:17:55 annma Exp $
 
                       view to kvoctrain parts
 
@@ -28,26 +28,17 @@
 
 
 #include <kvoctraincore.h>
-#include "kv_resource.h"
 #include "kvoctrain.h"
-#include "rowtable.h"
-#include "entry-dialogs/EntryDlg.h"
-#include "kvoctraindoc.h"
 #include "kvoctrainview.h"
 
-#include <kapplication.h>
-#include <kmessagebox.h>
 #include <kstandarddirs.h>
 #include <kconfig.h>
 #include <klocale.h>
 #include <kdebug.h>
 
-#include <qwidget.h>
 #include <qlayout.h>
-#include <qlistbox.h>
-#include <qiconset.h>
 #include <qbitmap.h>
-#include <qstyle.h>
+#include <qfile.h>
 
 #include <ctype.h>
 
@@ -260,7 +251,28 @@ void kvoctrainView::setHeaderProp (int id, const QString &name,
   }
   else
   {
-     QPixmap pix(pixfile);
+    QPixmap pix;     
+    if (QFile::exists(pixfile))
+      pix.load(pixfile);
+    else
+    {
+      //this is the code used by kxkb when a flag image can't be found
+      //see kdebase/kxkb/pixmap.cpp/LayoutIcon::findPixmap()
+      pix.resize(21, 14);
+      pix.fill(Qt::white);
+      
+      QPainter p(&pix);
+      
+      QFont font("sans");
+      font.setPixelSize(10);
+      font.setWeight(QFont::Bold);
+      p.setFont(font);
+      p.setPen(Qt::red);
+      p.drawText(2, 1, pix.width(), pix.height()-2, Qt::AlignCenter, "err");
+      p.setPen(Qt::blue);
+      p.drawText(1, 0, pix.width(), pix.height()-2, Qt::AlignCenter, "err");     
+    }
+     
      int w = pix.width();
      int h = pix.height();
 
@@ -323,9 +335,7 @@ void kvoctrainTable::setCurrentItem(int row)
   setCurrentRow( row, currentColumn() );
 }
 
-
-void kvoctrainTable::sortByColumn_alpha(int header)
-{
+void kvoctrainTable::sortByColumn(int header, bool alpha) {
   if (header == KV_COL_MARK)
    return;
 
@@ -343,23 +353,36 @@ void kvoctrainTable::sortByColumn_alpha(int header)
     return;
   }
 
+  QApplication::setOverrideCursor( waitCursor );
+
   clearSelection();
 
+  bool hasinlineenabled = getInlineEnabled();
+  setInlineEnabled(false);
+
   bool sortdir = false;
-  QApplication::setOverrideCursor( waitCursor );
   if (m_rows) {
     if (header >= KV_COL_ORG)
       sortdir = m_rows->sort (header-KV_EXTRA_COLS);
     else
-      sortdir = m_rows->sortByLesson_alpha();
+      if (alpha)
+        sortdir = m_rows->sortByLesson_alpha();
+      else
+        sortdir = m_rows->sortByLesson_index();
   }
   horizontalHeader()->setSortIndicator ( header, sortdir);
   repaintContents();
   m_rows->setModified();
   emit currentChanged(currentRow(), currentColumn());
+  setInlineEnabled(hasinlineenabled);
   QApplication::restoreOverrideCursor();
 }
 
+void kvoctrainTable::sortByColumn_alpha(int header)
+{
+  sortByColumn(header, true);
+}
+
 
 void kvoctrainTable::slotSelectionChanged()
 {
@@ -369,38 +392,7 @@ void kvoctrainTable::slotSelectionChanged()
 
 void kvoctrainTable::sortByColumn_index(int header)
 {
-  if (header == KV_COL_MARK)
-   return;
-
-  if (header >= numRows() ) {
-    kdError() << "header >= numRows()\n";
-    return;
-  }
-
-  if (m_rows && !m_rows->isAllowedSorting() ) {
-     KMessageBox::information(this, 
-               i18n("Sorting is currently turned off for this document.\n"
-                    "\n"
-                    "Use the document properties dialog to turn sorting on."),
-                    kapp->makeStdCaption(""));
-    return;
-  }
-
-  clearSelection();
-
-  bool sortdir = false;
-  QApplication::setOverrideCursor( waitCursor );
-  if (m_rows) {
-    if (header >= KV_COL_ORG)
-      sortdir = m_rows->sort (header-KV_EXTRA_COLS);
-    else
-      sortdir = m_rows->sortByLesson_index();
-  }
-  horizontalHeader()->setSortIndicator ( header, sortdir);
-  repaintContents();
-  m_rows->setModified();
-  emit currentChanged(currentRow(), currentColumn());
-  QApplication::restoreOverrideCursor();
+  sortByColumn(header, false);
 }
 
 
