@@ -1,6 +1,7 @@
+// -*- C++ -*-
 /***************************************************************************
 
-    $Id: kvoctrainview.h,v 1.10 2003/06/21 14:31:22 deller Exp $
+    $Id: kvoctrainview.h,v 1.12 2004/04/03 22:15:59 davh Exp $
 
                          view to kvoctrain parts
 
@@ -43,10 +44,8 @@ class kvoctrainApp;
 class kvoctrainDoc;
 class GradeCols;
 
-#include <qwidget.h>
 #include "rowtable.h"
 #include "kvoctraindoc.h"
-#include "langset.h"
 
 /**
   * This class provides an incomplete base for your application view. 
@@ -130,6 +129,9 @@ public slots:
 protected:
   int             current;
 
+ private:
+  void sortByColumn(int, bool);
+
 };
 
 #endif // KVOCTRAINVIEW_H
