@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: QueryManager.h,v 1.4 2003/07/17 12:48:21 binner Exp $
+    $Id: QueryManager.h,v 1.5 2004/02/22 22:44:01 annma Exp $
 
                             manage queries
 
@@ -177,7 +177,7 @@ class QueryManager
 
   QuerySelection select(kvoctrainDoc*, int act_lesson,
                         int oindex, int tindex,
-                        bool swap, bool block, bool expire);
+                        bool swap, bool altlearn, bool block, bool expire);
 
   bool validate(kvoctrainExpr *expr, int act_lesson,
                 int index, QString type);
