@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: UsageManager.cpp,v 1.12 2003/09/06 20:40:37 binner Exp $
+    $Id: UsageManager.cpp,v 1.13 2004/02/23 15:02:55 annma Exp $
 
                             manage usage labels
 
@@ -27,12 +27,9 @@
  ***************************************************************************/
 
 #include "UsageManager.h"
-#include "kvoctraincore.h"
 
-#include <kapplication.h>
 #include <klocale.h>
 
-#include "kvoctraindoc.h"
 
 #include <iostream>
 #include <vector>
