@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvd_rh_kvtml.cpp,v 1.14 2003/09/20 16:47:35 binner Exp $
+    $Id: kvd_rh_kvtml.cpp,v 1.15 2004/02/23 15:02:55 annma Exp $
 
                    read header parts of a kvtml document
 
@@ -25,15 +25,10 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "kvoctraindoc.h"
-#include "kvoctraincore.h"
 #include "QueryManager.h"
 
-#include <kapplication.h>
 #include <klocale.h>
-#include <kstandarddirs.h>
 
-#include <qmessagebox.h>
 #include <qtextcodec.h>
 
 bool kvoctrainDoc::loadFromKvtMl (QTextStream& is)
