@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvoctraincore.h,v 1.7 2003/07/17 12:48:21 binner Exp $
+    $Id: kvoctraincore.h,v 1.19 2004/02/28 01:08:22 annma Exp $
 
                      common #defines for kvoctrain core
 
@@ -46,33 +46,15 @@
 #define       CFG_FSIZE                "FontSize"
 #define       CFG_FFAMILY              "FontFamily"
 #define       CFG_FCHARSET             "FontCharSet"
-#define       CFG_GC_USE               "UseGradeCol"
-#define       CFG_GCOL0                "GradeCol0"
-#define       CFG_GCOL1                "GradeCol1"
-#define       CFG_GCOL2                "GradeCol2"
-#define       CFG_GCOL3                "GradeCol3"
-#define       CFG_GCOL4                "GradeCol4"
-#define       CFG_GCOL5                "GradeCol5"
-#define       CFG_GCOL6                "GradeCol6"
-#define       CFG_GCOL7                "GradeCol7"
 #define       CFG_SHOW_TOOLBAR         "ShowToolbar"
 #define       CFG_SHOW_STATUSBAR       "ShowStatusbar"
 #define       CFG_TOOLBAR_POS          "ToolBar_Pos"
-#define       CFG_INLINE_EDIT          "EnableInlineEdit"
 
 #define      CFG_GENERAL              "General"
 #define       CFG_LASTFILE             "LastFile"
-#define       CFG_SEPARATOR            "Separator"
 #define       CFG_PASTEORDER           "PasteOrder"
-#define       CFG_USECURRENT           "UseCurrent"
 #define       CFG_ENTRIESLESSON        "EntriesPerLesson"
-#define       CFG_BACKTIME             "BackupTime"
-#define       CFG_CUR_ROW              "CurrentRow"
-#define       CFG_CUR_COL              "CurrentCol"
-#define       CFG_RECENT               "RecentFiles"
 #define       CFG_HEADER_RESIZER       "HeaderResizer"
-#define       CFG_FIRST_TIME           "FirstTime"
-#define       CFG_SMART_APPEND         "SmartAppend"
 #define       CFG_AUTOSAVEOPT          "AutoSaveOptions"
 #define       CFG_ENTRYAUTOAPPLY       "EntryAutomaticApply"
 
@@ -82,15 +64,9 @@
 #define       CFG_LESSONSIZE           "LessonSize"
 
 #define      CFG_QUERYPROP            "QueryProperties"
-#define       CFG_MAXTIME_PER          "MaxTimePer"
 #define       CFG_QUERYMODE            "QueryMode"
-#define       CFG_SWAP_DIR             "SwapDir"
-#define       CFG_EXPIRE               "Expire"
-#define       CFG_BLOCK                "Block"
 #define       CFG_DEFTRANS             "DefaultTranslation"
 #define       CFG_DEFORG               "DefaultOriginal"
-#define       CFG_QUERYTIMEOUT         "QueryTimeout"
-#define       CFG_SHOWCOUNTER          "Showcounter"
 
 #define      CFG_NUMLANGSET           "NumLangSet"
 #define       CFG_L_SHORT              "ShortId"
