@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvoctraindoc.cpp,v 1.25 2003/06/21 14:31:23 deller Exp $
+    $Id: kvoctraindoc.cpp,v 1.29 2004/06/26 18:10:37 binner Exp $
 
                    maintain a kvoctrain document
 
@@ -34,9 +34,7 @@
 #include <kdebug.h>
 #include <kmessagebox.h>
 
-#include <qfile.h>
 #include <qfileinfo.h>
-#include <qtextstream.h>
 
 #include <algorithm>
 #include <functional>
@@ -44,7 +42,7 @@
 using namespace std;
 
 #include <iostream>
-#include <fstream.h>
+#include <sstream>
 
 #include <float.h>
 
@@ -60,7 +58,7 @@ void kvoctrainDoc::setVersion (QString vers)
 }
 
 
-void kvoctrainDoc::getVersion(int &major, int &minor, int &patch)
+void kvoctrainDoc::getVersion(int &, int &, int &)
 {
 }
 
@@ -239,9 +237,8 @@ bool kvoctrainDoc::saveAs (QObject *parent, QString name, QString title,
     QFile f( tmp);
 
     if (!f.open( IO_WriteOnly )) {               // open file for writing
-      QString format = i18n("File \"%1\" is not writable, probably you don\'t have permission to do this.\n");
-      QString msg = format.arg(tmp);
-      KMessageBox::error(0, msg, kapp->makeStdCaption(i18n("I/O Failure")));
+      QString msg = i18n("File \"%1\" is not writable, probably you do not have permission to do this.");
+      KMessageBox::error(0, msg.arg(tmp), kapp->makeStdCaption(i18n("I/O Failure")));
       return false;
     }
 
@@ -848,7 +845,7 @@ void kvoctrainDoc::setDocRemark(QString s)
 int kvoctrainDoc::search(QString substr, int id,
                          int first, int last,
                          bool word_start,
-                         bool tolerant)
+                         bool)
 {
    if (last >= numEntries()
        || last < 0 )
@@ -1036,7 +1033,7 @@ int kvoctrainDoc::cleanUp()
 
     ent_no++;
     if (ent_percent != 0 && (ent_no % ent_percent) == 0 )
-      emit progressChanged(this, (ent_no / f_ent_percent) /2.0);
+      emit progressChanged(this, (int)((ent_no / f_ent_percent) / 2.0));
 
     bool equal = true;
     if (kve1->getOriginal() == kve2->getOriginal() ) {
@@ -1061,7 +1058,7 @@ int kvoctrainDoc::cleanUp()
   for (int i = (int) to_delete.size()-1; i >= 0; i--) {
     ent_no++;
     if (ent_percent != 0 && (ent_no % ent_percent) == 0 )
-      emit progressChanged(this, 50 + ent_no / f_ent_percent / 2.0);
+      emit progressChanged(this, (int)(50 + ent_no / f_ent_percent / 2.0));
 #ifdef CLEAN_BUG
     sso << getEntry(to_delete[i])->getOriginal() << endl;
 #endif
