@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kvoctrainexpr.cpp,v 1.13 2003/07/17 12:48:21 binner Exp $
+    $Id: kvoctrainexpr.cpp,v 1.14 2004/02/23 15:02:56 annma Exp $
 
                    maintain a kvoctrain expression
 
@@ -29,15 +29,11 @@
 
 #include "kvoctraindoc.h"
 #include <qpainter.h>
-#include "qdatastream.h"
 
 #include <vector>
 using namespace std;
 
-#include "kvoctraincore.h"
-#include <klocale.h>
 #include <kdebug.h>
-#include <kstandarddirs.h>
 
 #include "kv_resource.h"  // FIXME: remove include
 
