@@ -1,22 +1,12 @@
 /* -*- C++ -*-
 
-  $Id: XmlWriter.cpp,v 1.2 2002/04/21 13:18:51 arnold Exp $
+  $Id: XmlWriter.cpp,v 1.4 2003/07/17 12:48:22 binner Exp $
 
   This file is part of KIllustrator.
   Copyright (C) 1998 Kai-Uwe Sattler (kus@iti.cs.uni-magdeburg.de)
 
   modified for kvoctrain by Ewald Arnold kvoctrain@ewald-arnold.dein April 99
 
-  -----------------------------------------------------------------------
-
-  $Log: XmlWriter.cpp,v $
-  Revision 1.2  2002/04/21 13:18:51  arnold
-  fixed escaping from "<" to &lt;
-
-  Revision 1.1  2001/10/05 15:43:20  arnold
-  import of version 0.7.0pre8 to kde-edu
-
-
   -----------------------------------------------------------------------
 
   This program is free software; you can redistribute it and/or modify
@@ -32,7 +22,7 @@
   
   You should have received a copy of the GNU Library General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "XmlWriter.h"
