@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: langset.cpp,v 1.5 2003/07/17 12:48:21 binner Exp $
+    $Id: langset.cpp,v 1.6 2004/03/07 22:46:58 annma Exp $
 
                       properties for a language
 
@@ -55,7 +55,7 @@ void LangSet::addSet (QString _shortId, QString _shortId2, QString _longId,
 
 void LangSet::appendSet(const LangSet &set)
 {
-  for (int i = 0; i < set.size(); ++i) {
+  for (int i = 0; i < (int) set.size(); ++i) {
     LangDef def;
     def.shortId = set.langs[i].shortId;
     def.shortId2 = set.langs[i].shortId2;
