@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: GenOptPage.cpp,v 1.11 2003/07/17 12:48:22 binner Exp $
+    $Id: GenOptPage.cpp,v 1.15 2004/02/27 02:31:35 annma Exp $
 
                        general options dialog page
 
@@ -27,15 +27,12 @@
  ***************************************************************************/
 
 #include "GenOptPage.h"
-#include <qkeycode.h>
-#include <qlabel.h>
 #include <qlineedit.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
 #include <qradiobutton.h>
 #include <qvalidator.h>
 #include <stdlib.h>
-#include <kapplication.h>
 #include <klocale.h>
 
 #include <QueryManager.h>
@@ -62,10 +59,10 @@ GenOptPage::GenOptPage
   group_resize->insert(hb_fixed);
 
   connect( chk_autoapply, SIGNAL(toggled(bool)), this, SLOT(slotAutoApplyChecked(bool)) );
-  connect( c_smart, SIGNAL(toggled(bool)), SLOT(slotSmartAppend(bool)) );
+  connect( kcfg_smartAppend, SIGNAL(toggled(bool)), SLOT(slotSmartAppend(bool)) );
   connect( c_btime, SIGNAL(toggled(bool)), SLOT(slotBTimeUsed(bool)) );
   connect( c_saveopt, SIGNAL(toggled(bool)), SLOT(slotAutoSaveOpts(bool)) );
-  connect( e_btime, SIGNAL(textChanged(const QString&)), SLOT(slotChangeBTime(const QString&)) );
+  connect( kcfg_backupTime, SIGNAL(textChanged(const QString&)), SLOT(slotChangeBTime(const QString&)) );
   connect( hb_fixed, SIGNAL(clicked()), SLOT(slotHBfixed()) );
   connect( hb_percent, SIGNAL(clicked()), SLOT(slotHBpercent()) );
   connect( hb_auto, SIGNAL(clicked()), SLOT(slotHBauto()) );
@@ -74,13 +71,13 @@ GenOptPage::GenOptPage
   smart = _smart;
   autosaveopts = _autosaveopts;
 
-  c_smart->setChecked(smart);
+  kcfg_smartAppend->setChecked(smart);
   c_saveopt->setChecked(autosaveopts);
 
   QString s;
   validator = new QIntValidator (0, 60*60*24*7, 0); // at least once a week
 
-  e_btime->setValidator (validator);
+  kcfg_backupTime->setValidator (validator);
   c_btime->setChecked(btime > 0);
   slotBTimeUsed(btime > 0);
 
@@ -119,7 +116,7 @@ void GenOptPage::initFocus() const
 
 void GenOptPage::slotBTimeUsed(bool on)
 {
-  e_btime->setEnabled(on);
+  kcfg_backupTime->setEnabled(on);
 
   if (on) {
     if (btime < 0 )
@@ -134,10 +131,10 @@ void GenOptPage::slotBTimeUsed(bool on)
 
   QString s;
   s.setNum (abs(btime));
-  bool b = e_btime->signalsBlocked();
-  e_btime->blockSignals(true);
-  e_btime->setText (s);
-  e_btime->blockSignals(b);
+  bool b = kcfg_backupTime->signalsBlocked();
+  kcfg_backupTime->blockSignals(true);
+  kcfg_backupTime->setText (s);
+  kcfg_backupTime->blockSignals(b);
 }
 
 
