@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: LangOptPage.cpp,v 1.23.2.1 2004/02/01 16:03:05 larkang Exp $
+    $Id: LangOptPage.cpp,v 1.25 2004/02/23 15:02:56 annma Exp $
 
                   language options dialog page
 
@@ -27,14 +27,9 @@
  ***************************************************************************/
 
 
-#include <qpixmap.h>
-#include <qkeycode.h>
-#include <qfileinfo.h>
 #include <qlabel.h>
 #include <kcombobox.h>
-#include <qradiobutton.h>
 #include <qpushbutton.h>
-#include <qlineedit.h>
 #include <qpopupmenu.h>
 
 #include <kfiledialog.h>
@@ -47,9 +42,7 @@
 #include "LangOptPage.h"
 
 #include <langset.h>
-#include <kv_resource.h>
 #include <kvoctraincore.h>
-#include <kvoctraindoc.h>
 
 #include <map>
 #include <algorithm>
@@ -1047,8 +1040,8 @@ void LangOptPage::loadCountryData()
       }
       else
         kdDebug() << "Couldn't find the language for: " << *it << endl;
-  }
-
+    }
+        
     int id = idx++;
     countryIdMap.insert(id, Country(name, langs, pixmap, id));
     regions[submenu].countries.append(countryIdMap[id]);
@@ -1103,14 +1096,14 @@ void LangOptPage::slotLangFromGlobalActivated(int i)
         continue;
       }
 
-    d_shortName->insertItem(s.stripWhiteSpace());
+      d_shortName->insertItem(s.stripWhiteSpace());
       langset.addSet(s, global_langset.shortId2(*it), global_langset.longId(*it), global_langset.PixMapFile(*it));
 
       if (first)
       {
-    d_shortName->setCurrentItem(d_shortName->count()-1);
-    slotShortActivated(s);
-    enableLangWidgets();
+        d_shortName->setCurrentItem(d_shortName->count()-1);
+        slotShortActivated(s);
+        enableLangWidgets();
 
         e_shortName2->setText(global_langset.shortId2(*it));
         slotShort2Changed(e_shortName2->text());
@@ -1119,9 +1112,9 @@ void LangOptPage::slotLangFromGlobalActivated(int i)
         slotLangChanged(global_langset.longId(*it));
 
         setPixmap(c.pixmap);
-    e_newName->setText("");
-    e_langLong->setFocus();
-    e_langLong->selectAll();
+        e_newName->setText("");
+        e_langLong->setFocus();
+        e_langLong->selectAll();
 	first = false;
       }
     }
