@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: AdjQueryDlg.cpp,v 1.18 2003/11/18 23:39:48 kniederk Exp $
+    $Id: AdjQueryDlg.cpp,v 1.20 2004/03/07 18:36:11 annma Exp $
 
                    query dialog for adjectives
 
@@ -28,11 +28,9 @@
 
 
 #include "AdjQueryDlg.h"
-#include "QueryDlgBase.h"
 #include "MyProgress.h"
 
 #include <kv_resource.h>
-#include <kvoctraindoc.h>
 #include <QueryManager.h>
 #include <langset.h>
 
@@ -42,7 +40,6 @@
 
 #include <qtimer.h>
 #include <qpushbutton.h>
-#include <qkeycode.h>
 #include <qlineedit.h>
 #include <qlabel.h>
 
@@ -97,7 +94,7 @@ AdjQueryDlg::AdjQueryDlg
 }
 
 
-void AdjQueryDlg::setQuery(QString type,
+void AdjQueryDlg::setQuery(QString,
                            int entry,
                            int col,
                            int q_cycle,
@@ -321,7 +318,7 @@ void AdjQueryDlg::lev3Changed(const QString&)
 }
 
 
-void AdjQueryDlg::closeEvent (QCloseEvent*e)
+void AdjQueryDlg::closeEvent (QCloseEvent*)
 {
   emit sigQueryChoice(StopIt);
 }
