@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: RandomQueryDlg.h,v 1.8 2003/11/18 23:39:48 kniederk Exp $
+    $Id: RandomQueryDlg.h,v 1.11 2004/07/13 13:35:25 annma Exp $
 
                    dialog when in random query mode
 
@@ -35,12 +35,8 @@
 
 /* Library Includes */
 
-#include <qdialog.h>
-#include <qwidget.h>
-#include <qpushbutton.h>
-#include <qbuttongroup.h>
+#include <qcombobox.h>
 #include <qlineedit.h>
-#include <qmultilineedit.h>
 
 class kvoctrainDoc;
 
@@ -65,6 +61,16 @@ public:
                  int mqtime,
                  bool show,
                  kvq_timeout_t type_timeout,
+                 bool _suggestions,
+                 bool _split,
+                 bool _periods,
+                 bool _colons,
+                 bool _semicolons,
+                 bool _commas,
+                 int  _fields,
+                 bool _show_more,
+                 bool _i_know,
+                 bool _swap,
                  QWidget *parent=0,
                  char *name=0);
 
@@ -85,10 +91,6 @@ public:
 public slots:
     virtual void initFocus() const;
 
-protected:
-    void keyPressEvent( QKeyEvent *e );
-    void setHintFields();
-
 signals:
    void sigQueryChoice(QueryDlgBase::Result userchoice);
    void sigEditEntry(int row, int col);
@@ -103,14 +105,33 @@ public slots:
     void timeoutReached();
     void editEntryClicked();
     void slotTransChanged(const QString&);
+    void slotTransLostFocus();
     void slotFFClicked();
     void slotTypeClicked();
     void slotRemClicked();
 
 protected:
+    virtual void keyPressEvent( QKeyEvent *e );
     virtual void closeEvent (QCloseEvent*e);
+    void setHintFields();
+    QStringList extractTranslations (QString trans);
 
     kvoctrainDoc *kv_doc;
+
+    QPtrList<QComboBox> transCombos;
+    QPtrList<QLineEdit> transFields;
+
+    QStringList translations;
+    QStringList vocabulary;
+
+    bool suggestion_hint;
+    bool suggestions;
+    bool split;
+    bool periods;
+    bool colons;
+    bool semicolons;
+    bool commas;
+    int  fields;
 };
 
 #endif
