@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: VerbQueryDlg.cpp,v 1.20 2003/11/18 23:39:48 kniederk Exp $
+    $Id: VerbQueryDlg.cpp,v 1.22 2004/03/07 18:36:11 annma Exp $
 
                     query dialog for verbs
 
@@ -26,11 +26,9 @@
  ***************************************************************************/
 
 #include "VerbQueryDlg.h"
-#include "QueryDlgBase.h"
 #include "MyProgress.h"
 
 #include <kv_resource.h>
-#include <kvoctraindoc.h>
 #include <QueryManager.h>
 
 #include <kapplication.h>
@@ -38,10 +36,8 @@
 #include <klocale.h>
 
 #include <qtimer.h>
-#include <qkeycode.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
-#include <qgroupbox.h>
 #include <qlineedit.h>
 
 VerbQueryDlg::VerbQueryDlg
@@ -110,7 +106,7 @@ void VerbQueryDlg::initFocus() const
 }
 
 
-void VerbQueryDlg::setQuery(QString type,
+void VerbQueryDlg::setQuery(QString,
                             int entry,
                             int col,
                             int q_cycle,
@@ -548,7 +544,7 @@ void VerbQueryDlg::slotP2pChanged(const QString&)
 }
 
 
-void VerbQueryDlg::closeEvent (QCloseEvent*e)
+void VerbQueryDlg::closeEvent (QCloseEvent*)
 {
    emit sigQueryChoice (StopIt);
 }
