@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: BlockOptPage.cpp,v 1.10 2002/07/21 04:27:09 binner Exp $
+    $Id: BlockOptPage.cpp,v 1.14 2004/02/23 16:43:49 annma Exp $
 
                   blocking options page class
 
@@ -14,43 +14,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: BlockOptPage.cpp,v $
-    Revision 1.10  2002/07/21 04:27:09  binner
-    CVS_SILENT Style guide fixes
-
-    Revision 1.9  2002/04/22 19:12:15  binner
-    CVS_SILENT Capitalisation fixes.
-
-    Revision 1.8  2001/12/29 10:41:06  arnold
-    merged fixes from POST-branch
-
-    Revision 1.7  2001/12/26 15:12:58  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.6  2001/11/10 22:30:01  arnold
-    removed compatibility for kde1
-
-    Revision 1.5  2001/10/28 16:56:56  arnold
-    replaced qtarch dialog files with qtdesigner
-
-    Revision 1.4  2001/10/17 21:41:16  waba
-    Cleanup & port to Qt3, QTableView -> QTable
-    TODO:
-    * Fix actions that work on selections
-    * Fix sorting
-    * Fix language-menu
-
-    Revision 1.3  2001/10/13 21:11:02  arnold
-    tested and fixed changes from previous cvs update
-
-    Revision 1.2  2001/10/13 11:45:29  coolo
-    includemocs and other smaller cleanups. I tried to fix it, but as it's still
-    qt2 I can't test :(
-
-    Revision 1.1  2001/10/05 15:46:01  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************
 
  ***************************************************************************
@@ -71,7 +34,6 @@
 #include <kmessagebox.h>
 #include <klocale.h>
 
-#include <qkeycode.h>
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <qcheckbox.h>
@@ -104,14 +66,14 @@ static ListRef date_itemlist [] =
         {I18N_NOOP("3 Weeks"),  3 * 60*60*24*7},
         {I18N_NOOP("4 Weeks"),  4 * 60*60*24*7},
 
-        {I18N_NOOP("1 Month"),  1 * 60*60*24*7*30},
-        {I18N_NOOP("2 Months"), 2 * 60*60*24*7*30},
-        {I18N_NOOP("3 Months"), 3 * 60*60*24*7*30},
-        {I18N_NOOP("4 Months"), 4 * 60*60*24*7*30},
-        {I18N_NOOP("5 Months"), 5 * 60*60*24*7*30},
-        {I18N_NOOP("6 Months"), 6 * 60*60*24*7*30},
-        {I18N_NOOP("10 Months"), 10 * 60*60*24*7*30},
-        {I18N_NOOP("12 Months"), 12 * 60*60*24*7*30},
+        {I18N_NOOP("1 Month"),  1 * 60*60*24*30},
+        {I18N_NOOP("2 Months"), 2 * 60*60*24*30},
+        {I18N_NOOP("3 Months"), 3 * 60*60*24*30},
+        {I18N_NOOP("4 Months"), 4 * 60*60*24*30},
+        {I18N_NOOP("5 Months"), 5 * 60*60*24*30},
+        {I18N_NOOP("6 Months"), 6 * 60*60*24*30},
+        {I18N_NOOP("10 Months"), 10 * 60*60*24*30},
+        {I18N_NOOP("12 Months"), 12 * 60*60*24*30},
         {0 ,  0}
       };
 
@@ -142,8 +104,8 @@ BlockOptPage::BlockOptPage
    connect( block6, SIGNAL(activated(int)), SLOT(slotSetSetBlock6(int)) );
    connect( expire7, SIGNAL(activated(int)), SLOT(slotSetExpire7(int)) );
    connect( block7, SIGNAL(activated(int)), SLOT(slotSetBlock7(int)) );
-   connect( c_expire, SIGNAL(toggled(bool)), SLOT(slotCheckExpire(bool)) );
-   connect( c_blocking, SIGNAL(toggled(bool)), SLOT(slotCheckBlock(bool)) );
+   connect( kcfg_expire, SIGNAL(toggled(bool)), SLOT(slotCheckExpire(bool)) );
+   connect( kcfg_block, SIGNAL(toggled(bool)), SLOT(slotCheckBlock(bool)) );
  
    l_lev7->setBuddy(block7);
    l_lev6->setBuddy(block6);
@@ -163,8 +125,8 @@ void BlockOptPage::setStates(QueryManager *_manager, bool _block, bool _expire)
    manager = _manager;
    block = _block;
    expire = _expire;
-   c_blocking->setChecked(block);
-   c_expire->setChecked(expire);
+   kcfg_block->setChecked(block);
+   kcfg_expire->setChecked(expire);
                                   
    setBlockBox (manager->blockItem(KV_LEV1_GRADE), block1);
    setBlockBox (manager->blockItem(KV_LEV2_GRADE), block2);
@@ -198,14 +160,14 @@ void BlockOptPage::setStates(QueryManager *_manager, bool _block, bool _expire)
    expire6->setEnabled(expire);
    expire7->setEnabled(expire);
 
-   emit blockExpire (c_blocking->isChecked(),
-                     c_expire->isChecked() );
+   emit blockExpire (kcfg_block->isChecked(),
+                     kcfg_expire->isChecked() );
 }
 
 
 void BlockOptPage::initFocus() const
 {
-  c_blocking->setFocus();
+  kcfg_block->setFocus();
 }
 
 
