@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: GroupOptPage.cpp,v 1.8 2002/07/21 05:12:04 binner Exp $
+    $Id: GroupOptPage.cpp,v 1.14 2004/06/26 18:10:37 binner Exp $
 
                      query groups dialog page
 
@@ -15,33 +15,6 @@
 
     -----------------------------------------------------------------------
 
-    $Log: GroupOptPage.cpp,v $
-    Revision 1.8  2002/07/21 05:12:04  binner
-    Use KLineEditDlg and QInputDialog.
-
-    Revision 1.7  2002/01/27 07:17:51  binner
-    CVS_SILENT Fixed capitalisation.
-
-    Revision 1.6  2001/12/26 15:12:58  mueller
-    CVSSILINT: fixincludes
-
-    Revision 1.5  2001/11/23 18:16:48  mueller
-    compile fixes (builddir != stddir, --enable-final)
-
-    Revision 1.4  2001/10/28 16:56:56  arnold
-    replaced qtarch dialog files with qtdesigner
-
-    Revision 1.3  2001/10/13 21:11:02  arnold
-    tested and fixed changes from previous cvs update
-
-    Revision 1.2  2001/10/13 11:45:29  coolo
-    includemocs and other smaller cleanups. I tried to fix it, but as it's still
-    qt2 I can't test :(
-
-    Revision 1.1  2001/10/05 15:46:01  arnold
-    import of version 0.7.0pre8 to kde-edu
-
-
  ***************************************************************************/
 
 /***************************************************************************
@@ -55,14 +28,12 @@
 
 #include "GroupOptPage.h"
 
-#include <qkeycode.h>
 #include <qcombobox.h>
 #include <qlabel.h>
 #include <qpushbutton.h>
 
-#include <kapplication.h>
 #include <klocale.h>
-#include <klineeditdlg.h>
+#include <kinputdialog.h>
 
 GroupOptPage::GroupOptPage
 (
@@ -93,7 +64,7 @@ void GroupOptPage::initFocus() const
 }
 
 
-void GroupOptPage::slotGroupSelected(int item)
+void GroupOptPage::slotGroupSelected(int )
 {
 }
 
@@ -114,15 +85,16 @@ void GroupOptPage::slotDeleteGroup()
 
 void GroupOptPage::slotNewGroup()
 {
-  KLineEditDlg dlg(i18n("Enter group description:"), QString::null, this);
-  dlg.setCaption(i18n("Group Description"));
-  if (dlg.exec()) {
-     ps_name->insertItem(dlg.text().stripWhiteSpace());
-     emit newGroup(dlg.text().stripWhiteSpace());
-     ps_name->setCurrentItem(ps_name->count()-1);
-     emit selectGroup(ps_name->currentItem());
-   }
-   updateButtons();
+  bool ok;
+  QString getGroup = KInputDialog::getText(
+            i18n( "Group Description" ), i18n( "Enter group description:" ), QString::null, &ok );
+  if( !ok )
+       return;
+  ps_name->insertItem(getGroup.stripWhiteSpace());
+  emit newGroup(getGroup.stripWhiteSpace());
+  ps_name->setCurrentItem(ps_name->count()-1);
+  emit selectGroup(ps_name->currentItem());
+  updateButtons();
 }
 
 
