@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: QueryOptionsDlg.h,v 1.3 2003/07/17 12:48:22 binner Exp $
+    $Id: QueryOptionsDlg.h,v 1.6 2004/07/11 13:32:18 annma Exp $
 
                      query options dialog class
 
@@ -30,7 +30,6 @@
 #define QueryOptionsDlg_included
 
 #include <qtabdialog.h>
-#include <qstrlist.h>
 
 #include "ThreshOptPage.h"
 #include "QueryOptPage.h"
@@ -56,6 +55,16 @@ public:
         KComboBox    *lessons,
         QueryManager *manager,
         bool          swapdir,
+        bool          suggestions,
+        bool          split,
+        bool          periods,
+        bool          colons,
+        bool          semicolons,
+        bool          commas,
+        int           fields,
+        bool          show_more,
+        bool          i_know,
+        bool          altlearn,
         bool          block,
         bool          expire,
         vector<PreSetting>  preset,
@@ -66,9 +75,20 @@ public:
     int  getMQueryTime()  const { return queryOptPage->getMQueryTime(); }
     bool getShowCounter() const { return queryOptPage->getShowCounter(); }
     int  getSwapDir()     const { return queryOptPage->getSwapDir(); }
+    int  getAltLearn()    const { return queryOptPage->getAltLearn(); }
     kvq_timeout_t getTypeQueryTimeout()   const
            { return queryOptPage->getTypeQueryTimeout(); }
 
+    bool getSuggestions() const { return queryOptPage->getSuggestions(); }
+    bool getSplit()       const { return queryOptPage->getSplit(); }
+    bool getPeriods()     const { return queryOptPage->getPeriods(); }
+    bool getColons()      const { return queryOptPage->getColons(); }
+    bool getSemicolons()  const { return queryOptPage->getSemicolons(); }
+    bool getCommas()      const { return queryOptPage->getCommas(); }
+    int  getFields()      const { return queryOptPage->getFields(); }
+    bool getShowMore()    const { return queryOptPage->getShowMore(); }
+    bool getIKnow()       const { return queryOptPage->getIKnow(); }
+
     int getBlock()       const { return blockOptPage->getBlock(); }
     int getExpire()      const { return blockOptPage->getExpire(); }
     vector<PreSetting> getPreSetting()  const { return settings; }
@@ -88,6 +108,7 @@ protected slots:
     void slotModifyGroup(int);
 
 protected:
+    virtual void showEvent (QShowEvent*);
 
     QueryManager   manager;
     ThreshOptPage *threshOptPage;
