@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: rowtable.h,v 1.17 2003/06/21 14:31:22 deller Exp $
+    $Id: rowtable.h,v 1.19 2004/04/03 22:16:00 davh Exp $
 
                      table view to kvoctrain document
 
@@ -26,9 +26,7 @@
 
 #include "kv_resource.h"
 
-#include <qglobal.h>
 #include <qtable.h>
-#include <qheader.h>
 
 #include <vector>
 using namespace std;
@@ -83,6 +81,7 @@ protected:
         virtual void contentsMouseDoubleClickEvent( QMouseEvent *e );
         virtual void setItem ( int row, int col, QTableItem * item );
         void setInlineEnabled(bool state);
+        bool getInlineEnabled();
 
 protected slots:
         void menuTriggerTimeout();
